﻿#pragma once
#include "exportdefine.h"
#include "viplexcommon/jsonserializer/jsonserializer.h"
#include "viplexcommon/interface/iviplexrequester.h"
extern "C"
{
    VIPLEX_EXPORT void exportFuncAPIAsync(std::function<void(const char *, ViplexCallback)>, const char *data, ViplexCallback callBack, const uint64_t timeout);
    /**
     * showdoc
     * @catalog 接口示例/初始化
     * @title （IOS）设置移动端平台类型
     * @description 如果调用方是 ios 系统，则需要调用接口，其他平台忽略此接口
     * @url void nvSetPlatform(const char *platform);
     * @param platform 必选 string 由于ios系统锁屏/后台的特殊机制，因此在udp搜索时需要一些特殊处理<br>填写`ios`即可
     * @return ""
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvSetPlatform(const char *platform);
    /**
    * showdoc
    * @catalog 接口示例/初始化
    * @title SDK初始化
    * @description SDK初始化接口,调用SDK接口前必须调用此接口完成SDK初始化
    * @url int nvInit(const char *sdkRootDir, const int type, const int platform);
    * @param sdkRootDir 必选 string 存放SDK日志、数据库的路径
    * @param type 必选 int 调用方来源是第三方还是Nova<br>`1`nova自己的平台<br>`0`第三方平台
    * @param platform 必选 int `1：`移动终端发来的（如手机）<br>`2：`表示传统电脑<br>`3：`表示平板<br>`4：`表示vnnox端发来的<br>`5：`来自iCare
    * @return ""
    * @return_param code int 错误码：<br>`0`初始化成功<br>`65286`日志初始化失败<br>`65287`数据库初始化失败
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT int nvInit(const char *sdkRootDir, const int type, const int platform);


#pragma region Diagnosis 诊断模块 
#pragma endregion 诊断模块 待开发

#pragma region PowerManager 多功能卡电源管理 

		/**
	* showdoc
	* @catalog 接口示例/多功能卡电源管理/定时开关电源
	* @title 设置定时电源开关状态
	* @description 设置定时电源开关状态的接口
	* @method
	* @url void nvSetTimingPowerSwitchStatus(const char *data, ExportViplexCallback callBack);
	* @json_param {"sn":"123456","taskInfo":{"type":"FUNCTIONPOWER","source":{"type":1,"platform":1},"data":[{"commands":[{"conditions":[{"cron":["0 15 10 ? * *","0 0 12 * * ?"],"action":0,"type":"power","startTime":"2018-06-06","endTime":"2018-06-07","enable":false,"powerIndex":0,"flag":"abc"},{"cron":["0 15 10 ? * *","0 0 12 * * ?"],"action":1,"type":"power","startTime":"2018-06-06","endTime":"2018-06-07","enable":false,"powerIndex":1,"flag":"abc"}]}],"enable":false,"portIndex":0,"connectIndex":1}]}}
	* @param sn 必选 string 产品唯一序列号
	* @param type 必选 string FUNCTIONPOWER(固定值)
	* @param source 必选 Object 表示任务的发布来源.如:VNNOX,CS,LCT等
	* @param source 必选 Object 表示任务的发布来源.如:VNNOX,CS,LCT等
	* @param platform 必选 int 表示任务发布来源,1:手机,2;CS,3:平板,4:VNNOX,5;Care,6:LCT
	* @param data 必选 ObjectArray 按照条件执行的多功能卡任务集合
	* @param enable 必选 bool 按条件执行的使能开关.如果为true,则执行conditions中的定时任务,如果为false,则不执行
	* @param portIndex 必选 int 多功能卡的网口地址
	* @param powerIndex 必选 int 多功能卡网口连接的设备编号
	* @param commands 必选 ObjectArray 按照条件执行的任务集合,支持多任务
	* @param conditions 必选 ObjectArray 按照条件执行的任务集合,支持多任务
	* @param cron 必选 StringArray 每个控制方案使用cron表达式数组表示,当有多个cron表达式时,cron表达式之间使用或的关系
	* @param action 必选 int 具体电源控制:0开,1关
	* @param type 必选 string 开关的类型,以字符串的形式表征
	* @param startTime 必选 string 有效时间的开始日期
	* @param endTime 必选 string 有效时间的结束日期
	* @param enable 必选 boolean 按条件执行的使能开关.如果为true,那么此条cron表达式生效,如果为false,则不生效
	* @param powerIndex 必选 int 多功能卡电源的下标(目前支持0-7)
	* @param flag 必选 string 此字段属于VNNOX,手机,CS专用字段
	* @return {"data":"12d4sa654d564ddauioaj4163"}
	* @return_param code int 错误码：`0`获取成功
	* @return_param data string 成功返回md5码,失败返回错误码对应的说明
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvSetTimingPowerSwitchStatus(const char *data, ExportViplexCallback callBack);
		/**
	* showdoc
	* @catalog 接口示例/多功能卡电源管理/定时开关电源
	* @title 获取定时开关电源状态
	* @description 获取定时开关电源状态的接口
	* @method
	* @url void nvGetTimingPowerSwitchStatus(const char *data, ExportViplexCallback callBack);
	* @json_param {"sn":"123456"}
	* @param sn 必选 string 产品唯一序列号
	* @return {"data":[{"commands":[{"conditions":[{"action":0,"cron":["0 15 10 ? * *","0 0 12 * * ?"],"enable":false,"endTime":"2018-06-07","flag":"abc","powerIndex":0,"startTime":"2018-06-06","type":"power"},{"action":1,"cron":["0 15 10 ? * *","0 0 12 * * ?"],"enable":false,"endTime":"2018-06-07","flag":"abc","powerIndex":1,"startTime":"2018-06-06","type":"power"}]}],"connectIndex":1,"enable":false,"portIndex":0}],"source":{"platform":1,"type":1},"type":"FUNCTIONPOWER"}
	* @return_param code int 错误码：`0`获取成功
	* @return_param data string 成功返回md5码,失败返回错误码对应的说明
	* @return_param type string FUNCTIONPOWER(固定值)
	* @return_param source Object 表示任务的发布来源.如:VNNOX,CS,LCT等
	* @return_param source Object 表示任务的发布来源.如:VNNOX,CS,LCT等
	* @return_param platform int 表示任务发布来源,1:手机,2;CS,3:平板,4:VNNOX,5;Care,6:LCT
	* @return_param data ObjectArray 按照条件执行的多功能卡任务集合
	* @return_param enable bool 按条件执行的使能开关.如果为true,则执行conditions中的定时任务,如果为false,则不执行
	* @return_param portIndex int 多功能卡的网口地址
	* @return_param powerIndex int 多功能卡网口连接的设备编号
	* @return_param commands ObjectArray 按照条件执行的任务集合,支持多任务
	* @return_param conditions ObjectArray 按照条件执行的任务集合,支持多任务
	* @return_param cron StringArray 每个控制方案使用cron表达式数组表示,当有多个cron表达式时,cron表达式之间使用或的关系
	* @return_param action int 具体电源控制:0开,1关
	* @return_param type string 开关的类型,以字符串的形式表征
	* @return_param startTime string 有效时间的开始日期
	* @return_param endTime string 有效时间的结束日期
	* @return_param enable boolean 按条件执行的使能开关.如果为true,那么此条cron表达式生效,如果为false,则不生效
	* @return_param powerIndex int 多功能卡电源的下标(目前支持0-7)
	* @return_param flag string 此字段属于VNNOX,手机,CS专用字段
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvGetTimingPowerSwitchStatus(const char *data, ExportViplexCallback callBack);
	/**
    * showdoc
    * @catalog 接口示例/多功能卡电源管理/电源实时状态获取
    * @title 获取电源实时状态获取
    * @description 获取电源实时状态的接口
    * @method
    * @url void nvGetRealtimePowerSwitchStatus(const char *data, ExportViplexCallback callBack);
    * @json_param {"sn":"123456"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"source":{"type":1,"platform":1},"current_status_info":[{"portIndex":0,"connectIndex":1,"updatePowerIndexStates":[{"type":"屏体电源","powerIndex:":0,"status":0},{"type":"屏体电源","powerIndex:":1,"status":0},{"type":"屏体电源","powerIndex:":2,"status":0},{"type":"屏体电源","powerIndex:":3,"status":0},{"type":"屏体电源","powerIndex:":4,"status":0},{"type":"屏体电源","powerIndex:":5,"status":0},{"type":"屏体电源","powerIndex:":6,"status":0},{"type":"屏体电源","powerIndex:":7,"status":0}]}]}
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 成功返回md5码,失败返回错误码对应的说明
    * @return_param source Object 表示任务的发布来源.如:VNNOX,CS,LCT等
    * @return_param type Object 表示任务的发布来源.如:VNNOX,CS,LCT等
    * @return_param platform int 表示任务发布来源,1:手机,2;CS,3:平板,4:VNNOX,5;Care,6:LCT
    * @return_param current_status_info ObjectArray 多功能卡的各路电源状态
    * @return_param portIndex int 多功能卡的网口地址
    * @return_param connectIndex int 多多功能卡网口连接的设备编号
    * @return_param updatePowerIndexStates ObjectArray 每张多功能卡中各路电源的状态
    * @return_param type string 开关的类型,以字符串的形式表征
    * @return_param powerIndex int 多功能卡电源的下标(目前支持0-7)
    * @return_param status int 0:开,1:关
    * @remark
    * @number 99
    */
	VIPLEX_EXPORT void nvGetRealtimePowerSwitchStatus(const char *data, ExportViplexCallback callBack);
    /**
     * showdoc
     * @catalog 接口示例/多功能卡电源管理/手动开关电源
     * @title 设置手动电源开关状态
     * @description 设置手动电源开关状态的接口
     * @method
     * @url void nvSetManualPowerSwitchStatus(const char *data, ExportViplexCallback callback)
     * @json_param {"sn":"123456","data":{"type":"FUNCTIONPOWER","source":{"type":1,"platform":1},"data":[{"conditions":[{"action":1,"type":"屏体电源","powerIndex":0},{"action":1,"type":"风扇电源","powerIndex":1}],"portIndex":0,"connectIndex":1}]}}
     * @param sn 必选 string 产品唯一序列号
     * @param data 必选 ObjectArray 按照条件执行的多功能卡任务集合
     * @param conditions 必选 ObjectArray 按照条件执行的任务集合,支持多任务
     * @param action 必选 int 具体电源控制。0：开、1：关
     * @param powerIndex 必选 int 开关的类型，以字符串的形式表征
     * @param type 必选 string 多功能卡电源的下标,(目前支持0-7)
     * @param connectIndex 必选 int 多功能卡网口连接的设备编号
     * @param portIndex 必选 int 多功能卡的网口地址
     * @param source 必选 Object 表示任务的发布来源。如：VNNOX、CS、LCT等
     * @param platform 必选 int 表示任务发布来源,1：手机,2：CS,3：平板,4：VNNOX,5：Care、6：LCT
     * @param type 必选 int 表示发布任务的平台,1：nova自己的平台0：第三方平台
     * @param type 必选 string FUNCTIONPOWER(固定值)
     * @return {"data":"12d4sa654d564ddauioaj4163"}
     * @return_param code int 错误码：`0`获取成功
     * @return_param data string 成功返回md5码,失败返回错误码对应的说明
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvSetManualPowerSwitchStatus(const char *data, ExportViplexCallback callBack);
    /**
     * showdoc
     * @catalog 接口示例/多功能卡电源管理/手动开关电源
     * @title 获取手动电源开关状态
     * @description 获取手动电源开关状态的接口
     * @method
     * @url void nvGetManualPowerSwitchStatus(const char *data, ExportViplexCallback callback)
     * @json_param {"sn":"123456"}
     * @param sn 必选 string 产品唯一序列号
     * @return {"data":[{"conditions":[{"action":1,"powerIndex":0,"type":"屏体电源"},{"action":1,"powerIndex":1,"type":"风扇电源"}],"connectIndex":1,"portIndex":0}],"source":{"platform":1,"type":1},"type":"FUNCTIONPOWER"}
     * @return_param code int 错误码：`0`获取成功
     * @return_param data string 成功返回md5码,失败返回错误码对应的说明
     * @return_param data ObjectArray 按照条件执行的多功能卡任务集合
     * @return_param conditions ObjectArray 按照条件执行的任务集合,支持多任务
     * @return_param action int 具体电源控制。0：开、1：关
     * @return_param powerIndex int 开关的类型，以字符串的形式表征
     * @return_param type string 多功能卡电源的下标,(目前支持0-7)
     * @return_param connectIndex int 多功能卡网口连接的设备编号
     * @return_param portIndex int 多功能卡的网口地址
     * @return_param source Object 表示任务的发布来源。如：VNNOX、CS、LCT等
     * @return_param platform int 表示任务发布来源,1：手机,2：CS,3：平板,4：VNNOX,5：Care、6：LCT
     * @return_param type int 表示发布任务的平台,1：nova自己的平台0：第三方平台
     * @return_param type string FUNCTIONPOWER(固定值)
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvGetManualPowerSwitchStatus(const char *data, ExportViplexCallback callBack);
#pragma endregion 多功能卡电源管理 待开发

#pragma region VolumeController 音量调节
    /**
    * showdoc
    * @catalog 接口示例/音量调节
    * @title 获取音量
    * @description 获取音量的接口
    * @method
    * @url void nvGetVolume(const char * data, ExportViplexCallback callback)
    * @json_param {"sn": "BZSA17332J0A20002272"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"ratio":75.0}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回data详情
    * @return_param ratio float 音量百分比
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetVolumeAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/音量调节
    * @title 设置音量
    * @description 设置音量的接口
    * @method
    * @url void nvSetVolume(const char * data, ExportViplexCallback callback)
    * @json_param {"sn": "BZSA17332J0A20002272","volumeInfo": {"ratio": 10}}
    * @param sn 必选 string 产品唯一序列号
    * @param volumeInfo 必选 Object 请求信息对象
    * @param ratio 必选 float 音量百分比
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 返回data详情
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetVolumeAsync(const char *data, ExportViplexCallback callback);

	/**
	* showdoc
	* @catalog 接口示例/音量调节/设置定时音量的方案
	* @title 设置定时音量的方案
	* @description 定时设置音量的的接口
	* @method
	* @url void nvSetTimingVolume(const char *data, ExportViplexCallback callBack);
	* @json_param {"sn":"BZSA79353N1310006847","data":{"type":"VOLUME","source":{"type":0,"platform":1},"enable":true,"conditions":[{"cron":["0 15 10 ? * *"],"value":50.0,"enable":true,"startTime":"2020-09-01 00:00:00","endTime":"4016-06-06 24:00:00"},{"cron":["0 15 10 ? * *"],"value":0,"enable":true,"startTime":"2020-09-01 00:00:00","endTime":"4016-06-06 24:00:00"}]}}
	* @param sn 必选 string 产品唯一序列号
	* @param type 必选 string 固定为"VOLUME"
	* @param type 必选 int `1`nova自己的平台,`0`第三方平台
	* @param platform 必选 int `1`移动终端发来的,`2`表示传统电脑,`3`表示平板,`4`表示web端发来的
	* @param enable 必选 bool 按条件执行的使能开关
	* @param cron 必选 stringarray 重复次数，每条条件使用cron表达式数组表示
	* @param value 必选 float 音量值,0-100
	* @param enable 必选 bool 该条件执行的使能开关
	* @param startTime 必选 string 有效期起始时间yyyy-MM-dd HH:mm:ss
	* @param sn 必选 string 有效期起始时间yyyy-MM-dd HH:mm:ss
	* @return ""
	* @return_param code int 错误码：`0`获取成功
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvSetTimingVolumeAsync(const char *data, ExportViplexCallback callback);
		/**
	* showdoc
	* @catalog 接口示例/音量调节/获取定时音量的方案
	* @title 获取定时音量的方案
	* @description 定时获取音量的的接口
	* @method
	* @url void nvGetTimingVolume(const char *data, ExportViplexCallback callBack);
	* @json_param {"sn":"BZSA79353N1310006847"}
	* @param sn 必选 string 产品唯一序列号
	* @return {"conditions":[{"value":50.0,"cron":["0 15 10 ? * *"],"enable":true,"endTime":"4016-06-06 24:00:00","startTime":"2020-09-01 00:00:00"},{"value":0.0,"cron":["0 15 10 ? * *"],"enable":true,"endTime":"4016-06-06 24:00:00","startTime":"2020-09-01 00:00:00"}],"enable":true,"source":{"platform":1,"type":1},"type":"VOLUME"}
	* @return_param code int 错误码：`0`获取成功
	* @return_param type string 固定为"VOLUME"
	* @return_param type int `1`nova自己的平台,`0`第三方平台
	* @return_param platform int `1`移动终端发来的,`2`表示传统电脑,`3`表示平板,`4`表示web端发来的
	* @return_param enable bool 按条件执行的使能开关
	* @return_param cron stringarray 重复次数，每条条件使用cron表达式数组表示
	* @return_param value float 音量值,0-100
	* @return_param enable bool 该条件执行的使能开关
	* @return_param startTime string 有效期起始时间yyyy-MM-dd HH:mm:ss
	* @return_param sn string 有效期起始时间yyyy-MM-dd HH:mm:ss
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvGetTimingVolumeAsync(const char *data, ExportViplexCallback callback);


#pragma endregion VolumeController 音量调节

#pragma region VPNConnection VPN连接管理
    /**
    * showdoc
    * @catalog 接口示例/VPN连接管理/VPN连接管理
    * @title 获取VPN连接信息
    * @description 获取VPN连接信息的接口
    * @method
    * @url void nvGetVPNConnectInfo(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"123456"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"connectInfo":{"connectStatus":2,"failReasonCode":0},"guid":"decf313f-1014-44ad-a059-28ed58fce170","networkInfo":{"ipAddress":"10.0.0.2"},"source":{"platform":2,"type":1},"taskAction":"VPN_CONNECT","timestamp":"2020-07-13 T02:27:47 Z+00:00","vpnInfo":{"address":"vpn.vnnox.com","isReconnect":false,"name":"456","password":"bOwVRSe8l4WnE6hCkItCEgLHFZpNndYx","protocolType":1,"redialInterval":180,"redialNumber":3,"sessionTimeout":7200,"sharedSecretKey":"novastar.tech","username":"vnnox"},"orderId":-1}
    * @return_param connectInfo object 连接上报信息
    * @return_param connectStatus int 连接接状态：1、链接中2、链接成功3、断开
    * @return_param failReasonCode int 失败原因code，0：正常，ERR_INTERRUPTED：超时后主动中断，ERR_ALREADY_EXISTED：命令重复，其他错误码见错误码说明
    * @return_param guid string 最后一条命令的唯一标识
    * @return_param timestamp string 时间戳
    * @return_param taskAction string 操作：VPN_CLOSE，VPN_CONNECT
    * @return_param networkInfo object 网络信息
    * @return_param ipAddress string Ip地址
    * @return_param source object 上报资源信息
    * @return_param type int 类型信息：1：nova，2：第三方平台
    * @return_param platform int 1：vnnox，2：cs软件
    * @return_param vpnInfo object vpn信息
    * @return_param address string vpn地址
    * @return_param isReconnect boolean 是否断线重连
    * @return_param name string vpn名称
    * @return_param password string 密码
    * @return_param protocolType string vpn协议类型
    * @return_param redialInterval int 重拨间隔
    * @return_param redialNumber int 重播次数
    * @return_param sessionTimeout int 会话时长
    * @return_param sharedSecretKey string 共享秘钥
    * @return_param username string 用户名
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetVPNConnectInfoAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/VPN连接管理/VPN连接管理
    * @title 设置VPN连接信息
    * @description 设置VPN连接信息的接口
    * @method
    * @url void nvSetVPNConnectInfo(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZWA17422J1X20000093","taskInfo":{"guid":"123456","taskAction":"VPN_CLOSE","source":{"type":1,"platform":2},"vpnInfo":{"name":"123456","address":"vpn.vnnox.com","protocolType":1,"username":"vnnox","password":"123456","sharedSecretKey":"novastar.tech","redialNumber":3,"redialInterval":180,"sessionTimeout":7200,"isReconnect":false}}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 object 设置VPN的详细信息
    * @param guid 必选 string 命令的唯一标识
    * @param taskAction 必选 string 操作：VPN_CLOSE，VPN_CONNECT
    * @param source 非必选 object 上报资源信息
    * @param type 非必选 int 类型信息：1：nova，0：第三方平台
    * @param platform 非必选 int 平台类型：1：移动终端发来的（如手机），2：表示传统电脑，3：表示平板，4：表示web端发来的
    * @param vpnInfo 必选 object vpn信息
    * @param name 必选 string vpn名称
    * @param address 必选 string vpn地址
    * @param protocolType 必选 string vpn协议类型
    * @param username 必选 string 用户名
    * @param password 必选 string 密码
    * @param sharedSecretKey 必选 string 共享秘钥
    * @param redialNumber 必选 int 重拨次数
    * @param redialInterval 必选 int 重播间隔
    * @param sessionTimeout 必选 int 会话时长
    * @param isReconnect 必选 boolean 是否断线重连
    * @return ""
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 成功返回md5码,失败返回错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetVPNConnectInfoAsync(const char *data, ExportViplexCallback callback);
#pragma endregion VPN连接管理 待开发

#pragma region AppManager
    /**
     * showdoc
     * @catalog 接口示例/App管理
     * @title 获取已安装的APP信息
     * @description 获取已安装的APP信息
     * @method
     * @url void getInstalledPackageInfo(const char *data, ExportViplexCallback callBack);
     * @json_param {"sn":"BZSA17332J0A20002272"}
     * @param sn 必选 string 产品唯一序列号
     * @return {"appInfos":[{"packageName":"nova.priv.terminal.syssetting","versionName":"1.0.2.0501","versionCode":102,"label":"systemSetting","isNetWorkPermission":true},
                                     {"packageName":"nova.priv.terminal.easypluto","versionName":"1.0.2.0502","versionCode":102,"label":"easypluto","isNetWorkPermission":true}]}
     * @return_param code int 错误码：`0`获取成功`65535`请求超时
     * @return_param packageName string 包名
     * @return_param versionName tring 版本名称
     * @return_param versionCode int	版本编号
     * @return_param label string APP名称
     * @return_param isNetWorkPermission boolean 是否允许访问网络
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvGetInstalledPackageInfoAsync(const char *data, ExportViplexCallback callBack);

    /**
     * showdoc
     * @catalog 接口示例/App管理
     * @title 获取正在运行的APP版本信息
     * @description 获取正在运行的APP版本信息
     * @method
     * @url void getRunningPackageInfo(const char *data, ExportViplexCallback callBack);
     * @json_param {"sn":"BZSA17332J0A20002272"}
     * @param sn 必选 string 产品唯一序列号
     * @return {"appInfos":[{"packageName":"nova.priv.terminal.syssetting","versionName":"1.0.2.0501","versionCode":102,"label":"systemSetting","isNetWorkPermission":true},
                                     {"packageName":"nova.priv.terminal.easypluto","versionName":"1.0.2.0502","versionCode":102,"label":"easypluto","isNetWorkPermission":true}]}
     * @return_param code int 错误码：`0`获取成功`65535`请求超时
     * @return_param packageName string 包名
     * @return_param versionName tring 版本名称
     * @return_param versionCode int	版本编号
     * @return_param label string APP名称
     * @return_param isNetWorkPermission boolean 是否允许访问网络
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvGetRunningPackageInfoAsync(const char *data, ExportViplexCallback callBack);

    /**
     * showdoc
     * @catalog 接口示例/App管理
     * @title 停止运行APP
     * @description 停止运行APP
     * @method
     * @url void forceStopApp(const char *data, ExportViplexCallback callBack);
     * @json_param {"sn":"BZSA17332J0A20002272"，"packageName":"nova.priv.terminal.screenService"}
     * @param sn 必选 string 产品唯一序列号
     * @param packageName 必选 string 要停止app的包名称
	 * @return {"data":"success"}
     * @return_param code int 错误码：`0`获取成功`65535`请求超时
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvForceStopAppAsync(const char *data, ExportViplexCallback callBack);

    /**
     * showdoc
     * @catalog 接口示例/App管理
     * @title 卸载安卓程序
     * @description 卸载安卓程序
     * @method
     * @url void uninstallPackage(const char *data, ExportViplexCallback callBack);
     * @json_param {"sn":"BZSA17332J0A20002272"，"packageName":"nova.priv.terminal.screenService"}
     * @param sn 必选 string 产品唯一序列号
     * @param packageName 必选 string 要卸载app的包名称
	 * @return {"data":"success"}
     * @return_param code int 错误码：`0`获取成功`65535`请求超时
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvUninstallPackageAsync(const char *data, ExportViplexCallback callBack);


    /**
    * showdoc
    * @catalog 接口示例/App管理
    * @title 安装APP
    * @description 安装APP
    * @method
    * @url void startUploadApk(const char *data, ExportViplexCallback callBack);
    * @json_param {"sn":"BZSA17332J0A20002272"，"apkFile":"data/data/com.example.myapp/app_flutter/NETEASE.apk","packageName":"","startAfterInstall":true}
    * @param sn 必选 string 产品唯一序列号
    * @param apkFile 必选 string 待安装app路径
    * @param packageName 非必选 string app名称
    * @param startAfterInstall 必选 bool 安装完成是否启动app
	* @return {"data":"success"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @remark
    * @number 10
    */
    VIPLEX_EXPORT void nvStartUploadApkCoreAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion AppManager APP管理

#pragma region PlayLogger 播放日志
    /**
    * showdoc
    * @catalog 接口示例/播放日志/播放日志路径获取
    * @title 播放日志路径获取
    * @description 播放日志路径获取的接口
    * @method
    * @url void nvGetPlaylogPath(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"123456"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"logList":["2020-07-13.json"],"url":"/sdcard/nova/viplex_terminal/play_log"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param logList stringArray 播放日志文件名集合
    * @return_param url string 播放日志目录路径
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetPlaylogPathAsync(const char *data, ExportViplexCallback callback);
#pragma endregion 播放日志 待开发

#pragma region PlayFont 字体
    /**
     * showdoc
     * @catalog 接口示例/字体
     * @title 获取终端支持的字体
     * @description 获取终端支持的字体的接口
     * @method
     * @url void nvGetTerminalFont(const char *data, ExportViplexCallback callback)
     * @json_param {"sn":"123456"}
     * @param sn 必选 string 产品唯一序列号
     * @return {"supportFonts":[{"name":"Arial","src":"system"},{"name":"Calibri","src":"system"},{"name":"Wingdings2","src":"system"},{"name":"SimSun","src":"system"},{"name":"KaiTi","src":"system"},{"name":"Microsoft YaHei","src":"system"},{"name":"Agency FB","src":"custom"}]}
     * @return_param code int 错误码：`0`获取成功
     * @return_param supportFonts ArrayObject 终端支持的字体
     * @return_param name String 字体名称
     * @return_param src String 字体来源，目前包括system、custom，以后也可支持来自某用户
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvGetTerminalFontAsync(const char *data, ExportViplexCallback callBack);
    /**
     * showdoc
     * @catalog 接口示例/字体
     * @title 删除字体
     * @description 删除字体的接口
     * @method
     * @url void nvDeleteFont(const char *data, ExportViplexCallback callback)
     * @json_param {"sn":"BZWA17422J1X20000093","taskInfo":{"fonts":[{"name":"Arail"}]}}
     * @param sn 必选 string 产品唯一序列号
     * @param taskInfo 必选 Object 字体信息
     * @param fonts 必选 object 要删除的字体列表
     * @param name 必选 string 字体名称
     * @return ""
     * @return_param code int 错误码：`0`获取成功
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvDeleteFontAsync(const char *data, ExportViplexCallback callBack);
    /**
     * showdoc
     * @catalog 接口示例/字体
     * @title 更新字体
     * @description 更新字体的接口
     * @method
     * @url void nvUpdateFont(const char *data, ExportViplexCallback callback)
     * @json_param {"sn":"BZWA17422J1X20000093","localFontPath":"C:\\Windows\\Fonts","taskInfo":{"fonts":[{"name":"Agency FB","style":["Bold","Italic","Normal","Underline","Strikeout"],"file":["AGENCYB.TTF","AGENCYB.TTF","AGENCYB.TTF","AGENCYB.TTF","AGENCYB.TTF"]}]}}
     * @param sn 必选 string 产品唯一序列号
     * @param localFontPath 必选 string 字体存放目录
     * @param taskInfo 必选 Object 字体信息
     * @param fonts 必选 objectArray 要添加的字体列表
     * @param name 必选 string 字体名称
     * @param style 必选 stringArray 字体属性
     * @param file 必选 stringArray 字体文件名
     * @return ""
     * @return_param code int 错误码：`0`获取成功
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvUpdateFontAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion 字体 待开发

#pragma region 生产功能测试
#pragma endregion 生产功能测试 待开发

#pragma region LEDSplicer 多屏拼接
    /**
    * showdoc
    * @catalog 接口示例/多屏拼接
    * @title 获取拼接参数
    * @description 获取多屏拼接参数的接口
    * @method
    * @url void nvGetSpliceInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA17332J0A20002272"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"height":0,"isScale":false,"offsetX":0,"offsetY":0,"order":0,"orderNum":0,"videoSource":0,"width":0}
    * @return_param order int 拼接屏的顺序
    * @return_param width int 播放窗口宽度
    * @return_param height int 播放窗口高度
    * @return_param offsetX int 视频源x偏移量
    * @return_param offsetY int 视频源y偏移量
    * @return_param videoSource int 视频源:内部0,HDMI1
    * @return_param orderNum int 拼接数量
    * @return_param isScale bool 是否缩放,true为全屏缩放,false为不缩放
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetSpliceInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
   * showdoc
   * @catalog 接口示例/多屏拼接
   * @title 设置拼接参数
   * @description 设置多屏拼接参数的接口
   * @method
   * @url void void nvSetSpliceInfo(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"","SpliceInfo":{"height":400,"isScale":false,"offsetX":0,"offsetY":0,"order":0,"orderNum":0,"videoSource":0,"width":400}}
   * @param sn 必选 string 产品唯一序列号
   * @param order 必选 int 拼接屏的顺序
   * @param width 必选 int 播放窗口宽度
   * @param height 必选 int 播放窗口高度
   * @param offsetX 必选 int 视频源x偏移量
   * @param offsetY 必选 int 视频源y偏移量
   * @param videoSource 必选 int 视频源:内部0,HDMI1
   * @param orderNum int 必选 拼接数量
   * @param isScale bool 必选 是否缩放,true为全屏缩放,false为不缩放
   * @return ""
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvSetSpliceInfoAsync(const char *data, ExportViplexCallback callBack);

#pragma endregion 多屏拼接 

#pragma region RunningLogger
#pragma endregion RunningLogger 日志管理 待开发

#pragma region SelfInspection
#pragma endregion SelfInspection 一键自检 待开发

#pragma region IPAudio
#pragma endregion IPAudio IP音频 待开发

#pragma region FixedPointDelivery
#pragma endregion FixedPointDelivery 定点投放 待开发

#pragma region EmergencyIntercut
#pragma endregion EmergencyIntercut 紧急插播 待开发

#pragma region Sensor
#pragma endregion Sensor 传感器子板 待开发

#pragma region ExternalDelivery
#pragma endregion ExternalDelivery 外投调节 待开发

#pragma region RadioFrequency
	/**
	* showdoc
	* @catalog 接口示例/射频管理
	* @title 获取Lora信息
	* @description 获取Lora信息
	* @method
	* @url void getLoraInfo(const char *data, ExportViplexCallback callBack)
	* @json_param {"sn":"BZSA17332J0A20002272"}
	* @param sn 必选 string 产品唯一序列号
	* @return {"exist":true,"frequency":433,"power":1,"version":1,"channel":23,"baudRate":9600,"transSpeed":2.4,"workState":0,"modelNum":1}
	* @return_param code int 错误码：0 获取成功，65535 请求超时
	* @return_param exist boolean 模块是否存在
	* @return_param frequency float 频率(单位：mhz)
	* @return_param power float 功率(单位：w)
	* @return_param version int 版本
	* @return_param channel float 信道
	* @return_param baudRate int 波特率
	* @return_param transSpeed float 空中速率(k/bps)
	* @return_param workState String 工作模式
	* @return_param modelNum int 模块型号
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvGetLoraInfoAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion RadioFrequency 射频管理  待补充

#pragma region PowerController

#pragma endregion PowerController 终端电源控制 待开发

#pragma region VideoSourceController
    /**
     * showdoc
     * @catalog 接口示例/视频源控制
     * @title 获取当前视频源
     * @description 获取当前视频源
     * @method
     * @url void getVideoControlInfo(const char *data, ExportViplexCallback callBack);
     * @json_param {"sn":"BZSA17332J0A20002272"}
     * @param sn 必选 string 产品唯一序列号
     * @return {"type":"VIDEO_SOURCE_SWITCH","source":{"type":1,"platform":1},"videoMode":1,"videoSource":0,"isScale":false,"offsetX":0,"offsetY":0,"conditions":[{"cron":"0 0 12 ? * *","source":0,"enable":true},{"cron":"0 0 12 ? * *","source":1,"enable":true}]}
     * @return_param code int 错误码：`0`获取成功`65535`请求超时
     * @return_param type String 固定值："VIDEO_SOURCE_SWITCH"
     * @return_param source object 下发命令的来源
     * @return_param type int 1：nova自己的平台, 0：第三方平台
     * @return_param platform int 0：未知，1：移动终端发来的（如手机），2：表示传统电脑，3：表示平板，4：表示web端发来的，5：终端本身
     * @return_param videoMode int 模式，HDMI优先 0，手动 1， 定时 2
     * @return_param videoSource int 视频源 SOURCE_INSIDE 内部 0， SOURCE_HDMI HDMI 1 ,该字段只对手动模式下有用
     * @return_param isScale	boolean	是否缩放，true为全屏缩放，false为不缩放
     * @return_param offsetX	int 偏移X
     * @return_param offsetY	int 偏移Y
     * @return_param conditions object 任务列表
     * @return_param cron String cron表达式，用户表示开始时间和重复
     * @return_param source int 视频源 SOURCE_INSIDE 内部 0， SOURCE_HDMI HDMI 1
     * @return_param enable boolean	该条定时任务是否生效
     * @remark
     * @number 99
     */

    VIPLEX_EXPORT void nvGetVideoControlInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
     * showdoc
     * @catalog 接口示例/视频源控制
     * @title 设置当前视频源
     * @description 设置当前视频源
     * @method
     * @url void setVideoControlInfo(const char *data, ExportViplexCallback callBack);
     * @json_param {"sn":"BZSA17332J0A20002272", "videdSourceInfo":{"type":"VIDEO_SOURCE_SWITCH","source":{"type":1,"platform":1},"videoMode":1,"videoSource":0,"isScale":false,"offsetX":0,"offsetY":0,"conditions":[{"cron":"0 0 12 ? * *","source":0,"enable":true},{"cron":"0 0 12 ? * *","source":1,"enable":true}]}}
     * @param sn 必选 string 产品唯一序列号
     * @param type String 固定值："VIDEO_SOURCE_SWITCH"
     * @param source object 下发命令的来源
     * @param type int 1：nova自己的平台, 0：第三方平台
     * @param platform int 0：未知，1：移动终端发来的（如手机），2：表示传统电脑，3：表示平板，4：表示web端发来的，5：终端本身
     * @param videoMode int 模式，HDMI优先 0，手动 1， 定时 2
     * @param videoSource int 视频源 SOURCE_INSIDE 内部 0， SOURCE_HDMI HDMI 1 ,该字段只对手动模式下有用
     * @param isScale	boolean	是否缩放，true为全屏缩放，false为不缩放
     * @param offsetX	int 偏移X
     * @param offsetY	int 偏移Y
     * @param conditions object 任务列表
     * @param cron String cron表达式，用户表示开始时间和重复
     * @param source int 视频源 SOURCE_INSIDE 内部 0， SOURCE_HDMI HDMI 1
     * @param enable boolean	该条定时任务是否生效
	 * @return {"data":"success"}
     * @return_param code int 错误码：`0`获取成功`65535`请求超时
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvSetVideoControlInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/视频源控制/EDID控制
    * @title 设置EDID
    * @description 设置EDID的接口
    * @method
    * @url void nvSetVideoEDID(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZWA17422J1X20000093","taskInfo":{"width":1920,"height":1080}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 设置信息
    * @param width 必选 int 显示屏宽度
    * @param height 必选 int 显示屏高度
    * @param fieldRate 必选 int 场频，即刷新频率
    * @return ""
    * @return_param code int 错误码：`0`获取成功
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetVideoEDIDAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/视频源控制/EDID控制
    * @title 获取EDID
    * @description 获取EDID的接口
    * @method
    * @url void nvGetVideoEDID(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZWA17422J1X20000093"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"fieldRate":60,"height":900,"width":1600}
    * @return_param code int 错误码：`0`获取成功
    * @return_param fieldRate int 场频，即刷新频率
    * @return_param height int 显示屏高度
    * @return_param height int 显示屏宽度
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetVideoEDIDAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion VideoSourceController 视频源控制

#pragma region userInfo

    /**
    * showdoc
    * @catalog 接口示例/显示屏用户信息
    * @title 修改配显示屏用户信息
    * @description 修改配显示屏用户信息的接口
    * @method
    * @url void nvSetUserInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"","userInfo":{"aliasName":"easy-pluto","registerAddress":{"country":"中国","province":"山西省","city":"西安市","county":"雁塔区","address":"科技二路，西安软件园"}}}
    * @param sn 必选 string 产品唯一序列号
    * @param userInfo 必选 Object 详情
    * @param aliasName 必选 string 显示屏别名
    * @param registerAddress 必选 object 注册地址
    * @param country 必选 string 国家
    * @param province 必选 string 省份
    * @param city 必选 string 城市
    * @param county 必选 string 县，区
    * @param address 必选 string 详细地址
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetUserInfoAsync(const char *data, ExportViplexCallback callBack);

    /**
    * showdoc
    * @catalog 接口示例/显示屏用户信息
    * @title 获取显示屏用户信息
    * @description 获取显示屏用户信息的接口
    * @method
    * @url void nvGetUserInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"aliasName":"easy-pluto","registerAddress":{"country":"中国","province":"山西省","city":"西安市","county":"雁塔区","address":"科技二路，西安软件园"}}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param aliasName string 显示屏别名
    * @return_param registerAddress object 注册地址
    * @return_param country string 国家
    * @return_param province string 省份
    * @return_param city string 城市
    * @return_param county string 县，区
    * @return_param address string 详细地址
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetUserInfoAsync(const char *data, ExportViplexCallback(callBack));
#pragma endregion userInfo 显示屏用户信息

#pragma region Login
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 搜索屏体
    * @description 搜索当前wifi网络下的所有屏体
    * @url void nvSerchTerminalAsync(ExportViplexCallback callback)
    * @return {"sn":"20393844393033","productName":"AX200","width":400,"height":800,"rotation":0,"aliasName":"XianYataScreen","logined":true,"username":["admin"],"tcpPort":16603,"ftpPort":16602,"syssetFtpPort":16604,"syssetTcpPort":16605,"key":"novaStar","platform":"rk3368","privacy":true,"terminalState":0,"ignoreTime":100029432434,"hasPassword":true,"password":"12345678"}
    * @return_param code int 错误码：<br>`0`搜索成功，result即为搜索返回内容。<br>`65535`搜索超时，代表在4s时间内未能搜索到任何终端
    * @return_param sn string 产品序列号
    * @return_param productName string 产品名称
    * @return_param width int 显示屏宽度, 单位为像素
    * @return_param height int 显示屏高度, 单位为像素
    * @return_param rotation int 旋转角度：0，90，180，270
    * @return_param aliasName string 显示屏别名
    * @return_param logined boolean 是否有人已经登陆
    * @return_param username string_array 若已经有人登陆，代表已经登陆的用户名列表
    * @return_param tcpPort int tcp连接端口
    * @return_param ftpPort int ftp连接端口
    * @return_param syssetFtpPort int 系统设置ftp端口
    * @return_param syssetTcpPort int 系统设置tcp端口
    * @return_param key string 终端返回的key,参与ftp的密码生产规则
    * @return_param platform string 系统平台信息（暂时会出现rk3368, rk312x）
    * @return_param privacy boolean True表示终端支持加密模式，当然如果是新的终端一定是True
    * @return_param password string 密码
    * @return_param terminalState int 当前屏体状态，terminalState共有6个值,分别代表：<br>`0`：未连接任何终端，当前处于未连接状态<br>`1`：连接成功但是未登录状态<br>`2`：被他人登录状态<br>`3`：登录成功状态<br>`4`：密码错误状态<br>`5`：离线状态，处于搜索不到的状态，但是曾经被搜索到过
    * @return_param ignoreTime long 记录点击忽略密码的时间戳
    * @return_param hasPassword boolean 是否记住密码，true表示记住，false，表示没有
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSerchTerminalAsync(ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 从数据库获取所有终端
    * @description 查询所有曾经搜索到的终端信息
    * @url void nvFindAllTerminalsAsync(ExportViplexCallback resultCallBack);
    * @return [{"aliasName":"Taurus-49999787","ftpPort":16602,"hasPassWord":false,"height":1080,"ignoreTime":0,"ip":"172.16.9.205","key":"novaStar","logined":false,"loginedUsernames":[""],"password":"","platform":"rk312x","privacy":true,"productName":"TC300","sn":"BZSA07194A0049999787","syssetFtpPort":16604,"syssetTcpPort":16605,"tcpPort":16603,"terminalState":5,"username":[],"width":1920}]
    * @return_param code int 错误码：<br>`0`获取成功
    * @return_param sn string 产品序列号
    * @return_param productName string 产品名称
    * @return_param width int 显示屏宽度, 单位为像素
    * @return_param height int 显示屏高度, 单位为像素
    * @return_param rotation int 旋转角度：0，90，180，270
    * @return_param aliasName string 显示屏别名
    * @return_param logined boolean 是否有人已经登陆
    * @return_param username string_array 若已经有人登陆，代表已经登陆的用户名列表
    * @return_param tcpPort int tcp连接端口
    * @return_param ftpPort int ftp连接端口
    * @return_param syssetFtpPort int 系统设置ftp端口
    * @return_param syssetTcpPort int 系统设置tcp端口
    * @return_param key string 终端返回的key,参与ftp的密码生产规则
    * @return_param platform string 系统平台信息（暂时会出现rk3368, rk312x）
    * @return_param privacy boolean True表示终端支持加密模式，当然如果是新的终端一定是True
    * @return_param password string 密码
    * @return_param terminalState int 当前屏体状态（数据库中搜索到的一直为5）
    * @return_param ignoreTime long 记录点击忽略密码的时间戳
    * @return_param hasPassword boolean 是否记住密码，true表示记住，false，表示没有
    * @return_param configInfo object 支持模块
    * @return_param installedPackageVersions object 已安装版本信息
    * @return_param productInfo object 设备信息
    * @return_param firmwareInfo object 固件版本信息
    * @return_param screenMosaicInfo object 多屏拼接信息
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvFindAllTerminalsAsync(ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 登录
    * @description 登陆接口和tcp连接是合并在一起的。假如某个时间tcp突然断开了，错误信息会从这个接口返回。
    * @url void nvLoginAsync(const char *data,ExportViplexCallback resultCallBack);
    * @json_param {"sn":"BZSA17332J0A20002272","username":"admin","password":"password","loginType":0,"rememberPwd":0}
    * @param sn 必选 string 产品唯一序列号
    * @param username 必选 string 用户名
    * @param password 必选 string 密码
    * @param loginType 必选 int `0`：登陆到屏体管理<br>`1`：登陆到系统设置（暗门登录）<br>`2`：登陆到诊断模块<br>`3`：LCT登录
    * @param loginType 必选 int 是否记住密码<br>`0`表示No<br>`1`表示Yes
    * @return {"logined":true,"password":"123456","sn":"BZSA17332J0A20002272","username":"admin","validation":true,"validition":true,"loginedUsernames":["admin"],"encrypt":""}
    * @return_param code int 错误码：<br>`0`不代表登录成功，具体看备注<br>`65313`请求参数中SN无效<br>`65300`长连接过程中socket断开，可能是网络原因，也可能是终端断开了socket连接<br>**注意：当错误码code=65300时，data为sn，目的是告诉上位机哪个终端断开了**<br>`65304`执行登录动作时tcp连接失败，一般是因为网络问题（或者ip为空，端口占用等原因）<br>`65353`已经登录过了，请不要再进行二次登录<br>`65351`记住密码登录时，用户名或密码错误，有可能密码被其他人修改了，上位机可根据此错误码让用户重新手动输入密码<br>`16`密码连续错误3次，进入防暴力机制，1min内不允许登录，data返回：<br>{"errorDiscription":"Continuein33seconds.","mRemainTime":33}，mRemainTime代表33s后才可以继续登录
    * @return_param sn string 产品序列号
    * @return_param username string 用户名
    * @return_param password string 密码
    * @return_param validition boolean 用户名和密码是否有效（旧版本遗留字段）
    * @return_param validation boolean 用户名和密码是否有效（新版本增加的字段）
    * @return_param logined boolean 是否成功登陆
    * @return_param loginedUsernames string_array 已经登陆的账户名称,当logined为false，validation为true时，此字段有效
    * @return_param encrypt string 密码的暗码，用于找回密码,当logined为false，validation为falsee时，此字段有效
    * @remark 判断是否登录成功说明：<br>&emsp;&emsp;当返回 code == 0时：<br>`1、`当 logined 为 true,且 validition 也为 true 时，代表登录成功<br>`2、`当 logined 为 false，但 validition 为 true 时，代表终端被其他人登录<br>`3、`当 logined 为 false，且 validition 也为 false 时，代表密码错误<br><br>请重点关注错误码
    * @number 99
    */
    VIPLEX_EXPORT void nvLoginAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 修改密码
    * @description 修改屏体的登录密码
    * @url void nvChangePassWordAsync(const char *data,ExportViplexCallback resultCallBack);
    * @json_param {"sn":"12345787454544","reSetInfo":{"username":"admin","password":"123456","newPassword":"12345678"}}
    * @param sn 必选 string 产品唯一序列号
    * @param username 必选 string 用户名
    * @param password 必选 string 旧密码
    * @param newPassword 必选 string 新密码
    * @return changepassword success
    * @return_param code int 错误码：<br>`0`修改成功
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvChangePassWordAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 删除屏体
    * @description 删除某个屏体
    * @url void nvDelTerminalInfoAsync(const char *data,ExportViplexCallback resultCallBack);
    * @json_param {"sn":"BZSA17332J0A20002272","type":"deleteTerminal"}
    * @param sn 必选 string 产品唯一序列号
    * @param type 必选 string "deleteTerminal"代表此次操作是"删除屏体（终端）"
    * @return Success
    * @return_param code int 错误码：<br>`0`删除成功<br>`65348`删除失败<br>`12`参数type错误，未实现的接口
    * @return_param data string 错误码描述，不用关注
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvDelTerminalInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 屏体信息存储（数据继承）
    * @description 此接口是旧版本屏体数据继承
    * @url void nvSetScreenInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    * @json_param [{"aliasName":"Taurus-10006848","screenMosaicInfo":{"order":456,"videoSource":127},"ftpPort":16602,"hasPassWord":false,"height":400,"ignoreTime":0,"ip":"192.168.1.113","key":"novaStar","logined":false,"password":"","productName":"T6","sn":"BZSA79353N1310006848","syssetFtpPort":16604,"syssetTcpPort":16605,"tcpPort":16603,"terminalState":0,"width":400}]
    * @param sn 必选 string 产品唯一序列号
    * @param productName 可选 string 产品名称
    * @param width 可选 int 显示屏宽度, 单位为像素
    * @param height 可选 int 显示屏高度, 单位为像素
    * @param rotation 可选 int 旋转角度：0，90，180，270
    * @param aliasName 可选 string 显示屏别名
    * @param logined 可选 boolean 是否有人已经登陆
    * @param username 可选 string_array 若已经有人登陆，代表已经登陆的用户名列表
    * @param tcpPort 可选 int tcp连接端口
    * @param ftpPort 可选 int ftp连接端口
    * @param syssetFtpPort 可选 int 系统设置ftp端口
    * @param syssetTcpPort 可选 int 系统设置tcp端口
    * @param key 可选 string 终端返回的key,参与ftp的密码生产规则
    * @param screenMosaicInfo 可选 object 拼接屏信息
    * @param order 可选 int 拼接屏顺序
    * @param videoSource 可选 int 视频源个数
    * @return Success
    * @return_param code int 错误码：<br>`0`存储成功<br>`65347`存储失败
    * @return_param data string 错误码描述，不用关注
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetScreenInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 清除密码
    * @description 清除屏体密码
    * @url void nvDelTerminalInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    * @json_param {"sn":"BZSA17332J0A20002272","type":"clearPassWord"}
    * @param sn 必选 string 产品唯一序列号
    * @param type 必选 string "clearPassWord"代表此次操作是"清除密码"
    * @return Success
    * @return_param code int 错误码：<br>`0`清除成功<br>`65348`删除失败<br>`12`参数type错误，未实现的接口
    * @return_param data string 错误码描述，不用关注
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvDelTerminalInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 获取拼接屏信息
    * @description 获取拼接屏信息
    * @url void nvGetTerminalInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    * @json_param {"sn":"BZSA17332J0A20002272","type":"getSystemInfo"}
    * @param sn 必选 string 产品唯一序列号
    * @param type 必选 string "getSystemInfo"代表此次操作是"获取系统信息"
    * @return {"mosaicWidth":400,"mosaicHeight":400,"mosaicNum":10}
    * @return_param code int 错误码：<br>`0`获取成功<br>`12`参数type错误，未实现的接口
    * @return_param mosaicWidth int 拼接宽度
    * @return_param mosaicHeight int 拼接高度
    * @return_param mosaicNum int 拼接总数
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetTerminalInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 设置弱密码忽略时间
    * @description 设置“点击忽略弱密码选项”的时间戳后，调用“搜索屏体”时返回设置的字段，否则调用“搜索屏体”时返回空字符串。<br>设置此时间戳的目的是在未来某段时间内不再弹出“是否忽略弱密码模态框”。
    * @url void nvSetTerminalInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    * @json_param {"sn":"BZSA17332J0A20002272","type":"setIgnoreTime","value": 123456789012345}
    * @param sn 必选 string 产品唯一序列号
    * @param type 必选 string "getSystemInfo"代表此次操作是"设置弱密码忽略时间"
    * @param value 必选 int 要设置的时间戳（毫秒）,比如：1113259324242
    * @return Success
    * @return_param code int 错误码：<br>`0`设置成功<br>`65347`设置失败<br>`12`参数type错误，未实现的接口
    * @return_param data string 错误码描述，不用关注
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetTerminalInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 设置系统信息
    * @description 设置“系统信息”。设置一些无关sn的配置信息，详见下面参数
    * @url void nvSetSystemInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    * @json_param {"mosaicWidth":400,"mosaicHeight":400,"lang":"cn","demo":true,"userType":"user"}
    * @param mosaicWidth 必选 int 拼接宽度
    * @param mosaicHeight 必选 int 拼接高度
    * @param lang 必选 string 多语言
    * @param demo 必选 bool 是否是demo
    * @param userType 必选 string 用户模式
    * @return Success
    * @return_param code int 错误码：<br>`0`设置成功<br>`65347`设置失败
    * @return_param data string 错误码描述，不用关注
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetSystemInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/搜索连接登录
    * @title 退出登录
    * @description 注意：退出登录后，返回成功或失败，login接口的长连接自动失效，不会再返回数据
    * @url void nvLogoutAsync(const char *data, ExportViplexCallback resultCallBack);
    * @json_param {"sn":"BZSA17332J0A20002272","loginType":0}
    * @param sn 必选 string 产品唯一序列号
    * @param loginType 必选 int `0：`断开屏体管理<br>`1：`断开系统设置（暗门）<br>`2：`断开诊断模块<br>`3：`断开LCT登录
    * @return disconnetSuccess
    * @return_param code int 错误码：<br>`0`退出成功
    * @return_param data string 错误码描述，不用关注
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvLogoutAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
  * showdoc
  * @catalog 接口示例/屏体其他项
  * @title 固件版本信息
  * @description 获取固件版本信息接口，所有版本的终端均有此接口，返回终端的版本信息。<br>**1.2.2 版本碰到缺少 mac 字段**
  * @url void nvGetFirmwareInfosAsync(const char *data, ExportViplexCallback resultCallBack);
  * @json_param {"sn":"BZSA17332J0A20002272"}
  * @param sn 必选 string 产品唯一序列号
  * @return {"fpga":"1.0.0.1","model":"AX100V010002CN0501","mainVersion":"1.0.1","productName":"T3","aliasName":"easy-PHOJ05447J0330015353","registerAddress":"西安软件园","mac":"30:5A:3A:04:62:C3"}
  * @return_param code int 错误码：<br>`0`获取成功<br>`65535`接口超时
  * @return_param fpga string FPGA版本
  * @return_param model string 系统版本
  * @return_param mainVersion string 终端软件主版本
  * @return_param productName string 产品名称
  * @return_param aliasName string 屏体别名
  * @return_param registerAddress string 屏体地址
  * @return_param mac string 屏体mac地址
  * @remark
  * @number 99
  */
    VIPLEX_EXPORT void nvGetFirmwareInfosAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
  * showdoc
  * @catalog 接口示例/屏体其他项
  * @title 已安装的软件版本信息
  * @description 获取终端已经安装的软件版本信息
  * @url void nvGetInstalledPackageVersionsAsync(const char *data, ExportViplexCallback resultCallBack);
  * @json_param {"sn":"BZSA17332J0A20002272","packageInfo":{"packageName":["nova.priv.terminal.syssetting","nova.priv.terminal.easypluto"]}}
  * @param sn 必选 string 产品唯一序列号
  * @param packageInfo 必选 object
  * @param packageName 必选 string_array 软件包名数组
  * @return {"result":[{"packageName":"nova.priv.terminal.syssetting","versionName":"1.0.2.0501","versionCode":102},{"packageName":"nova.priv.terminal.easypluto","versionName":"1.0.2.0502","versionCode":102}]}
  * @return_param code int 错误码：<br>`0`获取成功<br>`65535`接口超时
  * @return_param packageName string 包名
  * @return_param versionName string 版本名称
  * @return_param int string 版本号
  * @remark
  * @number 99
  */
    VIPLEX_EXPORT void nvGetInstalledPackageVersionsAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/屏体其他项
    * @title 设备信息
    * @description 获取终端设备信息
    * @url void nvGetProductInfo Async(const char *data, ExportViplexCallback resultCallBack);
    * @json_param {"sn":"BZSA17332J0A20002272"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"productInfo":{"productName":"","modelId":10043},"configInfo":{"videoSwitch":false,"displayDevice":"LED","portConfig":[{"portNO":1,"isMainPort":true,"belongMainPort":0},{"portNO":2,"isMainPort":true,"belongMainPort":0}]}}
    * @return_param code int 错误码：<br>`0`获取成功<br>`65535`接口超时
    * @return_param productInfo object 产品信息
    * @return_param productName string 产品名称，例如T3,T6
    * @return_param modelId int 产品编号
    * @return_param configInfo object 配置信息
    * @return_param videoSwitch bool 是否支持视频切换，true表示支持，false表示不支持
    * @return_param displayDevice string 显示设备，有两种LED、LCD
    * @return_param portConfig object_array 网口配置
    * @return_param portNO int 网口编号，例如 1,2,3,4
    * @return_param isMainPort bool 是否为主网口
    * @return_param belongMainPort int 对应的主网口，如果该网口是主网口，该字段无效
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetProductInfoAsync(const char *data, ExportViplexCallback resultCallBack);
    /**
    * showdoc
    * @catalog 接口示例/屏体其他项
    * @title 支持的模块信息
    * @description **注意：获取支持的模块信息时首先要调用“获取固件版本信息”接口得到版本号,不然没有版本号无法获取支持的模块信息。<br>字段说明以showdoc为准**
    * @url void nvGetconfiguration Async(const char *data, ExportViplexCallback resultCallBack);
    * @json_param {"sn":"BZSA17332J0A20002272"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"config_info":{"REBOOT":true,"SCREENPOWER":true,"SYNC_PLAY":true,"SPOTS":true,"VIDEO_SOURCE_SWITCH":true,"UPDATE":true,"SCREENSHOT":true,"TIMEZONE":true,"POWER":true,"VOICE":true,"LIGHT":true,"UPDATEOS":true,"CARE":true,"VNNOX":true,"PLAYLOG":true,"COLORTEMPERATURE":true,"INDICATORLIGHT":true,"NEXUSFONT":true,"TERMINALINFO":true,"NEWPROTOCOL":true,"RELAYPOWER":true,"RELAYPOWERCONFIG":true,"FIXEDPOINT":true,"RESET":true,"Brightness":{"Validity":true,"CompleteCron":true,"FloatValue":true},"WIFI":true,"CustomResolution":true,"NetWork":{"IsSupport":true,"Wifi":true,"Wired":true,"AP":true,"Mobile":true,"IsSupportNetWorkCheck":true,"WiFiApSwitch":false},"VideoSource":{"IsSupport":true,"Hdmi":true,"Input":{"IsSupport":true,"Hdmi":true},"Output":{"IsSupport":true,"HdmiToLvds":true}},"RadioFrequencyManage":{"IsSupport":true,"IsSupportLoraInfo":true,"IsSupportProduct":true},"Upgrade":{"IsSupportCheckValid":true},"SourceOutMode":{"IsSupportChangeSourceOutMode":true},"ZipRunningLog":{"IsSupportZipRunningLogInfo":true},"ReceiveCard":{"IsSupport":true,"Config":true,"Temperature":true},"ScreenConfig":{"IsSupport":true,"Config":true,"ScreenJoint":true,"IsSupportProduct":true},"Monitoring":{"IsSupport":true,"ClearMedia":true,"Memory":true,"CPU":true,"AmbientBrightness":true},"TimeControl":{"IsSupport":true,"Manual":true,"NTP":true,"Lora":true,"DayLightOffset":false},"Resolution":{"IsSupport":true,"CustomResolution":true},"SensorBoard":{"IsSupport":true,"SensorInfo":true,"IsSupportProduct":true},"Rotation":{"IsSupport":false,"IsSupportProduct":false},"PlayManager":{"IsSupport":true,"ProgramListManager":true},"InfraredDetector":{"IsSupport":true,"IsSupportProduct":true}}}
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetconfigurationAsync(const char *data, ExportViplexCallback resultCallBack);
#pragma endregion Login 搜索连接登录

#pragma region ScreenBrightness
    /**
    * showdoc
    * @catalog 接口示例/显示屏亮度&环境亮度/模式切换
    * @title 设置模式
    * @description 设置模式的接口
    * @method
    * @url void nvSetBrightnessAdjustMode(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"","brightnessAdjustModeInfo":{"mode":"MANUALLY"}}
    * @param sn 必选 string 产品唯一序列号
    * @param brightnessAdjustModeInfo 必选 Object 请求信息对象
    * @param mode 必选 string MANUALLY表示手动设置,AUTO表示自动
    * @return ""
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetBrightnessAdjustModeAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/显示屏亮度&环境亮度/模式切换
    * @title 获取模式
    * @description 获取模式的接口
    * @method
    * @url void nvGetBrightnessAdjustMode(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"mode":"MANUALLY ","source":{"platform":1,"type":1},"type":"SCREEN_BRIGHTNESS"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @return_param type String 表示类型，当为开关屏时为SCREENPOWER, 当为亮度模块时为 SCREEN_BRIGHTNESS
    * @return_param source object 表示任务的发布来源,我们现在终端的节目可以来自不同的来源。如PC、移动终端、云服务等
    * @return_param type number 1：nova自己的平台,0：第三方平台
    * @return_param platform number 表示任务的发布来源，我们现在终端的节目可以来自不同的来源。如PC、移动终端、云服务等
    * @return_param mode String MANUALLY表示手动设置,AUTO:表示自动
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetBrightnessAdjustModeAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/显示屏亮度&环境亮度/手动控制亮度
    * @title 手动设置亮度
    * @description 手动设置亮度的接口
    * @method
    * @url void nvSetScreenBrightness(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZWA17422J1X20000093","screenBrightnessInfo":{"ratio":45.0}}
    * @param sn 必选 string 产品唯一序列号
    * @param screenBrightnessInfo 必选 Object 请求信息对象
    * @param ratio 必选 float 显示屏亮度的值 百分比(0到100)
    * @return ""
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetScreenBrightnessAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/显示屏亮度&环境亮度/手动控制亮度
    * @title 手动获取亮度
    * @description 手动获取亮度的接口
    * @method
    * @url void nvGetScreenBrightness(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"ratio":45.0,"source":{"type":1,"platform":1}}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回data详情
    * @return_param ratio float 显示屏亮度的值 百分比（0到100）
    * @return_param source Object 表示任务的发布来源，我们现在终端的节目可以来自不同的来源。如PC、移动终端、云服务等。
    * @return_param type int 1：nova自己的平台, 0：第三方平台。
    * @return_param platform int 1：移动终端发来的（如手机），2：表示传统电脑，3：表示平板，4：表示vnnox端发来的。5:来自iCare
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetScreenBrightnessAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/显示屏亮度&环境亮度/定时或自动亮度调节
    * @title 获取亮度调节方案
    * @description 获取亮度调节方案的接口
    * @method
    * @url void nvGetBrightnessPolicy(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"","brightnessPolicyInfo":{"isSupportCompleteCron":false}}
    * @param sn 必选 string 产品唯一序列号
    * @param brightnessPolicyInfo 必选 Object 请求信息对象
    * @param isSupportCompleteCron 非必选 bool 是否支持完整cron表达式调节及有效期，不传此参数，默认为false
    * @return {"enable":true,"source":{"platform":1,"type":1},"conditions":[{"opticalFailureInfo":{"enable":true,"screenBrightness":30},"enable":true,"crons":["0 15 10 ? ** *"],"startTime":"2017-09-01 00:00 : 00","endTime":"4016-06-06 23:59:59","segments":[{"screenBrightness":80,"environmentBrightness":12000},{"screenBrightness":60,"environmentBrightness":10000}],"type":2,"args":[12000,20,80,40,10]},{"opticalFailureInfo":{"enable":true,"screenBrightness":30},"enable":true,"crons":["0 15 10 ? **"],"startTime":"2017-09-01 00:00:00","endTime":"4016-06-06 23:59:59","segments":[],"type":1,"args":[30]}],"type":"BRIGHTNESS","segmentConfig":{"opticalFailureInfo":{"enable":true,"screenBrightness":30},"segments":[{"screenBrightness":80,"environmentBrightness":12000},{"screenBrightness":60,"environmentBrightness":10000}],"args":[12000,20,80,40,10]},"timeStamp":"2018-07-19 11:27:15"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回参数
    * @return_param type string 固定为"BRIGHTNESS"
    * @return_param source object 表示任务的发布来源,我们现在终端的节目可以来自不同的来源,如PC、移动终端、云服务等
    * @return_param type number 1：nova自己的平台,0：第三方平台
    * @return_param platform number 1：移动终端发来的(如手机)，2：表示传统电脑，3：表示平板，4：表示web端发来的。
    * @return_param enable boolean 使能开关， 当为true表示所有有效
    * @return_param conditions object 按照条件执行的条件集合，我们支持多个条件触发。
    * @return_param type number 调节类型，1：定时调节，2：自动调节
    * @return_param cron array 重复次数，每条条件使用cron表达式数组表示，当为数组时，cron表达式之间使用或的关系
    * @return_param startTime string 策略有效期开始时间yyyy-MM-dd HH:mm:ss
    * @return_param endTime string 策略有效期结束时间yyyy-MM-dd HH:mm:ss ，永久有效的时间为4016-06-06 23:59:59
    * @return_param args object 亮度调节参数，定时调试时args只有一个值为亮度百分比,自动调节时args含有5个值,分别为最大环境亮度,最小环境亮度,最大屏体亮度,最小屏体亮度, 分段数
    * @return_param segments object 亮度调节参数的分段详细设置
    * @return_param environmentBrightness number 环境亮度值
    * @return_param screenBrightness number 对应环境亮度所要调节的屏体亮度值
    * @return_param opticalFailureInfo object 自动亮度调节时，获取环境亮度失败，是否调到固定值的选项，该字段只对自动亮度调节有效。
    * @return_param enable boolean 自动亮度调节时，获取环境亮度失败，是否调到固定值
    * @return_param screenBrightness number 需要调节到的固定亮度值
    * @return_param enable boolean 该条方案的使能开关
    * @return_param segmentConfig object 根据环境亮度配置的分段表数据segmentsConfig字段，内部字段参见自动亮度调节的参数说明
    * @return_param timeStamp string 当前数据的时间戳，为后期可能使用
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetBrightnessPolicyAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/显示屏亮度&环境亮度/定时或自动亮度调节
    * @title 设置亮度调节方案
    * @description 1.终端版本大于等于1.3.1 ：支持starttime，endtime，args中最大屏体亮度，最小屏体亮度支持浮点型。screenBrightness支持浮点型。终端版本小于1.3.1 不支持starttime、endtime以及屏体亮度支持浮点型。当下发定时任务时，args仅有一个参数，代表亮度 大于等于1.3.1 时类型为浮点型，小于1.3.1时为整型 。2.是否支持浮点型根据支持的模块判断是否是浮点型,支持：args中最大屏体亮度，最小屏体亮度支持浮点型。screenBrightness支持浮点型。不支持 :args中最大屏体亮度，最小屏体亮度，screenBrightness只能为int类型。
    * @method
    * @url void nvSetBrightnessPolicy(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"","taskInfo":{"type":"BRIGHTNESS","source":{"type":0,"platform":1},"enable":true,"conditions":[{"type":2,"cron":["0 15 10 ? ** *"],"args":[12000,20,80,40,10],"startTime":"2017-09-01 00:00 : 00","endTime":"4016-06-06 23:59:59","enable":true},{"type":1,"cron":["0 15 10 ? **"],"startTime":"2017-09-01 00:00:00","endTime":"4016-06-06 23:59:59","args":[30],"enable":true}],"segmentConfig":{"args":[12000,20,80,40,10],"segments":[{"environmentBrightness":12000,"screenBrightness":80},{"environmentBrightness":10000,"screenBrightness":60}],"opticalFailureInfo":{"enable":true,"screenBrightness":30}},"timeStamp":"2018-07-19 11:27:15"}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 请求信息对象
    * @param type 必选 string 固定为"BRIGHTNESS"
    * @param source 必选 object 表示任务的发布来源，我们现在终端的节目可以来自不同的来源。如PC、移动终端、云服务等
    * @param type 必选 number 1：nova自己的平台, 0：第三方平台
    * @param platform 必选 number 1：移动终端发来的(如手机)，2：表示传统电脑，3：表示平板，4：表示web端发来的
    * @param enable 必选 boolean 使能开关
    * @param conditions 必选 object 按照条件执行的条件集合，我们支持多个条件触发
    * @param type 必选 number 调节类型，1：定时调节，2：自动调节
    * @param cron 必选 array 重复次数，每条条件使用cron表达式数组表示，当为数组时，cron表达式之间使用或的关系 (cron详细格式见附件)
    * @param args 必选 array 亮度调节参数，定时调试时args只有一个值为亮度百分比，自动调节时args含有5个值，分别为最大环境亮度，最小环境亮度，最大屏体亮度，最小屏体亮度，分段数
    * @param startTime 必选 string 策略有效期开始时间yyyy-MM-dd HH:mm:ss(1.3.1以下没有此字段)
    * @param endTime 必选 string 策略有效期结束时间yyyy-MM-dd HH:mm:ss,永久有效的时间为4016-06-0623:59:59(1.3.1以下没有此字段)
    * @param segments 非必选 object 亮度调节参数的分段详细设置,(1.3.1以下在每条定时任务里面,>=1.3.1和定时列表平级)
    * @param environmentBrightness 非必选 int 环境亮度值
    * @param screenBrightness 非必选 number 对应环境亮度所要调节的屏体亮度值
    * @param opticalFailureInfo 非必选 object 自动亮度调节时,获取环境亮度失败,是否调到固定值的选项,该字段只对自动亮度调节有效
    * @param enable 必选 boolean 自动亮度调节时,获取环境亮度失败,是否调到固定值
    * @param screenBrightness 非必选 number 需要调节到的固定亮度值
    * @param enable 必选 boolean 该条方案的使能开关
    * @param segmentConfig 非必选 object 根据环境亮度配置的分段表数据,内部字段参见自动亮度调节的参数说明
    * @param timeStamp 必选 string 当前数据的时间戳,为后期可能使用
    * @return ""
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetBrightnessPolicyAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/显示屏亮度&环境亮度/环境亮度
    * @title 获取环境亮度
    * @description 获取环境亮度的接口
    * @method
    * @url void getEnvironmentBrightness(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"value":1000}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @return_param value int 环境亮度的值,单位LUX
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetEnvironmentBrightnessAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion LightController 显示屏亮度&环境亮度

#pragma region TemperatureController
    /**
    * showdoc
    * @catalog 接口示例/温度&色温/色温
    * @title 获取色温
    * @description 获取色温的接口
    * @method
    * @url void nvGetColorTemperature(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"colorTemperature":9300}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param colorTemperature int 色温值
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetColorTemperatureAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/温度&色温/色温
    * @title 设置色温
    * @description 当前终端无法做较为准确的色温设置，所以选定了3种色温，分别为9300、6500、4700，故回读亦是如此
    * @method
    * @url void nvSetColorTemperature(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZSA17332J0A20002272","colorTemperatureInfo":{"colorTemperature":6500}}
    * @param sn 必选 string 产品唯一序列号
    * @param colorTemperatureInfo 必选 Object 色温详情
    * @param colorTemperature 必选 int 色温值
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetColorTemperatureAsync(const char *data, ExportViplexCallback callback);
#pragma endregion TemperatureController 温度&色温 待补充 （获取箱体温度）

#pragma region SwitchController
    /**
    * showdoc
    * @catalog 接口示例/开关屏管理/模式切换
    * @title 设置模式
    * @description 设置模式的接口
    * @method
    * @url void nvSetScreenPowerMode(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"","taskInfo":{"mode":"MANUALLY"}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 详情
    * @param mode 必选 string MANUALLY 表示手动设置,AUTO：表示自动
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetScreenPowerModeAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/开关屏管理/模式切换
    * @title 获取模式
    * @description 获取模式的接口
    * @method
    * @url void nvGetScreenPowerMode(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"mode":"MANUALLY","source":{"platform":1,"type":1},"type":"SCREENPOWER"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param type String 表示类型，当为开关屏时为SCREENPOWER, 当为亮度模块时为 SCREEN_BRIGHTNESS
    * @return_param source object 详情参照附录定义
    * @return_param type number 1：nova自己的平台,0：第三方平台。
    * @return_param platform number 1：移动终端发来的（如手机），2：表示传统电脑，3：表示平板，4：表示web端发来的。
    * @return_param mode String MANUALLY表示手动设置,AUTO：表示自动
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetScreenPowerModeAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/开关屏管理/手动开关屏
    * @title 设置手动开关屏状态
    * @description 设置手动开关屏状态的接口
    * @method
    * @url void nvSetScreenPowerState(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"","taskInfo":{"state":"open"}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 详情
    * @param state 必选 string 显示屏开关状态,"OPEN":开,"CLOSE":关
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetScreenPowerStateAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/开关屏管理/手动开关屏
    * @title 获取手动开关屏状态
    * @description 获取手动开关屏状态的接口
    * @method
    * @url void nvGetScreenPowerState(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"state":"UNKNOW"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param state string 显示屏开关状态，"OPEN":开，"CLOSE":关
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetScreenPowerStateAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/开关屏管理/定时开关屏
    * @title 获取定时开关屏
    * @description 获取定时开关屏的接口
    * @method
    * @url void nvGetScreenPowerPolicy(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"type":"SCREENPOWER","source":{"type":0,"platform":1},"enable":true,"conditions":[{"cron":["0 15 10 ? * *","0 0 12 * * ?"],"action":"OPEN","enable":true},{"cron":["0 15 10 ? * *","0 0 12 * * ?"],"action":"CLOSE","enable":true}]}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param type string 固定为"SCREENPOWER"
    * @return_param source object 表示任务的发布来源，我们现在终端的节目可以来自不同的来源。如PC、移动终端、云服务等。
    * @return_param type number 1：nova自己的平台,0：第三方平台。
    * @return_param platform number 1：移动终端发来的（如手机），2：表示传统电脑，3：表示平板，4：表示web端发来的。
    * @return_param enable boolean 按条件执行的使能开关
    * @return_param conditions object 按照条件执行的任务集合，我们支持多个任务。
    * @return_param cron (string)array 重复次数，每条条件使用cron表达式数组表示，当为数组时，cron表达式之间使用或的关系
    * @return_param action String "OPEN":开， "CLOSE":关
    * @return_param enable boolean 该条件执行的使能开关
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetScreenPowerPolicyAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/开关屏管理/定时开关屏
    * @title 设置开关屏状态
    * @description 设置开关屏状态的接口
    * @method
    * @url void nvSetScreenPowerPolicy(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZWA17422J1X20000093","taskInfo":{"type":"SCREENPOWER","source":{"type":0,"platform":1},"enable":true,"conditions":[{"cron":["0 15 10 ? * *","0 0 12 * * ?"],"action":"OPEN","enable":true}]}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 详情
    * @param type 必选 string 固定为"SCREENPOWER"
    * @param source 非必选 object 表示任务的发布来源，我们现在终端的节目可以来自不同的来源。如PC、移动终端、云服务等。
    * @param type 非必选 number 1：nova自己的平台, 0：第三方平台。
    * @param platform 非必选 number 1：移动终端发来的(如手机)，2：表示传统电脑，3：表示平板，4：表示web端发来的。
    * @param enable 必选 boolean 按条件执行的使能开关
    * @param conditions 必选 object 按照条件执行的任务集合，我们支持多个任务。
    * @param cron 必选 (string)array 重复次数，每条条件使用cron表达式数组表示，当为数组时，cron表达式之间使用或的关系
    * @param action 必选 String "OPEN":开， "CLOSE":关
    * @param enable 必选 boolean 该条件执行的使能开关
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetScreenPowerPolicyAsync(const char *data, ExportViplexCallback callback);
#pragma endregion SwitchController 开关屏管理

#pragma region FileManager
#pragma endregion FileManager 系统文件管理 待开发

#pragma region ListManager
    /**
   * showdoc
   * @catalog 接口示例/清单管理
   * @title 清单回读
   * @description 获取节目清单的接口
   * @method
   * @url void nvGetProgramInfo(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272"}
   * @param sn 必选 string 产品唯一序列号
   * @return {"programInfos":[{"identifier":"62932662fb727f42d695201aa91e32c8","name":"PlayLists1","thumbnailUrl":"program_868679025220684_1/program_thumb.png","statusCode":1,"source":0},{"identifier":"62932662fb727f42d695201aa91e32c8","name":"PlayLists2","thumbnailUrl":"program_868679025220684_2/program_thumb.png","statusCode":1,"source":1}]}
   * @return_param name string 播放清单的名称
   * @return_param thumbnailUrl string 播放清单缩略图绝对路径
   * @return_param statusCode int 	清单播放状态(`0`表示停止播放;`1`表示正在播放;`2`表示暂停播放)
   * @return_param identifier string 播放方案的唯一标识，这里指的是内容上的，内容相同，则播放方案标识一样，目前存放planList 的md5码
   * @return_param source int 清单的来源(`0`表示局域网发送的节目；`1`表示Vnnox发送的节目;)
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetProgramInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
   * showdoc
   * @catalog 接口示例/清单管理
   * @title 清单删除
   * @description 删除节目清单的接口
   * @method
   * @url void nvDeletePlayList(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272","taskInfo":{"solutions":[{"name":"program1","identifier":"ccdc78e192d8d97bfd01c82881038a39"}]}}
   * @param sn 必选 string 产品唯一序列号
   * @param identifier 必选 string 播放方案的唯一标识
   * @param name 必选 string 播放清单的名称
   * @return ""
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvDeletePlayListAsync(const char *data, ExportViplexCallback callBack);
    /**
   * showdoc
   * @catalog 接口示例/清单管理
   * @title 清单播放
   * @description 获取节目清单的接口
   * @method
   * @url void nvStartPlay(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272","identifier":"62932662fb727f42d695201aa91e32c8"}
   * @param sn 必选 string 产品唯一序列号
   * @param identifier 必选 string 播放方案的唯一标识
   * @return ""
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvStartPlayAsync(const char *data, ExportViplexCallback callBack);
    /**
   * showdoc
   * @catalog 接口示例/清单管理
   * @title 清单暂停播放
   * @description 暂停节目播放的接口
   * @method
   * @url void nvPausePlay(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272","identifier":"62932662fb727f42d695201aa91e32c8"}
   * @param sn 必选 string 产品唯一序列号
   * @param identifier 必选 string 播放方案的唯一标识
   * @return ""
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvPausePlayAsync(const char *data, ExportViplexCallback callBack);
    /**
   * showdoc
   * @catalog 接口示例/清单管理
   * @title 清单恢复播放
   * @description 恢复节目播放的接口
   * @method
   * @url void nvResumePlay(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272","identifier":"62932662fb727f42d695201aa91e32c8"}
   * @param sn 必选 string 产品唯一序列号
   * @param identifier 必选 string 播放方案的唯一标识
   * @return ""
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvResumePlayAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion ListManager 清单管理 

#pragma region AdvancedFeatures
    /**
    * showdoc
    * @catalog 接口示例/高级特性
    * @title 设置同步播放开关
    * @description 设置同步播放开关的接口
    * @method
    * @url void setSyncPlay(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA17332J0A20002272","enable":true}
    * @param sn 必选 string 产品唯一序列号
    * @param enable 必选 bool 开启关闭同步播放
	* @return "success"
    * @return_param code int 错误码:`0`获取成功`65535`请求超时
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetSyncPlayAsync(const char *data, ExportViplexCallback callBack);

    /**
    * showdoc
    * @catalog 接口示例/高级特性
    * @title 获取同步播放配置
    * @description 获取同步播放配置
    * @method
    * @url void getSyncPlay(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA17332J0A20002272"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"data":{{"enable":false}}}
    * @return_param code int 错误码：0 获取成功，65535 请求超时
    * @return_param enable bool 终端是否开启同步播放
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetSyncPlayAsync(const char *data, ExportViplexCallback callBack);

    /**
    * showdoc
    * @catalog 接口示例/高级特性
    * @title 恢复出厂设置
    * @description 恢复出厂设置
    * @method
    * @url void setReBootWipeUserData(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA17332J0A20002272","setInfo":{"reason":"terminal connect failed"}}
    * @param sn 必选 string 产品唯一序列号
    * @param reason 必选 string 恢复出厂设置的原因
	* @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetReBootWipeUserDataAsync(const char *data, ExportViplexCallback callBack);

    /**
    * showdoc
    * @catalog 接口示例/高级特性
    * @title 清除所有媒体
    * @description 清除所有媒体
    * @method
    * @url void clearAllMedias(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA17332J0A20002272"}
    * @param sn 必选 string 产品唯一序列号
	* @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvClearAllMediasAsync(const char *data, ExportViplexCallback callBack);

    /**
    * showdoc
    * @catalog 接口示例/高级特性
    * @title OTG USB 状态获取
    * @description OTG USB 状态获取
    * @method
    * @url void getOTGUSBMode(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA17332J0A20002272"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"value":1.0}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param value double USB是否可用，1表示USB不可用，2表示USB可用，adb可调式
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetOTGUSBModeAsync(const char *data, ExportViplexCallback callBack);

    /**
    * showdoc
    * @catalog 接口示例/高级特性
    * @title OTG USB 状态设置
    * @description OTG USB 状态设置
    * @method
    * @url void setOTGUSBMode(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA17332J0A20002272","modeInfo":{"value":2.0}}
    * @param sn 必选 string 产品唯一序列号
    * @param value 必选 double USB是否可用，1表示USB不可用，2表示USB可用，adb可调式
    * @return "success"
	* @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetOTGUSBModeAsync(const char *data, ExportViplexCallback callBack);

    /**
   * showdoc
   * @catalog 接口示例/高级特性
   * @title 设置当前分辨率
   * @description 设置当前分辨率
   * @method
   * @url void setCurrentResolution(const char *data, ExportViplexCallback callBack)
   * @json_param {"sn":"BZSA17332J0A20002272","resolutionInfo":{"displayMode":1,"resolutionValue":"1280X720p-60"}}
   * @param sn 必选 string 产品唯一序列号
   * @param displayMode必选 int 显示模式，默认 DISPLAY_INTERFACE_TV(1)
   * @param resolutionValue 必选 string 分辨率的值
   * @return "success"
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvSetCurrentResolutioAsync(const char *data, ExportViplexCallback callBack);

    /**
   * showdoc
   * @catalog 接口示例/高级特性
   * @title 获取当前分辨率
   * @description 获取当前分辨率
   * @method
   * @url void getCurrentResolution(const char *data, ExportViplexCallback callBack)
   * @json_param {"sn":"BZSA17332J0A20002272"，"requestInfo":{"displayMode":1}}
   * @param sn 必选 string 产品唯一序列号
   * @param displayMode 必选 int 显示模式
   * @return {"value":"960x2048p-60"}
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @return_param value string 分辨率的值
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetCurrentResolutionAsync(const char *data, ExportViplexCallback callBack);

    /**
      * showdoc
      * @catalog 接口示例/高级特性
      * @title 获取终端所支持的分辨率
      * @description 获取终端所支持的分辨率
      * @method
      * @url void getSupportedResolution(const char *data, ExportViplexCallback callBack)
      * @json_param {"sn":"BZSA17332J0A20002272"，"requestInfo":{"displayMode":1}}
      * @param sn 必选 string 产品唯一序列号
      * @param displayMode 必选 int 显示模式
      * @return {"result":[{"value":"2048x256p-60"},{"value":"4096x512p-60"}]}
      * @return_param code int 错误码：`0`获取成功`65535`请求超时
      * @return_param value string 分辨率的值
      * @remark
      * @number 99
      */
    VIPLEX_EXPORT void nvGetSupportedResolutionAsync(const char *data, ExportViplexCallback callBack);

    /**
   * showdoc
   * @catalog 接口示例/高级特性/重启
   * @title 获取重启任务
   * @description 获取已经设置的重启任务的接口
   * @method
   * @url void nvGetReBootTaskAsync(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272"}
   * @param sn 必选 string 产品唯一序列号
   * @return {"conditions":[{"cron":["0 15 10 ? * *","0 0 12 * * ?"],"enable":true}],"executionType":"BY_CONDITIONS","reason":"Just to test","source":{"platform":1,"type":0},"type":"REBOOT"}
   * @return_param cron stringarray 每条条件使用cron表达式数组表示，当为数组时，cron表达式之间使用或的关系
   * @return_param enable bool 该条件是否启用
   * @return_param executionType string `IMMEDIATELY`立即执行;`BY_CONDITIONS`按照条件执行
   * @return_param reason string 重启的原因
   * @return_param platform int `1`移动终端发来的(如手机),`2`表示传统电脑，`3`表示平板，`4`表示web端发来的
   * @return_param type int `1`nova自己的平台,`0`第三方平台
   * @return_param type string 固定为"REBOOT"
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetReBootTaskAsync(const char *data, ExportViplexCallback callBack);
    /**
   * showdoc
   * @catalog 接口示例/高级特性/重启
   * @title 设置重启任务
   * @description 设置重启的接口
   * @method
   * @url void void nvSetReBootTask(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA07194A0049999716","taskInfo":{"type":"REBOOT","source":{"type":0,"platform":1},"executionType":"IMMEDIATELY","reason":"Just to test","conditions":[{"cron":["0 15 10 ? * *","0 0 12 * * ?"],"enable":true}]}}
   * @param sn 必选 string 产品唯一序列号
   * @param cron 必选 stringarray 每条条件使用cron表达式数组表示，当为数组时，cron表达式之间使用或的关系
   * @param enable 必选  该条件是否启用
   * @param executionType 必选 string `IMMEDIATELY`立即执行;`BY_CONDITIONS`按照条件执行
   * @param reason 必选 string 重启的原因
   * @param platform 必选 int `1`移动终端发来的(如手机),`2`表示传统电脑，`3`表示平板，`4`表示web端发来的
   * @param type 必选 int `1`nova自己的平台,`0`第三方平台
   * @param type 必选 string 固定为"REBOOT"
   * @return ""
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvSetReBootTaskAsync(const char *data, ExportViplexCallback callBack);

	/**
	* showdoc
	* @catalog 接口示例/高级特性
	* @title 获取终端的输出状态
	* @description 获取终端的输出状态
	* @method
	* @url void getHdmiOutputStatus(const char *data, ExportViplexCallback callBack)
	* @json_param {"sn":"BZSA17332J0A20002272"}
	* @param sn 必选 string 产品唯一序列号
	* @return {"value":1}
	* @return_param code int 错误码：0 获取成功，65535 请求超时
	* @return_param value int 1表示当前是HDMI，0表示RGB
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvGetHdmiOutputStatusAsync(const char *data, ExportViplexCallback callBack);

	/**
	* showdoc
	* @catalog 接口示例/高级特性
	* @title 设置终端的输出状态
	* @description 设置终端的输出状态
	* @method
	* @url void setHdmiOutputStatus(const char *data, ExportViplexCallback callBack)
	* @json_param {"sn":"BZSA17332J0A20002272","info":{"value":1}}
	* @param sn 必选 string 产品唯一序列号
	* @param value 必选 int 1表示当前是HDMI，0表示RGB
	* @return "sccuss"
	* @return_param code int 错误码：0 获取成功，65535 请求超时
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvSetHdmiOutputStatusAsync(const char *data, ExportViplexCallback callBack);

	/**
	* showdoc
	* @catalog 接口示例/高级特性
	* @title 设置自定义分辨率
	* @description 设置自定义分辨率
	* @method
	* @url void setCustomResolution(const char *data, ExportViplexCallback callBack)
	* @json_param {"sn":"BZSA17332J0A20002272","info":{"displayMode":1,"width":1920,"height":1080}}
	* @param sn 必选 string 产品唯一序列号
	* @param displayMode 必选 int 显示模式
	* @param width 必选 int 显示宽度
	* @param height 必选 int 显示高度
	* @return "sccuss"
	* @return_param code int 错误码：0 获取成功，65535 请求超时
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvSetCustomResolutionAsync(const char *data, ExportViplexCallback callBack);

#pragma endregion AdvancedFeatures 高级特性 

#pragma region AcquisitionReceiver
    /**
    * showdoc
    * @catalog 接口示例/采集器接收器
    * @title 获取采集接收器配置
    * @description 获取采集接收器配置的接口
    * @method
    * @url void nvGetPickerReceiver(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZWA17422J1X20000093"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"pickers":[{"period":1000,"pickType":"PERIOD","receivers":[{"outputDestination":"TCP_NET_WORK","persistent":false}],"type":"CPU_USAGE"}]}
    * @return_param code int 错误码：`0`获取成功
    * @return_param pickers objectArray 采集器列表
    * @return_param period long 采集周期，单位为毫秒，当为周期性采集时才有效
    * @return_param pickType string PERIOD：表示的是周期性采集，AUTO：表示的是自动的，根据这种类型的具体实现。
    * @return_param receivers object 关联的接收器
    * @return_param outputDestination string FILE：表示采集到文件，TCP_NET_WORK：表示的是自动的，根据这种类型的具体实现，CONSOLE：控制台，如终端的控制台，一般用户调试
    * @return_param persistent bool true：表示持久的，即当断电，上电依然有效，false：表示只添加到内存的
    * @return_param type string CPU_USAGE：cpu使用率，CPU_TERMPATURE：cpu温度，MEMORY_USAGE：内存使用率，WIFI_STATE_CHANGED：wifi状态变化
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetPickerReceiverAsync(const char *data, ExportViplexCallback callBack);

	/**
	* showdoc
	* @catalog 接口示例/采集器接收器
	* @title 添加采集接收器
	* @description 添加采集接收器
	* @method
	* @url void nvAddCollectorAsync(const char *data, ExportViplexCallback callBack);
	* @json_param {"sn":"BZSA07194A0049999716","info":{"pickers":[{"type":"CPU_USAGE", "pickType":"PERIOD","period":1000,"receivers":[{"outputDestination":"TCP_NET_WORK","persistent":false}]}]}}
	* @param sn 必选 string 产品唯一序列号
	* @param info 必选 object 采集器数据实体
	* @param pickers 必选 object 采集器数据列表
	* @param type 必选 enum 采集器类型
	* @param pickType 必选 enum PERIOD or AUTO
	* @param period 必选 long 采集周期
	* @param receivers 必选 object 关联的接收器
	* @param outputDestination 必选 enum 采集输出路径包括文件、网络和控制台
	* @param persistent 必选 bool 表示是否持久
	* @return "sccuss"
	* @return_param code int 错误码:`0`获取成功`65535`请求超时
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvAddCollectorAsync(const char *data, ViplexCallback callBack);

	/**
	* showdoc
	* @catalog 接口示例/采集器接收器
	* @title 删除采集接收器
	* @description 删除采集接收器
	* @method
	* @url void nvDeleteCollectorAsync(const char *data, ExportViplexCallback callBack);
	* @json_param {"sn":"BZSA07194A0049999716""info":{"type":["CPU_USAGE"]}}
	* @param sn 必选 string 产品唯一序列号
	* @param info 必选 object 删除的采集器类型
	* @param type 必选 list 删除的采集器类型列表
	* @return "sccuss"
	* @return_param code int 错误码:`0`获取成功`65535`请求超时
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvDeleteCollectorAsync(const char *data, ViplexCallback callBack);

#pragma endregion AcquisitionReceiver 采集器接收器

#pragma region USBVPlay
#pragma endregion USBVPlay U盘相关协议 待开发

#pragma region UpgradeManager
    /**
     * 文件搜索
     * @param options
     *{
     *  “paths”:[""],可以指定多个路径
     *  "types":[".txt"],//支持多条件搜索 结果按照类型区分
     *  "pageIndex":0,
     *  "pageSize":100,
     *
     *
     * }
     * @param Callback  返回所有满足条件的文件信息
     *
     */
    void nvQueryUpdateFileByTypeAsync(const char *data, ExportViplexCallback callBack);


    /**
     *  搜索在线升级包
     * @param options
     *{
     *    "productName":"/",
     *
     *
     *
     *
     * }
     * @param jsCallback
     *
     */
    void nvGetOnlineUpgradeFileAsync(const char *data, ExportViplexCallback callBack);
    /**
     *  下载升级包
     * @param options
     *{
     *    "url":"/",
     *    "targetAddress":""
     *
     *
     *
     * }
     * @param jsCallback
     *
     */
    void nvDownloadUpgradeFileAsync(const char *data, ExportViplexCallback callBack);
    /**
     *  停止升级包下载
     * @param options
     *{
     *
     *
     *
     *
     *
     * }
     * @param jsCallback
     *
     */
    void nvStopDownloadUpgradeFileAsync(const char *data, ExportViplexCallback callBack);
    /**
     * 从zip 中读取
     * @param options
     *{
     *    "zipFilePath":"/",
     *    "dFileName":"package_description.json"
     *
     *
     *
     * }
     * @param jsCallback
     *
     */
    void nvReadFileContentFromZipFileAsync(const char *data, ExportViplexCallback callBack);
    /**
    * 升级 OS
    * @param options
    * {
    *    "sn":"",
    *    "filePath":"/mnt/sdcard/viplex_terminal/",
    * }
    * @param Callback（result，error，progress）
    */
    void nvUpdateAppAsync(const char *data, ExportViplexCallback callBack);
    /**
    * 升级 OS
    * @param options
    * {
    *    "sn":"",
    *    "filePath":"/mnt/sdcard/viplex_terminal/",
    * }
    * @param Callback（）
    */
    void nvUpdateOSAsync(const char *data, ExportViplexCallback callBack);
    /**
     * 停止当前正在执行的升级接口
     * {
     *    "sn":""
     *
     * }
     * @param Callback （result，error）
     */
    void nvStopCurrentUpdateTaskAsync(const char *data, ExportViplexCallback callBack);
    /**
     * 升级可行性判断参数
     * @param options
     * {
     *    "sn":"",
     *    "verifyInfo":{
     *   "version": "TAURUSV010300CN1701",
     *   "totalSize": 279077363,
     *   "description": "TAURUSV010300CN1701",
     *   "packetType": "SINGLE",
     *   "excutionType": "UPDATE",
     *   "createdDate": "2018-08-10T21:04:23Z+08:00",
     *   "packages": [
     *     {
     *       "type": "OS",
     *       "version": "TAURUSV010300CN1701",
     *       "name": "TAURUSV010300CN1701.zip",
     *       "identifier": "VEFVUlVTVjAxMDMwMENOMTcwMS56aXA=",
     *       "size": 279077363,
     *       "startupAfterInstalled": true,
     *       "isUpgradeAppAfterOS":true,
     *       "supportedProducts": ["T1","T2"],
     *       "supportedPlatforms":["rk3368","rk312x"]
     *     }
     *   ]
     * }
     *
     *
     * }
     * @param jsCallback
     */
    VIPLEX_EXPORT void nvUpdateVerifyAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion UpgradeManager 升级 待修改类名（张鹏程）

#pragma region 网络配置
    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI
    * @title 获取WIFI列表
    * @description 获取WIFI列表的接口
    * @method
    * @url void nvGetWifiList(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"result":[{"ssid":"AirStation","bssid":"00:24:a5:bc:f4:56","level":4,"security":"PSK:WPA2","state":5},{"ssid":"ESAY_PLUTO","bssid":"c8:3a:35:47:ee:08","level":3,"security":"WPA","state":0}]}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param result jsonarray wifi列表，json数组
    * @return_param ssid String wifi的ssid
    * @return_param bssid String wifi的bssid
    * @return_param level int wifi信号等级
    * @return_param security String 密码加密方式，PSK:WPA，PSK:WPA2，PSK:WPA_WPA2，EAP，WEP，NONE
    * @return_param state int wifi状态
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetWifiListAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI
    * @title 连接wifi
    * @description 连接wifi的接口
    * @method
    * @url void nvConnectWifiNetwork(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"","taskInfo":{"ssid":"AP10006847","password":"12345678"}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 详情
    * @param ssid 必选 String wifi的ssid
    * @param password 必选 String 密码
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvConnectWifiNetworkAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI切换
    * @title 获取当前WIFI—AP/Station的状态
    * @description 获取当前WIFI—AP/Station的状态的接口
    * @method
    * @url void nvGetWifiCurrentStatus(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"taskArray":[{"type":"WIFI_AP_STATION_SWITCH","action":5,"status":1,"data":{"state":0}}]}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param taskArray objectArray 此条任务的类型，固定值WIFI_AP_STATION_SWITCH
    * @return_param action int 表示此命令的动作,ACTION_GET
    * @return_param status int 此任务执行是否成功：1-成功，2-失败，3-未知
    * @return_param data Object 具体的命令协议
    * @return_param state int 当前WIFI—AP/Station的状态，0表示当前为wifi-ap，1表示当前为wifi-station
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetWifiCurrentStatusAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI
    * @title 断开连接
    * @description 断开连接的接口
    * @method
    * @url void nvDisconnectWifiNetwork(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"","taskInfo":{"ssid":"AP10006847"}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 详情
    * @param ssid 必选 String wifi的ssid
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvDisconnectWifiNetworkAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI
    * @title 获取wifi的开启状态
    * @description 获取wifi的开启状态的接口
    * @method
    * @url void nvGetWifiEnabled(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"state":1}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param state int 1表示开启，0表示关闭
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetWifiEnabledAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI
    * @title 设置WIFI开启状态
    * @description 设置WIFI开启状态的接口
    * @method
    * @url void nvSetWifiEnabled(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZSA07194A0049999716","taskInfo":{"state":1}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 详情
    * @param state 必选 int 1表示开启，0表示关闭
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetWifiEnabledAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI
    * @title 忘记密码
    * @description 忘记密码的接口
    * @method
    * @url void nvSendForgetWifiCommand(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"","taskInfo":{"ssid":"AP10006847"}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 详情
    * @param ssid 必选 String wifi的ssid
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时`19`不存在的异常
    * @return_param data Object 错误码对应的具体描述
    * @remark 如果忘记的wifi的密码为空时返回ErrorCode为： ERR_NOT_EXISTED
    * @number 99
    */
    VIPLEX_EXPORT void nvSendForgetWifiCommandAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/4G网络
    * @title 获取移动网络配置信息
    * @description 获取移动网络配置信息的接口
    * @method
    * @url void nvGetMobileNetwork(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"basicConfigs":{"mobileData":true,"dataRoaming":true,"enable4G":true,"level":1},"advanced":{"networkType":"AUTO","APN":{"providerName":"中国移动"}}}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param basicConfigs object 基础配置
    * @return_param mobileData boolean 移动数据开关是否打开
    * @return_param dataRoaming boolean 漫游是否打开
    * @return_param enable4G boolean 是否使能4G网络
    * @return_param level int 4G网络的信号强度0~5
    * @return_param advanced object 高级特性
    * @return_param networkType String 网络类型，详细见说明部分(目前只支持AUTO)
    * @return_param APN object APN设置
    * @return_param providerName string sim卡的运行商名称
    * @remark AUTO:模块内部自动选择
    * @number 99
    */
    VIPLEX_EXPORT void nvGetMobileNetworkAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/4G网络
    * @title 设置移动网络配置信息
    * @description 设置移动网络配置信息的接口
    * @method
    * @url void nvSetMobileNetwork(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"","mobileData":{"basicConfigs":{"mobileData":true,"dataRoaming":true,"enable4G":true},"advanced":{"networkType":"AUTO","APN":{"providerName":"中国移动"}}}}
    * @param sn 必选 string 产品唯一序列号
    * @param mobileData 必选 Object 请求对象信息
    * @param basicConfigs 必选 object 基础配置
    * @param mobileData 必选 boolean 移动数据开关是否打开
    * @param dataRoaming 必选 boolean 漫游是否打开
    * @param enable4G 必选 boolean 是否使能4G网络
    * @param advanced 必选 object 高级特性
    * @param networkType 必选 String 网络类型，目前只支持 AUTO(自动)
    * @param APN 必选 object APN设置
    * @param providerName string sim卡的运行商名称
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @remark AUTO:模块内部自动选择
    * @number 99
    */
    VIPLEX_EXPORT void nvSetMobileNetworkAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/4G网络
    * @title 获取移动上网模块是否存在
    * @description 获取移动上网模块是否存在的接口
    * @method
    * @url void nvIsMobileModuleExisted(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"existed":true}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param existed boolean true存在，false不存在
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvIsMobileModuleExistedAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/有线网络
    * @title 获取有线网络信息
    * @description 获取有线网络信息的接口
    * @method
    * @url void nvGetEthernetInfo(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"ethernets":[{"scopeId":0,"name":"eth0","dhcp":false,"ip":"192.168.1.127","mask":"255.255.255.0","gateWay":"17.16.20.1","dns":["211.20.1.67"]}]}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param ethernets object 有线网络详情
    * @return_param scopeId int scopeId，如果 不知道，或者使用默认的，则填写-1
    * @return_param name string 名称，如 eth0,等等，可以指定的。
    * @return_param dhcp boolean true 的时候，表示使用动态地址分配，后面的字段无效
    * @return_param ip string ip地址
    * @return_param mask string 子网掩码
    * @return_param gateWay string 网关
    * @return_param dns (string)object DNS
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetEthernetInfoAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/有线网络
    * @title 设置有线网络信息
    * @description 设置仔细核对IP地址等信息，否则会导致搜到不到终端
    * @method
    * @url void nvSetEthernetInfo(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZSA07194A0049999716","taskInfo":{"ethernets":[{"scopeId":-1,"name":"eth0","dhcp":true,"ip":"172.16.9.192","mask":"255.255.255.0","gateWay":"172.16.9.254","dns":["172.16.0.201","172.16.0.202"]}]}}
    * @param sn 必选 string 产品唯一序列号
    * @param taskInfo 必选 Object 详情
    * @param ethernets 必选 Array 无
    * @param scopeId 必选 int scopeId，如果不知道，或者使用默认的，则填写-1
    * @param name 必选 string 名称，如 eth0,等等，可以指定的。
    * @param dhcp 必选 boolean true 的时候，表示使用动态地址分配，后面的字段无效
    * @param ip 必选 string ip地址
    * @param mask 必选 string 子网掩码
    * @param gateWay 必选 string 网关
    * @param dns (string)object	DNS
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetEthernetInfoAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI-AP
    * @title 获取WiFi-AP信息
    * @description 获取WiFi-AP信息的接口
    * @method
    * @url void nvgGetAPNetwork(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"aliasName":"AP","password":"12345678","suffix":"20002272"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param aliasName String AP别名
    * @return_param suffix String AP后缀
    * @return_param password String AP密码
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetAPNetworkAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI-AP
    * @title 设置wifi-AP信息
    * @description 设置wifi-AP信息的接口
    * @method
    * @url void nvSetAPNetwork(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA07194A0049999716","aliasName":"AP","suffix":"0016","password":"12345678","channelId":10}
    * @param sn 必选 string 产品唯一序列号
    * @param aliasName 必选 String AP别名
    * @param suffix 必选 String AP后缀
    * @param password 必选 String AP密码,8<=密码长度<=32,数字加大小写字母，不能有特殊字符
    * @param channelId 必选 int 信道，范围为1-13,默认为6
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetAPNetworkAsync(const char *data, ExportViplexCallback callBack);

    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI-AP
    * @title 获取APN信息
    * @description 获取APN信息
    * @method
    * @url void nvGetAPNInfoAsync(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA07194A0049999716"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"APNs":[{"carrier":"Orange FR-MMS","mcc":"208","mnc":"01","apn":"orange.acte","user":"orange","password":"orange","server":"*","port":"80","mmsc":"http://mms.orange.fr","mmsproxy":"192.168.010.200","mmsport":"8080","type":"mms","isUserDefined":false,"isUsed":true},{"carrier":"中国移动彩信 (China Mobile)","mcc":"460","mnc":"00","apn":"cmwap","server":"*","proxy":"10.0.0.172","mmsc":"http://mmsc.monternet.com","mmsproxy":"10.0.0.172","mmsport":"80","type":"mms","protocol":"IPV4V6","isUserDefined":false,"isUsed":true}]}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param APNs Object APN列表
    * @return_param carrier string APN名称，可为空，只用来显示apn列表中此apn的显示名字
    * @return_param mcc string 由三位数组成。 用于识别移动用户的所在国家
    * @return_param mnc string 由两位或三位组成。 用于识别移动用户的归属PLMN
    * @return_param apn string APN网络标识（接入点名称），是APN参数中的必选组成部分。此标识由运营商分配
    * @return_param user string 用户名称
    * @return_param password string 密码
    * @return_param server string 服务器地址
    * @return_param proxy string 代理服务器的地址
    * @return_param port string 代理服务器的端口
    * @return_param mmsc string MMS中继服务器/多媒体消息业务中心，是彩信的交换服务器
    * @return_param mmsproxy string 彩信代理服务器的地址
    * @return_param mmsport string 彩信代理服务器的端口号
    * @return_param type string apn的接入点类型
    * @return_param protocol string 支持的协议，不配置默认为IPV4
    * @return_param authtype string apn的认证协议
    * @return_param roamingProtocol string Apn漫游协议
    * @return_param isUserDefined boolean 是否用户自定义
    * @return_param isUsed boolean 是否正在使用
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetAPNInfoAsync(const char *data, ExportViplexCallback callBack);

    /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI-AP
    * @title 设置APN信息
    * @description 设置APN信息
    * @method
    * @url void nvSetAPNInfoAsync(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA17313J0820001562","APNs":[{"carrier":"Orange FR-MMS","mcc":"208","mnc":"01","apn":"orange.acte","user":"orange","password":"orange","server":"*","port":"80","mmsc":"http://mms.orange.fr","mmsproxy":"192.168.010.200","mmsport":"8080","type":"mms","isUserDefined":false,"isUsed":true},{"carrier":"中国移动彩信 (China Mobile)","mcc":"460","mnc":"00","apn":"cmwap","server":"*","proxy":"10.0.0.172","mmsc":"http://mmsc.monternet.com","mmsproxy":"10.0.0.172","mmsport":"80","type":"mms","protocol":"IPV4V6","isUserDefined":false,"isUsed":true}]}
    * @param sn string 产品唯一序列号
    * @param APNs object Apn信息列表
    * @param carrier tring APN名称，可为空，只用来显示apn列表中此apn的显示名字
    * @param mcc string 由三位数组成。用于识别移动用户的所在国家
    * @param mnc string 由两位或三位组成。用于识别移动用户的归属PLMN
    * @param apn string APN网络标识（接入点名称），是APN参数中的必选组成部分。此标识由运营商分配
    * @param user string 用户名称
    * @param password string 密码
    * @param server string 服务器地址
    * @param proxy string 代理服务器的地址
    * @param port string 代理服务器的端口
    * @param mmsc string MMS中继服务器/多媒体消息业务中心，是彩信的交换服务器
    * @param mmsproxy string 彩信代理服务器的地址
    * @param mmsport string 彩信代理服务器的端口号
    * @param type string apn的接入点类型
    * @param protocol string 支持的协议，不配置默认为IPV4
    * @param authtype string apn的认证协议
    * @param roamingProtocol string Apn漫游协议
    * @param isUserDefined boolean 是否用户自定义
    * @param isUsed boolean 是否正在使用
    * @return {"basicConfigs":{"mobileData":true,"dataRoaming":true, "enable4G":true,"level":1}, "advanced":{"networkType":"AUTO", "APN":{ "providerName":"中国移动"}}}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data object 返回成功参数
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetAPNInfoAsync(const char *data, ExportViplexCallback callBack);

   /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI-AP
    * @title 设置飞行模式开关状态
    * @description 设置飞行模式开关状态
    * @method
    * @url void nvSetFlightModeAsync(const char *data, ViplexCallback callback)
    * @json_param {"sn":"BZSA07194A0049999716","enable":true}
    * @param sn 必选 string 产品唯一序列号
    * @param enable 必选 bool 设置飞行模式开关状态
    * @return {"errorDiscription":"the description that describe the error in detail."}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data object 返回失败的data参数
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetFlightModeAsync(const char *data, ViplexCallback callback);

   /**
    * showdoc
    * @catalog 接口示例/网络配置/WIFI-AP
    * @title 获取飞行模式开关状态
    * @description 获取飞行模式开关状态
    * @method
    * @url void nvGetFlightModeAsync(const char *data, ViplexCallback callback)
    * @json_param {"sn":"BZSA07194A0049999716"}
    * @param sn 必选 string 产品唯一序列号
    * @return {"enable":true}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param enable bool 飞行模式开关状态
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetFlightModeAsync(const char *data, ViplexCallback callback);


    /**
     * showdoc
     * @catalog 接口示例/网络配置/WIFI-AP
     * @title 获取4G网络状态
     * @description 获取4G网络状态
     * @method
     * @url nvGet4GNetworkStatusAsync(const string &data, ViplexCallback callback)
     * @json_param {"sn":"BZSA07194A0049999716"}
     * @param sn 必选 string 产品唯一序列号
     * @return {"mobileNetState":0,"netType":1}
     * @return_param code int 错误码：`0`获取成功`65535`请求超时
     * @return_param mobileNetState int 4G网络状态,1正常2异常0未知（当前连接有线网或WIFI）
     * @return_param netType int 网络类型,0：无网络，1：有线网，2：wifi，3：2G，4：3G,5:4G,6:未知
     * @remark
     * @number 99
     */
    VIPLEX_EXPORT void nvGet4GNetworkStatusAsync(const char *data, ViplexCallback callback);

	/**
	 * showdoc
	 * @catalog 接口示例/网络配置/WIFI-AP
	 * @title 获取AP开启状态
	 * @description 获取AP开启状态
	 * @method
	 * @url nvGetAPNetworkOpenStatusAsync(const string &data, ViplexCallback callback)
	 * @json_param {"sn":"BZSA07194A0049999716"}
	 * @param sn 必选 string 产品唯一序列号
	 * @return {"ebable":true}
	 * @return_param code int 错误码：`0`获取成功`65535`请求超时
	 * @return_param enable bool AP的开启状态
	 * @remark
	 * @number 99
	 */
	VIPLEX_EXPORT void nvGetAPNetworkOpenStatusAsync(const char *data, ViplexCallback callback);

	/**
	 * showdoc
	 * @catalog 接口示例/网络配置/WIFI-AP
	 * @title 设置AP开启状态
	 * @description 设置AP开启状态
	 * @method
	 * @url nvSetAPNetworkOpenStatusAsync(const string &data, ViplexCallback callback)
	 * @json_param {"sn":"BZSA07194A0049999716","enable":true}
	 * @param sn 必选 string 产品唯一序列号
	 * @return "sccuss"
	 * @return_param code int 错误码：`0`获取成功`65535`请求超时
	 * @remark
	 * @number 99
	 */
	VIPLEX_EXPORT void nvSetAPNetworkOpenStatusAsync(const char *data, ViplexCallback callback);
#pragma endregion 网络配置 NetworkConfigurator

#pragma region ScreenConfiguration

    /**
   * showdoc
   * @catalog 接口示例/配屏/配屏
   * @title 获取配屏信息
   * @description 获取配屏信息的接口
   * @method
   * @url void void nvGetScreenAttribute(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272"}
   * @param sn 必选 string 产品唯一序列号
   * @return {"screenAttributes":[{"id":1,"screenSource":0,"xCount":1,"yCount":1,"xOffset":0,"yOffset":0,"portNumber":2,"orders":[0,1],"scanInfos":[{"width":128,"height":128,"x":0,"y":0,"xInPort":0,"yInPort":0,"portIndex":0,"connectIndex":0}]}]}
   * @return_param id int 显示屏id
   * @return_param screenSource int 显示屏id
   * @return_param id int 显示屏id
   * @return_param id int 配屏参数来源（`0`手机配屏,`1`LCT配屏）
   * @return_param xCount int X方向上接收卡个数
   * @return_param yCount int y方向上接收卡个数
   * @return_param xOffset int x方向上显示位置的偏移坐标
   * @return_param yOffset int y方向上显示位置的偏移坐标
   * @return_param portNumber int 所使用的网口数量
   * @return_param orders intArray 总共8种走线，数组内容顺序按照网口大小依次从小到大排列
   * @return_param scanInfos object 接收卡信息集合
   * @return_param width int 接收卡宽度
   * @return_param height int 接收卡高度
   * @return_param x int 接收卡所在显卡x坐标
   * @return_param y int 接收卡所在显卡y坐标
   * @return_param xInPort int 接收卡所在网口带载区域x坐标
   * @return_param yInPort int 接收卡所在网口带载区域y坐标
   * @return_param portIndex int 接收卡所在网口下标
   * @return_param connectIndex int 接收卡所在网口下的连接位置
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetScreenAttributeAsync(const char *data, ExportViplexCallback callBack);

    /**
   * showdoc
   * @catalog 接口示例/配屏/配屏
   * @title 设置配屏信息
   * @description 设置配屏信息的接口
   * @method
   * @url void void nvSetScreenAttribute(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272","screenAttributes":[{"id":0,"orders":[0,1],"portNumber":1,"scanInfos":[{"connectIndex":0,"height":256,"portIndex":0,"width":256,"x":0,"xInPort":0,"y":0,"yInPort":0}],"screenSource":1,"xCount":1,"xOffset":0,"yCount":1,"yOffset":0}]}
   * @param sn 必选 string 产品唯一序列号
   * @param id 必选 int 显示屏id
   * @param screenSource 必选 int 显示屏id
   * @param id 必选 int 显示屏id
   * @param id 必选 int 配屏参数来源（`0`手机配屏,`1`LCT配屏）
   * @param xCount 必选 int X方向上接收卡个数
   * @param yCount 必选 int y方向上接收卡个数
   * @param xOffset 必选 int x方向上显示位置的偏移坐标
   * @param yOffset 必选 int y方向上显示位置的偏移坐标
   * @param portNumber 必选 int 所使用的网口数量
   * @param orders 必选 intArray 总共8种走线，数组内容顺序按照网口大小依次从小到大排列
   * @param scanInfos 必选 object 接收卡信息集合
   * @param width 必选 int 接收卡宽度
   * @param height 必选 int 接收卡高度
   * @param x 必选 int 接收卡所在显卡x坐标
   * @param y 必选 int 接收卡所在显卡y坐标
   * @param xInPort 必选 int 接收卡所在网口带载区域x坐标
   * @param yInPort 必选 int 接收卡所在网口带载区域y坐标
   * @param portIndex 必选 int 接收卡所在网口下标
   * @param connectIndex 必选 int 接收卡所在网口下的连接位置
   * @return ""
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvSetScreenAttributeAsync(const char *data, ExportViplexCallback callBack);

    /**
   * showdoc
   * @catalog 接口示例/配屏/接收卡文件配屏
   * @title 接收卡文件配屏
   * @description 接口的功能是终端可以通过接收卡文件配屏。该接口业务逻辑分为3步：1获取文件上传路径、2将本地文件上传到指定路径、3配屏
   * @method
   * @url void nvSetRecvCardFile(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272","filePath":"C:/test","fileName":"5036.rcfgx"}
   * @param sn 必选 string 产品唯一序列号
   * @param filePath 必选 string 	配屏文件的地址
   * @param fileName 必选 string 配屏文件的名称
   * @return ""
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvSetRecvCardFileAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion ScreenConfiguration 配屏 

#pragma region ICareConfigurator
    /**
   * showdoc
   * @catalog 接口示例/icare配置
   * @title 获取icare配置信息
   * @description 获取icare配置信息的接口
   * @method
   * @url void nvGetIcareConfigInfo(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA17332J0A20002272","requestInfo":{"language":"zh-cn"}}
   * @param sn 必选 string 产品唯一序列号
   * @param language 必选 string `zh-cn`中文,`en`英文
   * @return {"state":true,"serverNodes":[{"label":"测试","node":"t.novaicare.com"},{"label":"美国节点","node":"care-us.novaicare.com"},{"label":"中国节点","node":"care.novaicare.com"}],"url":"t.novaicare.com","username":"XXX","isOnline":true}
   * @return_param state bool 开启状态,true为开启,false为关闭
   * @return_param serverNodes object 显示屏id
   * @return_param label string 服务器名称
   * @return_param node string 服务器地址
   * @return_param url string 当前连接的服务器地址
   * @return_param username string 绑定的用户名
   * @return_param isOnline string 是否在线,true为在线,false为不在线
   * @return_param code int 错误码：`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetIcareConfigInfoAsync(const char *data, ExportViplexCallback callBack);

    /**
   * showdoc
   * @catalog 接口示例/icare配置
   * @title 设置icare配置信息
   * @description 设置icare配置信息的接口
   * @method
   * @url void nvSetIcareConfigInfo(const char *data, ExportViplexCallback callBack)
   * @json_param {"sn":"BZSA17332J0A20002272","requestInfo":{"state":true,"url":"care.novaicare.com","username":"XXX"}}
   * @param sn 必选 string 产品唯一序列号
   * @param state 必选 bool 开启状态,true为开启,false为关闭
   * @param url 必选 string 当前连接的服务器地址
   * @param username 必选 string 绑定的用户名
   * @return ""
   * @return_param code int 错误码:`0`获取成功`33`账号不存在`34`未配屏`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvSetIcareConfigInfoAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion ICareConfigurator icare配置

#pragma region CloudConfigurator

    /**
   * showdoc
   * @catalog 接口示例/终端cloud配置
   * @title 绑定Cloud服务器
   * @description 绑定Cloud服务器的接口
   * @method
   * @url void nvSetBindPlayer(const char *data, ExportViplexCallback callBack)
   * @json_param {"sn":"BZSA07194A0049999716","playerInfo":{"baseUrl":"https://api-cn.vnnox.com","data":{"playerList":[{"identifier":"84f37cb1a12783654780f47da13b55db##dangjintao","isUsed":true,"name":"dangjintao","playerIdentifier":"BZSA07194A0049999716"}],"token":"f2972f5a403d5e13d1c6103f91bf78a58055bfd5"},"isNewVnnox":true,"password":"123456","username":"gmt"}}
   * @param sn 必选 string 产品唯一序列号
   * @param baseUrl 必选 string 用于更换服务器时,终端访问对应服务器主机地址
   * @param password 必选 string 播放机认证的密码
   * @param username 必选 string 	播放机认证的用户名
   * @param isNewVnnox 必选 bool 绑定的是否为新的vnnox
   * @param token 必选 string 播放机交互TOKEN(播放器与服务器交互,要将此TOKEN加入http协议header中)
   * @param identifier 必选 string 服务端播放机唯一标识(从VNNOX获取的Identifer+"##播放器名称")
   * @param isUsed 必选 string 服务端播放机是否已绑定
   * @param name 必选 string 服务端播放机名称
   * @param playerIdentifier 必选 string 终端播放器唯一标识
   * @return ""
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvSetBindPlayerAsync(const char *data, ExportViplexCallback callBack);

    /**
   * showdoc
   * @catalog 接口示例/终端cloud配置
   * @title 获取播放器列表
   * @description 获取播放器列表的接口
   * @method
   * @url void nvGetCloudPlayerList(const char *data, ExportViplexCallback callBack)
   * @json_param {"host":"http://beta-rest.vnnox.com","data":{"username":"qht1003077897","password":"qht1003077897","playerType":2}}
   * @param host 必选 string 服务器地址
   * @param username 必选 string 播放机认证的用户名
   * @param password 必选 string 播放机认证的密码
   * @param playerType 必选 int `1`同步`2`异步
   * @return {"status":[10000],"data":{"token":"654ad5s64f65w46f5e456wa4f","playerList":[{"name":"player_1","identifier":"654ad-5s64f6-5w46-f5e45-6wa4f","isUsed":true,"playerIdentifier":"33-22-44-22-44"}]}}
   * @return_param status int 返回结果状态
   * @return_param token string 播放机交互TOKEN(播放器与服务器交互)
   * @return_param name string 服务端播放机名称
   * @return_param identifier string 服务端播放机唯一标识
   * @return_param isUsed bool 服务端播放机是否已绑定
   * @return_param token string 终端播放器唯一标识
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetCloudPlayerListAsync(const char *data, ExportViplexCallback callBack);
    /**
   * showdoc
   * @catalog 接口示例/终端cloud配置
   * @title 获取播放器绑定信息
   * @description 获取播放器绑定信息的接口
   * @method
   * @url void nvGetBindPlayer(const char *data, ExportViplexCallback callBack)
   * @json_param {"sn":"BZSA07194A0049999716"}
   * @param sn 必选 string 产品唯一序列号
   * @return {"isBind":true,"errorDescription":" ","baseUrl":"http://test.vnnox.com","password":"wxgaly199425","username":"wxgaly","status":[10000],"data":{"token":"9e49437a8bc44ba790389524b74c76acdc7909e6","playerList":[{"identifier":"103190fdfa52c37516aae26a9d00ed7c","isUsed":true,"name":"异步播放机1","playerIdentifier":"30:34:00:00:00:17"}]}}
   * @return_param isBind bool 终端播放器是否被绑定
   * @return_param errorDescription string 播放器未被绑定的错误信息
   * @return_param baseUrl string 用于更换服务器时，终端访问对应服务器主机地址
   * @return_param password string 播放机认证的密码
   * @return_param username string 播放机认证的用户名
   * @return_param status intarray 播放机当前心跳状态(10000表示心跳正常)
   * @return_param token string 播放机交互TOKEN(播放器与服务器交互)
   * @return_param name string 服务端播放机名称
   * @return_param identifier string 服务端播放机唯一标识
   * @return_param isUsed bool 服务端播放机是否已绑定
   * @return_param token string 终端播放器唯一标识
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetBindPlayerAsync(const char *data, ExportViplexCallback callBack);

#pragma endregion CloudConfigurator 终端cloud配置

#pragma region MonitorConfigurator
    /**
   * showdoc
   * @catalog 接口示例/监控/获取系统参数
   * @title 获取硬盘存储信息
   * @description 获取硬盘存储信息
   * @method
   * @url void void nvGetAvailableStorageDataAsync(const char *data, ExportViplexCallback callBack)
   * @json_param {"sn":"BZSA07194A0049999716"}
   * @param sn 必选 string 产品唯一序列号
   * @return {"diskAvailableSize":3.67,"diskTotalSize":3.96,"storageInfos":[{"diskAvailableSize":3938967552,"diskCriticalSize":524288000,"diskReserveSize":0,"diskTotalSize":4248846336,"type":"LOCAL"}]}
   * @return_param diskTotalSize float 外部存储空间总大小,单位G
   * @return_param diskAvailableSize float 可用空间大小,单位G
   * @return_param storageInfos object 存储空间信息
   * @return_param diskAvailableSize float 磁盘可用空间大小,单位Byte
   * @return_param diskCriticalSize float 磁盘空间不足预警阀值,当剩余存储空间小于该值,部分功能可能无法正常使用,单位Byte
   * @return_param diskReserveSize float 磁盘内部预留空间,单位Byte
   * @return_param diskTotalSize float 磁盘存储空间总大小,单位Byte
   * @return_param type string 磁盘类型,`LOCAL`内部存储（SD卡） `EXTERNAL`外部存储（U盘等）
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetAvailableStorageDataAsync(const char *data, ExportViplexCallback callBack);

    /**
   * showdoc
   * @catalog 接口示例/监控/获取系统参数
   * @title 获取CPU使用率
   * @description 获取CPU使用率的接口
   * @method
   * @url void nvGetCPUUsage(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA07194A0049999716"}
   * @param sn 必选 string 产品唯一序列号
   * @return {"value":18}
   * @return_param value float CPU使用率
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetCPUUsageAsync(const char *data, ExportViplexCallback callBack);

/**
* showdoc
* @catalog 接口示例/监控/获取系统参数
* @title 获取CPU温度
* @description 获取CPU温度的接口
* @method
* @url void nvGetCPUTempAsync(const char *data, ExportViplexCallback callBack);
* @json_param {"sn":"BZSA07194A0049999716"}
* @param sn 必选 string 产品唯一序列号
* @return {"value":38.8}
* @return_param value float CPU使用率
* @return_param code int 错误码:`0`获取成功`65535`请求超时
* @remark
* @number 99
*/
	VIPLEX_EXPORT void nvGetCPUTempAsync(const char *data, ExportViplexCallback callBack);

/**
* showdoc
* @catalog 接口示例/监控/获取系统参数
* @title 获取可用内存
* @description 获取可用内存的接口
* @method
* @url void nvGetAvailableMemoryAsync(const char *data, ExportViplexCallback callBack);
* @json_param {"sn":"BZSA07194A0049999716"}
* @param sn 必选 string 产品唯一序列号
* @return {"value":18}
* @return_param value float CPU使用率
* @return_param code int 错误码:`0`获取成功`65535`请求超时
* @remark
* @number 99
*/
	VIPLEX_EXPORT void nvGetAvailableMemoryAsync(const char *data, ExportViplexCallback callBack);

	/**
	* showdoc
	* @catalog 接口示例/监控
	* @title 获取发送卡的监控信息
	* @description 获取发送卡的监控信息
	* @method
	* @url void nvGetSendCardMonitorInfoAsync(const char *data, ExportViplexCallback callBack);
	* @json_param {"sn":"BZSA07194A0049999716"}
	* @param sn 必选 string 产品唯一序列号
	* @return {"sendCardMonitorInfo":[{"isDVIConnected": true,"DVIRate": 60,"redundancePortInfo": [{"isRedundant": false,"devMappingList": [{"devIndex": 0,"devType": 1},{"devIndex": 0,"devType": 2},{"devIndex": 0,"devType":3}],"deviceWorkState": 1},	{"isRedundant": true,"devMappingList": [{"devIndex": 0,"devType": 1},{"devIndex": 0,"devType": 2},{"devIndex": 1,"devType": 3}],"deviceWorkState": 0}],"deviceMapList": [{"deviceIndex": 0,"deviceType": 1}, {"deviceIndex": 0,"deviceType": 2}],"deviceWorkState": 0}]}
	* @return_param code int 错误码:`0`获取成功`65535`请求超时
	* @return_param sendCardMonitorInfo	object	发送卡的监控数据
	* @return_param deviceWorkState	int	工作状态， 正常OK=1，异常 Error = 1， 未知 Unknown = 2
	* @return_param deviceMapList	object	设备的位置索引信息
	* @return_param deviceIndex	int	设备所在位置编号，设备串联上的第几个
	* @return_param deviceType	int	设备类型
	* @return_param isDVIConnected	boolean	DVI源是否连接
	* @return_param DVIRate	int	DVI刷新率，仅在DVI连接时才有效
	* @return_param redundancePortInfo	object	网口信息的列表
	* @return_param deviceWorkState	int	工作状态， 正常OK=1，异常 Error = 1， 未知 Unknown = 2
	* @return_param deviceMapList	object	设备的位置索引信息
	* @return_param deviceIndex	int	设备所在位置编号，设备串联上的第几个
	* @return_param deviceType	int	设备类型
	* @return_param isRedundant	boolean	是否是冗余网口
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvGetSendCardMonitorInfoAsync(const char *data, ViplexCallback callBack);

	/**
	* showdoc
	* @catalog 接口示例/监控
	* @title 获取接收卡的数量及信息
	* @description 获取接收卡的数量及信息
	* @method
	* @url void nvGetReceiverCountAndInfoAsync(const char *data, ExportViplexCallback callBack);
	* @json_param {"sn":"BZSA07194A0049999716"}
	* @param sn 必选 string 产品唯一序列号
	* @return {"receiveCardRegionInfo":[{"senderIndex": 0,"portIndex": 0,"connectIndex": 0,"X": 0,"Y": 0,"XInPort": 0,"YInPort": 0,"width": 400,"height": 400,"rowIndexInScreen": 0,"colIndexInScreen": 0}]}
	* @return_param code int 错误码:`0`获取成功`65535`请求超时
	* @return_param receiveCardRegionInfo	object	所有接收卡的位置和大小信息
	* @return_param senderIndex byte 所属发送卡序号， 若为-1，表示留空
	* @return_param portIndex	byte	所属输出口序号
	* @return_param connectIndex	int	位于所在输出口的第几个
	* @return_param X	int	X位置(在其所在显卡的X坐标)
	* @return_param Y	int	Y位置(在其所在显卡的Y坐标)
	* @return_param XInPort	int	X位置(在其所在Port带载区域的X坐标)
	* @return_param YInPort	int	Y位置(在其所在Port带载区域的Y坐标)
	* @return_param width	int	带载像素宽度
	* @return_param height	int	带载像素高度
	* @return_param rowIndexInScreen	int	位于屏体第几行
	* @return_param colIndexInScreen	int	位于屏体第几列
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvGetReceiverCountAndInfoAsync(const char *data, ViplexCallback callBack);

	/**
	* showdoc
	* @catalog 接口示例/监控
	* @title 根据接收卡索引获取监控信息
	* @description 根据接收卡索引获取监控信息
	* @method
	* @url void nvGetMonitorInfoByReceiverIndexAsync(const char *data, ExportViplexCallback callBack);
	* @json_param {"info":{"receiveCardRegionInfo": [{"portIndex":0,"connectedIndex":0},{"portIndex":0,"connectedIndex":1}]}}
	* @param sn 必选 string 产品唯一序列号
	* @param receiveCardRegionInfo 必选 object 所要获取的接收卡的位置信息
	* @param portIndex 必选 byte 所属输出口序号，网口位置
	* @param connectedIndex 必选 int 位于所在输出口的第几个
	* @return {"receiveCardRegionInfo":[{"portIndex":0,"connectedIndex":0},{"portIndex":0,"connectedIndex":1}]}
	* @return_param code int 错误码:`0`获取成功`65535`请求超时
	* @return_param receiveCardRegionInfo	object	所要获取的接收卡的位置信息
	* @return_param portIndex	byte	所属输出口序号，网口位置
	* @return_param connectedIndex	int	位于所在输出口的第几个
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvGetMonitorInfoByReceiverIndexAsync(const char *data, ViplexCallback callBack);
#pragma endregion MonitorConfigurator 监控 

#pragma region ScreenManager
    /**
    * showdoc
    * @catalog 接口示例/屏体其他项/校时
    * @title 获取时区
    * @description 获取时区的接口
    * @method
    * @url void nvGetCurrentTimeAndZone(const char * data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"utcTimeMillis":1585190230828,"timeZone":"Europe/London","currentTime":"2020-03-26 02:37:10","isTimeOffsetEnable":true,"beginTime":"","endTime":"","timeOffsetValue":0,"gmt":"GMT+08:00"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param utcTimeMillis long utc时间的毫秒表示
    * @return_param timeZone string 时区，例如"Asia/Shanghai"
    * @return_param gmt string 时区gmt，例如"GMT+08:00"
    * @return_param isTimeOffsetEnable boolean 是否开启时间补偿，开启为true，否则false
    * @return_param beginTime string 补时开始时间，传递开始的月和天，例如"2020-05-23"
    * @return_param endTime string 补时结束时间，传递开始的月和天，例如"2020-12-23"
    * @return_param timeOffsetValue long 时间补偿值，以秒为单位，带符号数。例如：+6000
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetCurrentTimeAndZoneAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/屏体其他项/校时
    * @title 设置卡上的时间
    * @description 设置卡上的时间的接口
    * @method
    * @url void nvCalibrateTime(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZSA17332J0A20002272","currentTime":"2020-03-26 02:37:10","timeZoneInfo":{"utcTimeMillis":1585190230828,"timeZone":"Europe/London","isTimeOffsetEnable":true,"beginTime":"","endTime":"","timeOffsetValue":0,"gmt":"GMT+08:00"}}
    * @param sn 必选 string 产品唯一序列号
    * @param currentTime 必选 string 当前时区对应的时间时区
    * @param timeZoneInfo 必选 Object 时区详情
    * @param utcTimeMillis 必选 long utc时间的毫秒表示
    * @param timeZone 必选 string 时区，例如"Asia/Shanghai"
    * @param gmt 必选 string 时区gmt，例如"GMT+08:00"
    * @param isTimeOffsetEnable 必选 boolean 是否开启时间补偿，开启为true，否则false
    * @param beginTime 必选 string 补时开始时间，传递开始的月和天，例如"2020-05-23"
    * @param endTime 必选 string 补时结束时间，传递开始的月和天，例如"2020-05-23"
    * @param timeOffsetValue 必选 long 时间补偿值，以秒为单位，带符号数。例如：+6000
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @return_param utcTimeMillis long utc时间的毫秒表示
    * @return_param timeZone string 时区，例如"Asia/Shanghai"
    * @return_param gmt string 时区gmt，例如"GMT+08:00"
    * @return_param isTimeOffsetEnable boolean 是否开启时间补偿，开启为true，否则false
    * @return_param timeOffsetValue long 时间补偿值，以秒为单位，带符号数。例如：+6000
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvCalibrateTimeAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/屏体其他项/NTP校时
    * @title 获取对时配置
    * @description 获取对时配置，通过此接口可获取到ntp对时和Lora对时taskArray数组，不区分版本，低版本通过旧网络对时协议获取到信息后，转换为0x99协议的形式
    * @method
    * @url void nvGetNetTimingInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"source":{"type":1,"platform":1},"taskArray":[{"type":"LORA_SYNC","action":5,"status":1,"data":{"enable":true,"address":1,"channel":23,"mode":"MASTER","groupId":"novad101","regulation":{"timeEnable":false,"brightnessEnable":true,"volumeEnable":true,"environmentalMonitoring":true}}},{"type":"NTP_CONFIG","action":5,"status":1,"data":{"enable":true,"server":"http://ntpsss.net"}}]}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param source object 下发命令的来源
    * @return_param type int 1：nova自己的平台,0：第三方平台
    * @return_param platform int 1:手机、2:CS、3:平板、4:VNNOX、5:Care、6:LCT、7:Lora
    * @return_param taskArray object 任务数组
    * @return_param type string 表征业务类型,固定值:"NTP_CONFIG",或者固定值:"LORA_SYNC"
    * @return_param action int 表征此命令的动作，固定值：ACTION_SET(5)
    * @return_param status int 成功或失败,0:未知状态;1:成功;2:失败
    * @return_param data object NTP校时配置项
    * @return_param enable boolean ntp是否使能
    * @return_param server string ntp服务器地址
    * @return_param data object 射频同步配置项
    * @return_param enable boolean 射频同步使能
    * @return_param mode string 主从模式"MASTER"or"SLAVE"
    * @return_param address int 目标地址
    * @return_param channel int 目标信道
    * @return_param groupId string 组id，用户划分设备组,(字符串格式，最大长度为10个字节，由上位机做限制)
    * @return_param regulation object 同步使能规则
    * @return_param timeEnable boolean 时间同步使能
    * @return_param brightnessEnable boolean 亮度同步使能
    * @return_param volumeEnable boolean 音量同步使能
    * @return_param environmentalMonitoring boolean 环境检测数据同步使能
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetNetTimingInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/屏体其他项/NTP校时
    * @title NTP校时配置
    * @description 设置对时配置，包括配置ntp对时和lora对时，以数组的形式下发，也可以单独下发ntp或者lora
    * @method
    * @url void nvSetNetTimingInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"BZSA17332J0A20002272","TimingInfo":{"source":{"type":1,"platform":1},"taskArray":[{"type":"LORA_SYNC","action":4,"data":{"enable":true,"address":1,"channel":23,"mode":"MASTER","groupId":"novad101","regulation":{"timeEnable":false,"brightnessEnable":true,"volumeEnable":true,"environmentalMonitoring":true}}},{"type":"NTP_CONFIG","action":4,"data":{"enable":true,"server":"http://ntpsss.net"}}]}}
    * @param sn 必选 string 产品唯一序列号
    * @param TimingInfo 必选 string 对时配置对象
    * @param source 必选 object 下发命令的来源
    * @param type 必选 int 1：nova自己的平台,0：第三方平台
    * @param platform 必选 int 1：手机、2：CS、3：平板、4：VNNOX、5：Care、6：LCT、7:Lora
    * @param taskArray 必选 object 任务数组
    * @param type 必选 string 表征业务类型,固定值："NTP_CONFIG"，或者固定值："LORA_SYNC"
    * @param action 必选 int 表征此命令的动作，固定值：ACTION_SET
    * @param data 必选 object NTP校时配置项
    * @param enable 必选 boolean ntp是否使能
    * @param server 必选 string ntp服务器地址
    * @param data 必选 object 射频同步配置项
    * @param enable 必选 boolean 射频同步使能
    * @param mode 必选 string 主从模式"MASTER"or"SLAVE"
    * @param address 必选 int 目标地址
    * @param channel 必选 int 目标信道
    * @param groupId 必选 string 组id，用户划分设备组,(字符串格式，最大长度为10个字节，由上位机做限制)
    * @param regulation 必选 object 同步使能规则
    * @param timeEnable 必选 boolean 时间同步使能
    * @param brightnessEnable 必选 boolean 亮度同步使能
    * @param volumeEnable 必选 boolean 音量同步使能
    * @param environmentalMonitoring 必选 boolean 环境检测数据同步使能
    * @return {"taskArray":[{"action":4,"errorCode":0,"status":1,"type":"NTP_CONFIG"},{"action":4,"errorCode":0,"status":1,"type":"LORA_SYNC"}]}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @return_param type string 表征业务类型,固定值："NTP_CONFIG"或"LORA_SYNC"
    * @return_param action int 表征此命令的动作，固定值：ACTION_GET(4)
    * @return_param status int 成功或失败，0:未知状态；1:成功；2:失败
    * @return_param errorCode int 错误码
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetNetTimingInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/对时服务器列表
    * @title 获取时间服务器列表
    * @description 1.获取对时服务器列表，由两部分组成，用户自定义及服务器获取到的列表，服务器获取到的列表会根据语言返回对应的地址，服务器列表地址如：http://download.vnnox.com/vnnox_api_host/timehost.json2.服务器获取到的列表不可修改
    * @method
    * @url void nvGetNetTimingListInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"lang":"en"}
    * @param lang 必选 string 语言，英文：en，中文：zh-cn，日文：jp，韩文：kr，西班牙语：es，法语：fr
    * @return {"serverInfo":[{"islocal":true,"label":"aa","node":"www.baidu.com"}]}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 返回值错误码对应的说明
    * @return_param serverInfo array 返回服务器列表数组
    * @return_param islocal bool 是否是用户自定义添加的数据，true：用户自定义，false：服务器获取
    * @return_param label string 节点名称
    * @return_param node string 节点地址
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetNetTimingListInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/对时服务器列表
    * @title 添加对时服务器
    * @description 添加对时服务器的接口
    * @method
    * @url void nvAddNetTimingInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"label":"aa","node":"www.baidu.com"}
    * @param label 必选 string 节点名称
    * @param node 必选 string 节点地址
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvAddNetTimingInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/对时服务器列表
    * @title 删除对时服务器
    * @description 删除对时服务器列表，如果存在两条node和label都完全一致的数据，则删除第一条
    * @method
    * @url void nvDeleteNetTimingInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"label":"aa","node":"www.baidu.com"}
    * @param label 必选 string 节点名称
    * @param node 必选 string 节点地址
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvDeleteNetTimingInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/对时服务器列表
    * @title 修改对时服务器
    * @description 修改对时服务器列表,修改服务器列表,如果存在两条node和label都完全一致的数据,则修改第一条
    * @method
    * @url void nvUpdateNetTimingInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"oldServer":{"label":"zhangsan","node":"123.123.123"},"newServer":{"label":"lisi","node":"111.111.111"}}
    * @param oldServer 必选 Object 被修改的服务器信息
    * @param label 必选 string 节点名称
    * @param node 必选 string 节点地址
    * @param newServer 必选 Object 修改后的服务器信息
    * @param label 必选 string 节点名称
    * @param node 必选 string 节点地址
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvUpdateNetTimingInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/对时服务器列表
    * @title 添加对时服务器列表
    * @description 添加对时服务器列表的接口
    * @method
    * @url void nvAddNetTimingInfoList(const char *data, ExportViplexCallback callBack)
    * @json_param {"serverInfo":[{"label":"aa","node":"www.baidu.com"},{"label":"aa","node":"www.baidu.com"}]}
    * @param serverInfo 必选 array 服务器列表数组
    * @param label 必选 string 节点名称
    * @param node 必选 string 节点地址
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvAddNetTimingInfoListAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/屏体其他项/校时
    * @title 获取时区
    * @description 获取时区的接口
    * @method
    * @url void nvGetCurrentTimeAndZone(const char * data, ExportViplexCallback callback)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"utcTimeMillis":1585190230828,"timeZone":"Europe/London","currentTime":"2020-03-26 02:37:10","isTimeOffsetEnable":true,"beginTime":"","endTime":"","timeOffsetValue":0,"gmt":"GMT+08:00"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param utcTimeMillis long utc时间的毫秒表示
    * @return_param timeZone string 时区，例如"Asia/Shanghai"
    * @return_param gmt string 时区gmt，例如"GMT+08:00"
    * @return_param isTimeOffsetEnable boolean 是否开启时间补偿，开启为true，否则false
    * @return_param beginTime string 补时开始时间，传递开始的月和天，例如"2020-05-23"
    * @return_param endTime string 补时结束时间，传递开始的月和天，例如"2020-12-23"
    * @return_param timeOffsetValue long 时间补偿值，以秒为单位，带符号数。例如：+6000
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetCurrentTimeAndZoneAsync(const char *data, ExportViplexCallback callback);
    /**
    * showdoc
    * @catalog 接口示例/屏体其他项/校时
    * @title 设置卡上的时间
    * @description 设置卡上的时间的接口
    * @method
    * @url void nvCalibrateTime(const char *data, ExportViplexCallback callback)
    * @json_param {"sn":"BZSA17332J0A20002272","currentTime":"2020-03-26 02:37:10","timeZoneInfo":{"utcTimeMillis":1585190230828,"timeZone":"Europe/London","isTimeOffsetEnable":true,"beginTime":"","endTime":"","timeOffsetValue":0,"gmt":"GMT+08:00"}}
    * @param sn 必选 string 产品唯一序列号
    * @param currentTime 必选 string 当前时区对应的时间时区
    * @param timeZoneInfo 必选 Object 时区详情
    * @param utcTimeMillis 必选 long utc时间的毫秒表示
    * @param timeZone 必选 string 时区，例如"Asia/Shanghai"
    * @param gmt 必选 string 时区gmt，例如"GMT+08:00"
    * @param isTimeOffsetEnable 必选 boolean 是否开启时间补偿，开启为true，否则false
    * @param beginTime 必选 string 补时开始时间，传递开始的月和天，例如"2020-05-23"
    * @param endTime 必选 string 补时结束时间，传递开始的月和天，例如"2020-05-23"
    * @param timeOffsetValue 必选 long 时间补偿值，以秒为单位，带符号数。例如：+6000
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @return_param utcTimeMillis long utc时间的毫秒表示
    * @return_param timeZone string 时区，例如"Asia/Shanghai"
    * @return_param gmt string 时区gmt，例如"GMT+08:00"
    * @return_param isTimeOffsetEnable boolean 是否开启时间补偿，开启为true，否则false
    * @return_param timeOffsetValue long 时间补偿值，以秒为单位，带符号数。例如：+6000
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvCalibrateTimeAsync(const char *data, ExportViplexCallback callback);


	/**
	* showdoc
	* @catalog 接口示例/其他/校时
	* @title 获取是否夏令时
	* @description 获取是否夏令时的接口
	* @method
	* @url void nvGetIsUseDayLightTimeAsync(const char *data, ExportViplexCallback callBack)
	* @json_param {"isUseDayLightTimeData":{"timeZone":"Asia/Shanghai","gmt":"GMT+08:00"}
	* @param isUseDayLightTimeData 必选 Object 获取是否夏令时信息
	* @param gmt 必选 string 时区gmt
	* @return "success"
	* @return_param code int 错误码：`0`获取成功`65535`请求超时
	* @return_param data string 返回值错误码对应的说明
	* @remark
	* @number 99
	*/
	VIPLEX_EXPORT void nvGetIsUseDayLightTimeAsync(const char *data, ExportViplexCallback callback);

#pragma region ScreenShot 
    /**
     * showdoc
     * @catalog 接口示例/屏体管理
     * @title 获取终端截图
     * @description 获取终端截图
     * @method
     * @url void downLoadScreenshot(const char *data, ExportViplexCallback callBack);
     * @json_param {"sn":"BZSA17332J0A20002272","width":256,"height":256,"type":"PNG"}
     * @param sn 必选 string 产品唯一序列号
     * @param width 必选 int 图片宽度
     * @param height 必选 int 图片高度
     * @param type 必选 enum 图片格式，PNG png格式， JPG jpg格式
     * @return {"code":0,"path":"/cache/screenShots/screenshot.png"}
     * @return_param code int 错误码：`0`获取成功`65535`请求超时
     * @return_param path string 截图路径
     * @remark
     * @number 90
     */
    VIPLEX_EXPORT void nvDownLoadScreenshotAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion ScreenShot 截屏

#pragma endregion ScreenManager 屏体其他项

#pragma region 其他

    /**
    * showdoc
    * @catalog 接口示例/温度&色温/温度
    * @title 获取箱体温度
    * @description 获取箱体温度的接口
    * @method
    * @url void nvGetScreenUnitTemp(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":""}
    * @param sn 必选 string 产品唯一序列号
    * @return {"temps":[{"bx":0,"by":0,"value":20},{"bx":128,"by":0,"value":25}]}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 错误码对应的具体描述
    * @return_param temps object 数组对象
    * @return_param bx int X坐标
    * @return_param by int y坐标
    * @return_param value float 温度值
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetScreenUnitTempAsync(const char *data, ExportViplexCallback callBack);
    /**
   * showdoc
   * @catalog 接口示例/其他/数据迁移
   * @title 数据迁移
   * @description 数据迁移的接口
   * @method
   * @url void nvDataBaseMigration(const char *data, ExportViplexCallback callBack)
   * @json_param {"templates":[{"data":[{"width":0.4,"height":0.4,"left":0.4,"top":0.4,"zindex":1,"index":0}]}],"size":[{"height":300,"width":300}],"program":[{"ID":"15","programName":"name","PLAYLIST":"","Width":"400","Height":"400"}]}
   * @param ID 必选 string 节目ID
   * @param programName 必选 string 节目名称
   * @param PLAYLIST 必选 string playlist.json文件中的内容
   * @param Width 必选 string 节目分辨率的宽
   * @param Height 必选 string 节目分辨率的高
   * @param templates 必选 object 自定义模版信息
   * @param width 必选 int 模板中窗口宽度
   * @param height 必选 int 模板中窗口高度
   * @param left 必选 float 模板中窗口左边占比
   * @param top 必选 float 模板中窗口上边占比
   * @param zindex 必选 int Z序
   * @param index 必选 int 模板中窗口窗口的ID
   * @param width 必选 int 模板的宽度
   * @param templates 必选 int 自定义模版信息
   * @return ""
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    void nvDataBaseMigrationAsync(const char *data, ExportViplexCallback(callBack));

    /**
   * showdoc
   * @catalog 接口示例/其他/下载缩略图
   * @title 下载缩略图
   * @description 下载缩略图的接口
   * @method
   * @url void nvDownLoadFiles(const char *data, ExportViplexCallback callBack);
   * @json_param {"sn":"BZSA07194A0049999716","remotePathsAndFileNames":{"sdcard/nova/viplex_terminal/program/program_DANGJT-P1/tu1/35384db4-d10a-4db8-a1fe-54479706376f.png":"1.png","sdcard/nova/viplex_terminal/program/program_DANGJT-P1/tu2/296653e7-814c-4fad-9198-c731c0770d8c.png":"2.png"},"downLoadDirectoryPath":"/data/data/com.example.myhandy_android/app_flutter/log","fileType":".png"}
   * @param sn 必选 string 产品唯一序列号
   * @param remotePathsAndFileNames 必选 map {"需要下载缩略图文件路径":"自定义文件名称"}
   * @param downLoadDirectoryPath 必选 string 指定路径，缩略图下载到这个路径下
   * @param fileType 必选 string 文件类型
   * @return ""
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvDownLoadFilesAsync(const char *data, ExportViplexCallback callBack);

    /**
   * showdoc
   * @catalog 接口示例/其他/获取指定路径下指定类型文件
   * @title 获取指定路径下指定类型文件
   * @description 获取指定路径下指定类型文件的接口
   * @method
   * @url void nvQueryFileByType(const char *data, ExportViplexCallback callBack);
   * @json_param {"paths":["C:/"],"types":[".txt"],"pageIndex":0,"pageSize":100}
   * @param paths 必选 string 需要查询的路径
   * @param types 必选 string 需要查询的文件类型
   * @param pageIndex 必选 int 每页显示的个数(暂未用到,可设置任意值)
   * @param pageSize 必选 int 查询的最大值(暂未用到,可设置任意值)
   * @return {"files":["C:/1.txt"]}
   * @return_param files stringarray 查询到的指定后缀类型的文件集合
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvQueryFileByTypeAsync(const char *data, ExportViplexCallback callBack);



#pragma region EditProgram
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 创建节目
    * @description 创建节目的接口
    * @method
    * @url  void nvCreateProgram(const char *data, ExportViplexCallback callBack)
    * @json_param {"name":"jiemu1","width":400,"height":400,"tplID":1}
    * @param name 必选 String 节目名称
    * @param width 必选 int 宽度
    * @param height 必选 int 高度
	* @param tplID 必选 int 模板ID
    * @return {"programID":1}
    * @return_param code int 错误码：`0`获取成功`65340`创建失败
    * @return_param data string 返回值错误码对应的详细信息
    * @return_param programID int 创建成功的节目id
    * @remark
    * @number 
    */
    VIPLEX_EXPORT void nvCreateProgramAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 编辑节目
    * @description 修改page的接口
    * @method
    * @url void nvSetPageParam(const char *data, ExportViplexCallback callBack)
    * @json_param {"programID":1,"pageID":1,"pageInfo":{"name":"pageNew","widgetContainers":[{"audioGroup":"","backgroundColor":"#00000000","backgroundDrawable":"","contents":{"widgetGroups":[],"widgets":[{"id":1,"mid":2,"name":"","type":"PICTURE","duration":10000,"repeatCount":1,"layout":{"x":"34.6%","y":"24.0%","width":"100%","height":"100%"},"displayRatio":"ORIGINAL","inAnimation":{"type":1,"duration":1000},"outAnimation":{"type":0,"duration":0},"dataSource":"26a0debe893d5c837270c60dde463913.png","originalDataSource":"D:/nova/dog.png","backgroundMusic":"/local/media/1.mp3","backgroundColor":"#00ff0000","backgroundDrawable":"/local/media/dog.png","zOrder":100,"constraints":[{"startTime":"2016-11-14T12:15:15Z+8:00","cron":[],"endTime":"2017-02-10T12:15:15Z+8:00"}],"fold":{"enable":true,"count":2,"orientation":"HORIZONTAL","layoutItems":[{"y":0,"height":200,"x":0,"width":200},{"y":200,"height":200,"x":0,"width":200}]},"metadata":""}]},"enable":true,"id":1,"itemsSource":"","layout":{"height":"100%","width":"100%","x":"0%","y":"0%"},"name":"widgetContainers1","pickCount":0,"pickPolicy":"ORDER","zOrder":0}]}}
    * @param programID 必选 int 节目id
    * @param pageID 必选 int pageId(当前版本pageId为1)
    * @param pageInfo 必选 Object page的详细信息
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时`65285`修改page失败
    * @return_param data string 返回值错误码对应的详细信息
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetPageParamAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 生成节目
    * @description 生成节目的接口
    * @method
    * @url void nvMakeProgram(const char *data, ExportViplexCallback callBack)
    * @json_param {"programID":1,"outPutPath":"test","mediasPath":[{"oldPath":"test","newPath":"test"}]}
    * @param programID 必选 int 节目id
    * @param outPutPath 必选 string 生成节目相关协议的路径
    * @param oldPath 必选 string 原文件路径(针对IOS获取不到原文件时使用)
    * @param newPath 必选 string 文件现路径(针对IOS获取不到原文件时，将源文件复制到某路径下)
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65338`创建Json文件时失败
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvMakeProgramAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 配置默认系统模板
    * @description 配置默认系统模板的接口
    * @method
    * @url void nvSetSystemTplInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"data":[{"data":[{"width":1,"height":1,"left":0,"top":0,"zindex":0,"index":0}]},{"data":[{"width":0.5,"height":1,"left":0,"top":0,"zindex":0,"index":0},{"width":0.5,"height":1,"left":0.5,"top":0,"zindex":1,"index":1}]},{"data":[{"width":1,"height":0.5,"left":0,"top":0,"zindex":0,"index":0},{"width":1,"height":0.5,"left":0,"top":0.5,"zindex":1,"index":1}]},{"data":[{"width":0.3333,"height":1,"left":0,"top":0,"zindex":0,"index":0},{"width":0.3333,"height":1,"left":0.3333,"top":0,"zindex":1,"index":1},{"width":0.3333,"height":1,"left":0.6666,"top":0,"zindex":2,"index":2}]},{"data":[{"width":1,"height":0.3333,"left":0,"top":0,"zindex":0,"index":0},{"width":1,"height":0.3333,"left":0,"top":0.3333,"zindex":1,"index":1},{"width":1,"height":0.3333,"left":0,"top":0.6666,"zindex":2,"index":2}]},{"data":[{"width":0.5,"height":0.5,"left":0,"top":0,"zindex":0,"index":0},{"width":0.5,"height":0.5,"left":0.5,"top":0,"zindex":1,"index":1},{"width":0.5,"height":0.5,"left":0,"top":0.5,"zindex":2,"index":2},{"width":0.5,"height":0.5,"left":0.5,"top":0.5,"zindex":3,"index":3}]}]}
    * @param width 必选 int 高度
    * @param height 必选 int 高度
    * @param left 必选 float 左边占比
    * @param top 必选 float 上边占比
    * @param zindex 必选 int Z序
    * @param index 必选 int 小窗口的ID
    * @return "success"
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvSetSystemTplInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 添加用户自定义模板
    * @description 添加用户自定义模板的接口
    * @method
    * @url void nvAddTpl(const char *data, ExportViplexCallback callBack)
    * @json_param {"data":[{"data":[{"width":1,"height":1,"left":0,"top":0,"zindex":0,"index":0}]}],"size":{"width":400,"height":400}}
    * @param width 必选 int 宽度
    * @param height 必选 int 高度
    * @param left 必选 float 左边占比
    * @param top 必选 float 上边占比
    * @param zindex 必选 int Z序
    * @param index 必选 int 小窗口的ID
    * @param width 必选 int 模板的宽度
    * @param height 必选 int 模板的高度
    * @return {"tplID":1}
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 返回值错误码对应的说明
    * @return_param tplID int 增家的模板ID
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvAddTplAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 编辑用户自定义模板
    * @description 编辑用户自定义模板的接口
    * @method
    * @url void nvEditTpl(const char *data, ExportViplexCallback callBack)
    * @json_param {"tplID":1,"data":[{"data":[{"width":1,"height":1,"left":0,"top":0,"zindex":0,"index":0}]}],"size":{"width":400,"height":400},"isSystemTpl":true}
    * @param tplID 必选 int 模板id
    * @param width 必选 int 宽度
    * @param height 必选 int 高度
    * @param left 必选 float 左边占比
    * @param top 必选 float 上边占比
    * @param zindex 必选 int Z序
    * @param index 必选 int 小窗口的ID
    * @param width 必选 int 模板的宽度
    * @param height 必选 int 模板的高度
    * @return {"tplID":1}
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvEditTplAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 删除用户自定义模板
    * @description 删除用户自定义模板的接口
    * @method
    * @url void nvDeleteTpl(const char *data, ExportViplexCallback callBack)
    * @json_param {"tplID":[1,2,3]}
    * @param tplID 必选 intArray 模板id
    * @return {"tplID":1}
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvDeleteTplAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 获取本地节目
    * @description 获取本地节目的接口
    * @method
    * @url void nvGetProgram(const char *data, ExportViplexCallback callBack)
    * @json_param ""
    * @param data 必选 string data为任意字符串，“”或“任意string”
    * @return {"name":"jiemu1","programID":1,"height":400,"width":400,"page":{"id":1,"name":"page1","widgetContainers":[{"audioGroup":"","backgroundColor":"#00000000","backgroundDrawable":"","contents":{"widgetGroups":[],"widgets":[]},"enable":true,"id":1,"itemsSource":"","layout":{"height":"100%","width":"100%","x":"0%","y":"0%"},"name":"widgetContainers1","pickCount":0,"pickPolicy":"ORDER","zOrder":0}],"widgetGroups":[],"widgets":[]}]}}
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 返回值错误码对应的说明
    * @return_param name string 节目名称
    * @return_param programID int 节目的ID
    * @return_param height int 节目的宽
    * @return_param page int 节目page信息
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvGetProgramAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 删除本地节目
    * @description 删除本地节目的接口
    * @method
    * @url void nvDeleteProgram(const char *data, ExportViplexCallback callBack)
    * @json_param {"programID":[1,2,3]}
    * @param programID 必选 intArray 节目的ID数组
    * @return "success"
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvDeleteProgramAsync(const char *data, ExportViplexCallback callBack);



    VIPLEX_EXPORT void nvStartTransferProgramAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 取消节目发布
    * @description 取消节目发布的接口
    * @method
    * @url void nvStopProgramTransfer(const char *data, ExportViplexCallback callBack)
    * @json_param ""
    * @param data 必选 string data为任意字符串，""或任意string
    * @return "success"
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 返回值错误码对应的说明
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvStopProgramTransferAsync(const char *data, ExportViplexCallback callBack);

    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 获取模板列表
    * @description 获取模板列表的接口
    * @method
    * @url void nvGetCustomerTplAsync(const char *data, ExportViplexCallback callBack)
    * @json_param "string"
    * @param data 必选 string 参数data可以任意string,但是必须有该参数
    * @return {"templates":[{"data":[{"width":1,"height":1,"left":0,"top":0,"zindex":0,"index":0}]}],"size":{"width":400,"height":400},"isSystemTpl":true}
    * @return_param width int 宽度
    * @return_param height int 高度
    * @return_param left float 左边占比
    * @return_param top float 上边占比
    * @return_param index int 小窗口的ID
    * @return_param width int 模板宽度
    * @return_param height int 模板宽度
    * @return_param isSystemTpl bool 是否用户自定义模板
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @remark
    * @number 99
    */
    void nvGetCustomerTplAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/节目编辑
    * @title 获取媒体文件MD5码
    * @description 获取媒体文件MD5码的接口
    * @method
    * @url void nvGetFileMD5(const char *data, ExportViplexCallback callBack)
    * @json_param {"filePath":"C:/test/media"}
    * @param filePath 必选 string 媒体所在路径
    * @return "12d4sa654d564ddauioaj4163"
    * @return_param code int 错误码：`0`获取成功
    * @return_param data string 成功返回md5码,失败返回错误码对应的说明
    * @remark
    * @number 99
    */
    void nvGetFileMD5Async(const char *data, ExportViplexCallback callBack);
#pragma endregion EditProgram 节目编辑

#pragma region NodeServerList 节点服务器列表
    /**
 * showdoc
 * @catalog 接口示例/其他/节点服务器列表
 * @title 获取节点服务器列表
 * @description 获取硬盘存储信息
 * @method
 * @url void nvGetNodeServerList(const char *data, ExportViplexCallback callBack);
 * @json_param {"lang":"en"}
 * @param lang 必选 string 语言,英文:en,中文:zh-cn,日文:jp,韩文:kr,西班牙语:es,法语:fr
 * @return {"serverInfo":[{"islocal":true,"label":"aa","node":"www.baidu.com"}]}
 * @return_param islocal bool 外部存储空间总大小,单位G
 * @return_param diskAvailableSize float 是否是用户自定义添加的数据,true:用户自定义,false:服务器获取
 * @return_param label string 节点名称
 * @return_param node string 节点地址
 * @return_param code int 错误码:`0`获取成功`65535`请求超时
 * @remark
 * @number 99
 */
    VIPLEX_EXPORT void nvGetNodeServerListAsync(const char *data, ExportViplexCallback callBack);
    /**
 * showdoc
 * @catalog 接口示例/其他/节点服务器列表
 * @title 添加节点服务器
 * @description 添加对时服务器的接口
 * @method
 * @url void nvAddNodeServerList(const char *data, ExportViplexCallback callBack)
 * @json_param {"label":"aa","node":"www.baidu.com"}
 * @param label 必选 string 节点名称
 * @param node 必选 string 节点地址
 * @return "success"
 * @return_param code int 错误码：`0`获取成功`65535`请求超时
 * @return_param data string 返回值错误码对应的说明
 * @remark
 * @number 99
 */
    VIPLEX_EXPORT void nvAddNodeServerListAsync(const char *data, ExportViplexCallback callBack);
    /**
 * showdoc
 * @catalog 接口示例/其他/节点服务器列表
 * @title 删除节点服务器
 * @description 删除对时服务器列表，如果存在两条node和label都完全一致的数据，则删除第一条
 * @method
 * @url void nvDeleteNodeServerList(const char *data, ExportViplexCallback callBack)
 * @json_param {"label":"aa","node":"www.baidu.com"}
 * @param label 必选 string 节点名称
 * @param node 必选 string 节点地址
 * @return "success"
 * @return_param code int 错误码：`0`获取成功`65535`请求超时
 * @return_param data string 返回值错误码对应的说明
 * @remark
 * @number 99
 */
    VIPLEX_EXPORT void nvDeleteNodeServerListAsync(const char *data, ExportViplexCallback callBack);
    /**
 * showdoc
 * @catalog 接口示例/其他/节点服务器列表
 * @title 修改节点服务器
 * @description 修改对时服务器列表,修改服务器列表,如果存在两条node和label都完全一致的数据,则修改第一条
 * @method
 * @url void nvUpdateNetTimingInfo(const char *data, ExportViplexCallback callBack)
 * @json_param {"oldServer":{"label":"zhangsan","node":"123.123.123"},"newServer":{"label":"lisi","node":"111.111.111"}}
 * @param oldServer 必选 Object 被修改的服务器信息
 * @param label 必选 string 节点名称
 * @param node 必选 string 节点地址
 * @param newServer 必选 Object 修改后的服务器信息
 * @param label 必选 string 节点名称
 * @param node 必选 string 节点地址
 * @return "success"
 * @return_param code int 错误码：`0`获取成功`65535`请求超时
 * @return_param data string 返回值错误码对应的说明
 * @remark
 * @number 99
 */
    VIPLEX_EXPORT void nvChangeNodeServerListAsync(const char *data, ExportViplexCallback callBack);
    /**
 * showdoc
 * @catalog 接口示例/其他/节点服务器列表
 * @title 添加服务器列表
 * @description 添加服务器列表的接口
 * @method
 * @url void nvAddNetTimingInfoList(const char *data, ExportViplexCallback callBack)
 * @json_param {"serverInfo":[{"label":"aa","node":"www.baidu.com"},{"label":"aa","node":"www.baidu.com"}]}
 * @param serverInfo 必选 array 服务器列表数组
 * @param label 必选 string 节点名称
 * @param node 必选 string 节点地址
 * @return "success"
 * @return_param code int 错误码：`0`获取成功`65535`请求超时
 * @return_param data string 返回值错误码对应的说明
 * @remark
 * @number 99
 */
    VIPLEX_EXPORT void nvAddNodeServerInfoListAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion NodeServerList 


#pragma region feedback
    /**
    * showdoc
    * @catalog 接口示例/其他/意见反馈
    * @title 上传用户反馈信息
    * @description 上传用户反馈信息的接口
    * @method
    * @url void nvUploadFeedbackInfo(const char *data, ExportViplexCallback callBack)
    * @json_param {"sn":"","contact":"minyf@novastar.tech","description":"我的意见反馈描述双卡双待的","attacheds":[{"dir":"feedback/handy/20200301/abc.jpg"},{"dir":"feedback/handy/20200301/abc.zip"}]}
    * @param sn 必选 string 产品唯一标识号
    * @param contact 非必选 string 联系方式
    * @param description 必选 string 意见反馈描述
    * @param attacheds 非必选 Object 附件
    * @param dir 非必选 string 上传到阿里云的文件dir目录
    * @return {"logid":"225be01205","status":0,"data":"ok"}
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data Object 返回值具体描述
    * @return_param logid string 请求日志id
    * @return_param status int 结果返回状态，0-成功，非0代表失败，具体参考code码含义
    * @return_param errmsg string 错误时会返回错误描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvUploadFeedbackInfoAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/意见反馈
    * @title 取消上传意见反馈
    * @description 取消上传意见反馈的接口
    * @method
    * @url void nvUploadFeedBackFileState(const char *data, ExportViplexCallback callBack)
    * @json_param {"state":true}
    * @param state 非必选 bool true表示继续下载，false表示停止下载，默认为false
    * @return "success"
    * @return_param code int 错误码：`0`获取成功`65535`请求超时
    * @return_param data string 返回值具体描述
    * @remark
    * @number 99
    */
    VIPLEX_EXPORT void nvUploadFeedBackFileStateAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion feedback 用户反馈

#pragma region StatusCollector
    /**
    * @brief获取内存信息
    * @param const char * data
    * {
    *     "sn":"",
    *     "period":XXX
    * }
    * @param ExportViplexCallback callback只有如下三种情况会进行回调：
    1.参数不正确，无法解析
    2.请求成功
    3.请求失败
    * @returnVIPLEX_EXPORT void
    */
    VIPLEX_EXPORT void nvStartGetAvailableMemoryDataAsync(const char *data, ExportViplexCallback callBack);
    /**
    * @brief结束信息采集
    * @param const char * data
    * {
    *     "sn":"",
    *     "type":""
    * }
    * @param ExportViplexCallback callback只有如下三种情况会进行回调：
    1.参数不正确，无法解析
    2.请求成功
    3.请求失败
    * @returnVIPLEX_EXPORT void
    */
    VIPLEX_EXPORT void nvFinishDataAsync(const char *data, ExportViplexCallback callBack);


#pragma endregion StatusCollector

#pragma region BindingManager
    /**
 * showdoc
 * @catalog 接口示例/其他/绑定优化
 * @title 是否公有云
 * @description 是否公有云的接口
 * @method
 * @url void nvIsCommonCloud(const char *data, ExportViplexCallback callBack);
 * @json_param {"baseUrl":"https://api-cn.vnnox.com"}
 * @param baseurl 必选 string 播放器绑定地址
 * @return {"status":[10000],"data":{"isCloud":1}}
 * @return_param status intarray 返回服务端状态码:`10000`成功,`10306`url格式错误
 * @return_param code int 错误码:`0`获取成功`65535`请求超时
 * @remark
 * @number 99
 */
	VIPLEX_EXPORT void nvIsCommonCloudAsync(const char *data, ExportViplexCallback callBack);
    /**
 * showdoc
 * @catalog 接口示例/其他/绑定优化
 * @title 获取播放器唯一识别号
 * @description 获取播放器唯一识别号的接口
 * @method
 * @url void nvGetPlayerIdentifer(const char *data, ExportViplexCallback callBack）
 * @json_param {"baseUrl":"https://test-rest-k8s.vnnox.com","data":{"token":"f2972f5a403d5e13d1c6103f91bf78a58055bfd5","number":1}}
 * @param baseurl 必选 string 播放器绑定地址
 * @param token 必选 string 播放机交互TOKEN(播放器与服务器交互)
 * @param number 必选 int 申请的唯一标识的数量（int最大值为1000，超过1000，按照1000进行计算
 * @return {"status":[10000],"data":{"identifierList":["b518fd5c1ac9e6c68d20ed97c749b490"]}}
 * @return_param status intarray 返回服务端状态码:`10000`成功,`10201`http[header]中token为空`10202`http[header]中token错误
 * @return_param identifierList stringarray 申请的唯一标识号
 * @return_param code int 错误码:`0`获取成功`65535`请求超时
 * @remark
 * @number 99
 */
	VIPLEX_EXPORT void nvGetPlayerIdentiferAsync(const char *data, ExportViplexCallback callBack);
    /**
   * showdoc
   * @catalog 接口示例/其他/绑定优化
   * @title 播放器名称校验
   * @description 播放器名称校验的接口
   * @method
   * @url void nvIsExistPlayerName(const char *data, ExportViplexCallback callBack)
   * @json_param {"baseUrl":"https://test-rest-k8s.vnnox.com","data":{"token":"f2972f5a403d5e13d1c6103f91bf78a58055bfd5","playerName":"dangjintao"}}
   * @param baseurl 必选 string 播放器绑定地址
   * @param token 必选 string 播放机交互TOKEN(播放器与服务器交互)
   * @param playerName 必选 string 播放器名称
   * @return {"status":[10000],"data":{"playerName":"dangjintao"}}
   * @return_param status intarray 返回服务端状态码:`10000`成功,`10201`http[header]中token为空`10202`http[header]中token错误`10209`播放器名称格式错误`10210`播放器名称已存在
   * @return_param playerName  string 播放器名称
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
	VIPLEX_EXPORT void nvIsExistPlayerNameAsync(const char *data, ExportViplexCallback callBack);
    /**
    * showdoc
    * @catalog 接口示例/其他/绑定优化
    * @title 获取token值
    * @description 播放器名称校验的接口
    * @method
    * @url void nvGetToken(const char *data, ExportViplexCallback callBack);
    * @json_param {"baseUrl":"https://test-rest-k8s.vnnox.com","data":{"username":"gmt","password":"123456"}}
    * @param baseurl 必选 string 播放器绑定地址
    * @param username 必选 string 播放器用户名
    * @param password 必选 string 播放器密码
    * @return {"status":[10000],"data":{"token":"654ad5s64f65w46f5e456wa4f","timeout":3600}}
    * @return_param status intarray 返回服务端状态码:`10000`成功,`10001`用户名或密码错误
    * @return_param token string 播放机交互TOKEN（播放器与服务器交互，要将此TOKEN加入http协议header中）
    * @return_param timeout int token的超时时间(单位s)
    * @return_param code int 错误码:`0`获取成功`65535`请求超时
    * @remark
    * @number 99
    */
	VIPLEX_EXPORT void nvGetTokenAsync(const char *data, ExportViplexCallback callBack);
#pragma endregion 
    /**
   * showdoc
   * @catalog 接口示例/其他/获取时区列表
   * @title 获取时区列表
   * @description 获取时区列表的接口
   * @method
   * @url void nvGetTimeZone(const char *data, ExportViplexCallback callBack);
   * @json_param "anystring"
   * @param data 必选 string 参数data必须有,但是可以为任意string
   * @return {"Pacific/Midway":"中途岛 (UTC-11:00)","Pacific/Honolulu":"檀香山 (UTC-10:00)","America/Anchorage":"安克雷奇 (UTC-08:00)","America/Los_Angeles":"洛杉矶/美国太平洋 (UTC-07:00)","America/Tijuana":"提华纳/美国太平洋 (UTC-07:00)","America/Phoenix":"凤凰城美国山区 (UTC-07:00)","America/Chihuahua":"奇瓦瓦 (UTC-06:00)","America/Denver":"丹佛/美国山区 (UTC-06:00)","America/Costa_Rica":"哥斯达黎加/美国中部 (UTC-06:00)","America/Regina":"里贾纳/美国中部 (UTC-06:00)","America/Mexico_City":"墨西哥城/美国中部 (UTC-05:00)","America/Chicago":"芝加哥/美国中部 (UTC-05:00)","America/Bogota":"波哥大/哥伦比亚 (UTC-05:00)","America/New_York":"纽约/美国东部 (UTC-04:00)","America/Caracas":"加拉加斯/委内瑞拉 (UTC-04:30)","America/Barbados":"巴巴多斯/大西洋 (UTC-04:00)","America/Manaus":"马瑙斯/亚马逊 (UTC-04:00)","America/Santiago":"圣地亚哥 (UTC-03:00)","America/Sao_Paulo":"圣保罗 (UTC-03:00)","America/St_Johns":"圣约翰/纽芬兰 (UTC-04:00)","America/Argentina/Buenos_Aires":"布宜诺斯艾利斯 (UTC-03:00)","America/Montevideo":"蒙得维的亚/乌拉圭 (UTC-03:00)","America/Godthab":"戈特霍布 (UTC-02:00)","Atlantic/South_Georgia":"南乔治亚 (UTC-02:00)","Atlantic/Cape_Verde":"佛得角 (UTC-01:00)","Atlantic/Azores":"亚述尔群岛 (UTC+00:00)","Africa/Casablanca":"卡萨布兰卡 (UTC+00:00)","Europe/London":"伦敦/格林尼治 (UTC+00:00)","Africa/Brazzaville":"布拉扎维/西部非洲 (UTC+01:00)","Africa/Windhoek":"温得和克 (UTC+01:00)","Europe/Amsterdam":"阿姆斯特丹/中欧 (UTC+02:00)","Europe/Belgrade":"贝尔格莱德/中欧 (UTC+02:00)","Europe/Brussels":"布鲁塞尔/中欧 (UTC+02:00)","Europe/Sarajevo":"萨拉热窝/中欧 (UTC+02:00)","Africa/Harare":"哈拉雷/中部非洲 (UTC+02:00)","Africa/Cairo":"开罗/东欧 (UTC+02:00)","Asia/Beirut":"贝鲁特/东欧 (UTC+03:00)","Europe/Athens":"雅典/东欧 (UTC+03:00)","Europe/Helsinki":"赫尔辛基/东欧 (UTC+03:00)","Asia/Jerusalem":"耶路撒冷/以色列 (UTC+03:00)","Asia/Amman":"安曼/东欧 (UTC+03:00)","Europe/Minsk":"明斯克 (UTC+03:00)","Asia/Baghdad":"巴格达 (UTC+03:00)","Europe/Moscow":"莫斯科 (UTC+03:00)","Asia/Kuwait":"科威特 (UTC+03:00)","Africa/Nairobi":"内罗毕/东部非洲 (UTC+03:00)","Asia/Baku":"巴库 (UTC+05:00)","Asia/Tbilisi":"第比利斯 (UTC+04:00)","Asia/Yerevan":"埃里温 (UTC+04:00)","Asia/Dubai":"迪拜 (UTC+04:00)","Asia/Tehran":"德黑兰/伊朗 (UTC+04:30)","Asia/Kabul":"喀布尔/阿富汗 (UTC+04:30)","Asia/Karachi":"卡拉奇 (UTC+05:00)","Asia/Oral":"乌拉尔 (UTC+05:00)","Asia/Yekaterinburg":"叶卡捷林堡 (UTC+05:00)","Asia/Calcutta":"加尔各答 (UTC+05:30)","Asia/Colombo":"科伦坡 (UTC+05:30)","Asia/Katmandu":"加德满都/尼泊尔 (UTC+05:45)","Asia/Almaty":"阿拉木图 (UTC+06:00)","Asia/Rangoon":"仰光/缅甸 (UTC+06:30)","Asia/Krasnoyarsk":"克拉斯诺亚尔斯克 (UTC+07:00)","Asia/Bangkok":"曼谷 (UTC+07:00)","Asia/Shanghai":"北京/中国 (UTC+08:00)","Asia/Hong_Kong":"香港/中国 (UTC+08:00)","Asia/Irkutsk":"伊尔库茨克 (UTC+08:00)","Asia/Kuala_Lumpur":"吉隆坡 (UTC+08:00)","Australia/Perth":"佩思 (UTC+08:00)","Asia/Taipei":"台北时间 (UTC+08:00)","Asia/Seoul":"首尔 (UTC+09:00)","Asia/Tokyo":"东京/日本 (UTC+09:00)","Asia/Yakutsk":"雅库茨克 (UTC+09:00)","Australia/Adelaide":"阿德莱德 (UTC+09:30)","Australia/Darwin":"达尔文 (UTC+09:30)","Australia/Brisbane":"布里斯班 (UTC+10:00)","Australia/Hobart":"霍巴特 (UTC+10:00)","Australia/Sydney":"悉尼 (UTC+10:00)","Asia/Vladivostok":"符拉迪沃斯托克/海参崴 (UTC+10:00)","Pacific/Guam":"关岛 (UTC+10:00)","Asia/Magadan":"马加丹 (UTC+10:00)","Pacific/Majuro":"马朱罗 (UTC+12:00)","Pacific/Auckland":"奥克兰 (UTC+12:00)","Pacific/Fiji":"斐济 (UTC+12:00)","Pacific/Tongatapu":"东加塔布 (UTC+13:00)"}
   * @return_param code int 错误码:`0`获取成功`65535`请求超时
   * @remark
   * @number 99
   */
    VIPLEX_EXPORT void nvGetTimeZoneAsync(const char *data, ExportViplexCallback callBack);

#pragma endregion 其他  待补充
}



