﻿#pragma once
#include <string>
#include "singleheader/json.hpp"
#include "protocoljson.h"
#include <QtCore/QMetaType>
#include <QtCore/QVariant>
//#include "viplexcommon/spdlogger.h"
#include "viplexcommon/viplexcommon_global.h"

using namespace std;
using nlohmann::json;




namespace ns {
	VIPLEXCOMMON_EXPORT void to_json(json& j, const std::string &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, std::string &data);

	struct PlayerBindStatus
	{
		bool isBindPlayer;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerBindStatus &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerBindStatus &data);

	struct PlayerBindInfoData
	{
		PlayerBindStatus data;
		std::vector<int> status;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerBindInfoData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerBindInfoData &data);
}


namespace ns {
	struct LoginInfo
	{
		int m_id;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LoginInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LoginInfo &data);
}
namespace ns {
	struct ErrorDescription
	{
		string errorDescription;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ErrorDescription &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ErrorDescription &data);
}

//vector<int> getIntFromKey(const json &j, const std::string &key);
namespace ns {
	struct  StatusCode
	{
		vector<string> statusCodes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const StatusCode &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, StatusCode &data);
}
Q_DECLARE_METATYPE(ns::StatusCode);
namespace ns {
	//服务器地址请求信息
	struct HostData
	{
		string url;       //访问的服务器地址
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const HostData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, HostData &data);
}
Q_DECLARE_METATYPE(ns::HostData);


namespace ns {
	struct  RequestResultData
	{
		int result;
		string detail;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RequestResultData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RequestResultData &data);
}

namespace ns {
	//播放器列表请求信息
	struct PlayersData
	{
		string url;              //访问的服务器地址
		string userName;   //认证用户名
		string passWord;    //认证用户密码
		int playerType;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayersData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayersData &data);
}

namespace ns {

	//播放器详细信息
	struct PlayerInfo
	{
		string name;//播放器名称
		bool isUsed;//是否视同
		string identifier;//播放器编号
		string  playerIdentifier;//播放器唯一识别号（之前是本机的MAC）
		bool litePlayerRegister = false;//是否简单版播放器
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerInfo &data);

	//播放器列表信息
	struct ServerPlayerList
	{
		string url;
		string token;
		std::vector<ns::PlayerInfo> players; //播放器列表

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerPlayerList &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerPlayerList &data);
	//VIPLEXCOMMON_EXPORT void from_json1(const json& j, ServerPlayerList &data);


	//绑定认证信息
	struct  BoundingData
	{
		string baseUrl; //服务器地址
		bool isNewVnnox = false;
		string passWord;  //认证用户名
		string userName; //认证用户密码
		ServerPlayerList serverPlayers; //绑定的播放器
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BoundingData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BoundingData &data);
}



namespace ns {
	//播放方案存贮路径
	struct LocalFolder
	{
		string localFolderPath;//播放发难存储路径（包含媒体、HTML5组件、媒体文件）
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LocalFolder &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LocalFolder &data);
}


namespace ns {

	//矩形区域信息
	struct Layout
	{
		int x;
		int y;
		int width;
		int height;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Layout &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Layout &data);

	//播放显示区域比例信息
	struct FLayout
	{
		float x;
		float y;
		float width;
		float height;
	};

	//播放显示区域（协议传输的是字符串，因此这里用字符串对象进行接收）
	struct DisplayRect
	{
		string x = "0";
		string y = "0";
		string width = "400";
		string height = "400";
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const DisplayRect &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DisplayRect &data);
	//将协议中的字符串描述的百分比信息转化成FLOAT值
	VIPLEXCOMMON_EXPORT void rectToFLayout(const DisplayRect &rect, FLayout &layout);

	//播放屏幕属性
	struct  DisplayAttribute
	{
		DisplayRect layout;//播放窗口显示区域
		bool IsFullScreen = false;//是否全屏显示
		string TopType = "PLAYING";//播放置顶类型
		bool isPreView = false;//是否预览
		string backGroundColor;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const DisplayAttribute &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DisplayAttribute &data);

	//播放器对象
	struct  Player
	{
		int   playerId = 0; //播放屏幕ID
		DisplayAttribute displayAttribute;//播放屏幕属性
	};


	VIPLEXCOMMON_EXPORT void to_json(json& j, const Player &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Player &data);

}
Q_DECLARE_METATYPE(ns::DisplayRect*);
Q_DECLARE_METATYPE(ns::DisplayAttribute);
Q_DECLARE_METATYPE(ns::Player);

namespace ns {

	//播放任务
	struct Task
	{
		int playerId = 0;
		int taskId = 0;
		DisplayRect displayRect;
		int zOrder;
		string backgroundColor;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Task &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Task &data);

}
Q_DECLARE_METATYPE(ns::Task);

namespace ns {
	//播放页面
	struct Page
	{
		int playerId = 0;
		int taskId = 0;
		int layerId = 0;
		int pageId = 0;
		DisplayRect displayRect;
		string backgroundColor;
		string topType;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Page &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Page &data);

}
Q_DECLARE_METATYPE(ns::Page);

namespace ns {

	enum EnumOrientation
	{
		HORIZONTAL,//水平打折
		VERTICAL/*垂直打折*/
	};

	struct Fold {
		bool enable = false;
		int count = 1;
		string orientation;
		std::vector<Layout> layoutItemns;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Fold &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Fold &data);
}

//文本媒体
namespace ns {
	///播放媒体挂件

		//图片特效
	struct  Animation
	{
		int type = 0;
		long duration = 1000;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Animation &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Animation &data);

	//时间约束
	struct Constraint
	{
		string startTime;     //开始时间（只含时分秒）
		std::vector<string> cron;//时间约束的CRON表达式
		string endTime;     //结束时间（只含时分秒）
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Constraint &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Constraint &data);

	struct GeneralMetadata
	{
		SubType subType;
		std::string modelData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GeneralMetadata &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GeneralMetadata &data);

	struct ModelData
	{
		bool isSyn;
		string  zone;
		string zoneType;
		string lang;
		int width;
		int height;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ModelData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ModelData &data);
	struct  WidgetLayout
	{
		string x;
		string y;
		string width;
		string height;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WidgetLayout &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WidgetLayout &data);

};
Q_DECLARE_METATYPE(ns::Animation);
//Q_DECLARE_METATYPE(ns::Widget);


namespace ns {

	//字体
	struct  CustomFont
	{
		std::vector<string> family;
		string style;
		int size = 16;
		bool isUnderline = false;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CustomFont &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CustomFont &data);

	struct ColorfulTextEffect
	{
		string type;
		std::vector<std::string> colors;
		string texture;
		string tempTexturePath;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ColorfulTextEffect &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ColorfulTextEffect &data);
	//文字属性
	struct TextProperty
	{
		string backgroundColor;
		string textColor;
		CustomFont font;
		bool shadowEnable = false;
		int shadowRadius = 10;
		int shadowDx = 2;
		int shadowDy = 0;
		string shadowColor;
		bool strokeEnable;
		int strokeWidth;
		int letterSpacing = 0;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TextProperty &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TextProperty &data);

	//文本属性
	struct TextAttribute
	{
		//TextProperty title;
		//TextProperty pubTime;
		//TextProperty body;

		int key = 0;
		TextProperty textInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TextAttribute &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TextAttribute &data);


	//文本片段
	struct Seg
	{
		int attributeKey = 0; //对应的文本属性key
		string  content; //要显示的内容
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Seg &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Seg &data);

	//文本行
	struct Line
	{
		std::vector<Seg> segs;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Line &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Line &data);
	//文本段落
	struct  Paragraph
	{
		string  verticalAlignment;
		string horizontalAlignment;
		string backgroundColor = "#000000FF";
		int lineSpacing = 0;
		int letterSpacing = 0;
		std::vector<Line> lines;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Paragraph &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Paragraph &data);


	//页面切换效果描述
	struct PageSwitchAttributes
	{
		Animation inAnimation;
		int remainDuration = 10000;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PageSwitchAttributes &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PageSwitchAttributes &data);

	struct ScrollEffect
	{
		float speed = 1;
		//MoveType moveType = MoveType::MARQUEE_LEFT;
		string animation = "NONE";
		string headTailSpacing;
		bool isHeadTail = false;
		bool speedByPixelEnable = false;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScrollEffect &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScrollEffect &data);

	struct ScrollAttributes
	{
		ScrollEffect effecs;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScrollAttributes &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScrollAttributes &data);

	struct ScrollAttribute
	{
		ScrollAttributes scrollAttributes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScrollAttribute &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScrollAttribute &data);

	struct TextOffset
	{
		int x = 0;
		int y = 0;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TextOffset &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TextOffset &data);

	//图片组播放方式
	struct DisplayStyle
	{
		//SwitchingType type = SwitchingType::SCROLL;
		string type;
		bool singleLine = false;
		PageSwitchAttributes pageSwitchAttributes;
		ScrollAttributes scrollAttributes;
		//TextOffset offset;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DisplayStyle &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DisplayStyle &data);

	struct BackgroundMusic
	{
		bool isTextSync = false;
		int duration = 0;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BackgroundMusic &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BackgroundMusic &data);

	struct RichTextContent
	{
		DisplayStyle displayStyle;
		std::vector<TextAttribute> textAttributes;
		bool autoPaging;
		std::vector<Paragraph> paragraphs;
		BackgroundMusic baskgroundMusic;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const RichTextContent &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RichTextContent &data);
	//富文本
	struct RichTextInfo
	{
		string itemSource;
		RichTextContent content;
		string VerTextAlignment;
		string HorTextAlignment;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RichTextInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RichTextInfo &data);
}


namespace ns {

	//RSS媒体
	struct  RSSMetaData
	{
		long updatePeriod;
		bool titleEnable = false;
		bool pubTimeEnable = false;
		bool bodyEnable = false;
		bool bodyImageEnable = false;
		TextAttribute textAttributes;
		DisplayStyle displayStyle;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RSSMetaData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RSSMetaData &data);
}


namespace ns {

	//流媒体
	struct  StreamMediaData
	{
		string source;
		string protocolType;
		string videoType;
		int volume = 10000;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const StreamMediaData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, StreamMediaData &data);
}

//图片组媒体
namespace ns {

	struct PictureData
	{
		int Id;
		string dataSource;
		string originalDataSource;
		bool enable;
		int duration;
		Animation inAnimation;
		Animation outAnimation;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PictureData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PictureData &data);

	//图片组媒体
	struct  PictureGroupMediaData
	{
		std::vector<PictureData> pictures;
		DisplayStyle displayStyle;
		ScrollAttributes scrollAttributes;
		SwitchingType type = PAGE_SWITCH;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PictureGroupMediaData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PictureGroupMediaData &data);
}


namespace ns {

	struct PlayerLoc
	{
		int playerId = 0;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerLoc &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerLoc &data);

	struct TaskLoc :PlayerLoc
	{
		int taskId = 0;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskLoc &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskLoc &data);

	struct LayerLoc :TaskLoc
	{
		int layerId = 0;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LayerLoc &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LayerLoc &data);


	struct PageLoc :LayerLoc
	{
		int pageId = 0;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PageLoc &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PageLoc &data);

	struct ContainerLoc :PageLoc
	{
		int containerId = 0;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ContainerLoc &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ContainerLoc &data);
}

namespace ns {

	struct ReturnData
	{
		// If success, = id(playerid,taskid...)
		// else = error code;
		int result = 0;

		//If success, none
		//else, description
		string detail;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReturnData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReturnData &data);
}
namespace ns {

	struct MediaStatus
	{
		int playerId;
		int taskId;
		int layerId;
		int pageId;
		int containerId;
		int widgetId;

		/**
		* START, STOP, PAUSE,...
		*/
		int state;
		/**
		* optional
		*/
		int value;

		MediaStatus()
		{}
		MediaStatus(int playerId, int taskId, int layerId, int pageId, int containerId, int widgetId, int state, int value = 0)
		{
			this->playerId = playerId;
			this->taskId = taskId;
			this->layerId = layerId;
			this->pageId = pageId;
			this->containerId = containerId;
			this->widgetId = widgetId;
			this->state = state;
			this->value = value;
		}
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaStatus &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaStatus &data);
}
namespace ns {

	struct NtpData
	{
		bool enable;
		string server;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const NtpData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, NtpData &data);

	struct CorrectTimeData
	{
		bool enable;
		NtpData ntpData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CorrectTimeData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CorrectTimeData &data);
}
namespace ns {

	struct AppInfo {

		int  pid;
		string apppath;
		string appname;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AppInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AppInfo &data);
}

namespace ns {
	struct AccelarateEnable
	{
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AccelarateEnable &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AccelarateEnable &data);
}

namespace ns {
	struct VideoPath
	{
		string path;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VideoPath &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VideoPath &data);
}

namespace ns {
	struct Duration
	{
		long VideoDuration;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Duration &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Duration &data);
}


namespace ns {
	struct DetailDescription
	{
		int code;
		string message;
		DetailDescription(string message, int code)
		{
			this->code = code;
			this->message = message;
		}
	};
}

namespace ns {
	//服务器列表
	struct Server
	{
		std::string name;   //别名
		std::string address;    //服务器地址
		bool bCustom = false;   //是否自定义添加
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Server &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Server &data);

	struct Servers
	{
		map<std::string, vector<Server>>servers;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Servers &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Servers &data);
}

namespace ns {
	struct  TaskData
	{
		int taskID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskData &data);
}

namespace ns {
	struct  NEWTextProperty
	{
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const NEWTextProperty &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, NEWTextProperty &data);
}




namespace ns
{
	struct SolidText
	{
		std::string text;
		NEWTextProperty textAttributes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SolidText &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SolidText &data);
}

namespace ns
{
	//数字时钟
	struct DigitalClock
	{
		std::string zone;
		std::string gmt;
		std::string regular;
		std::vector<string> weekTemplates;
		std::vector<string> suffixTemplates;
		SolidText solidText;
		//bool isDisplayMilliseconds = false;
		TextProperty textAttributes;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DigitalClock &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DigitalClock &data);
}

namespace ns
{
	struct Units
	{
		std::string timerName;
		std::string zero;
		std::string singular;
		std::string plural;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Units &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Units &data);

	//计时媒体
	struct CountTimer
	{
		std::string regular;

		std::string regularNew;//判断单位单复数

		std::vector<Units> units;

		SolidText solidText;
		int64_t  targetDateTime;
		std::string countType;
		bool isDisplayMilliseconds = false;//是否显示秒
		TextProperty textAttributes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CountTimer &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CountTimer &data);
}

namespace ns
{
	//简单天气:区域
	struct Area
	{
		std::string country;
		std::string province;
		std::string city;
		std::string county;
		std::string cityCode;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Area &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Area &data);
}
namespace ns
{
	//简单天气:播放效果
	struct Effects
	{
		string animation;
		float speed;
		bool speedByPixelEnable;
		bool isHeadTail;
		std::string headTailSpacing;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Effects &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Effects &data);
}


namespace ns
{
	//简单天气
	struct SimpleWeather
	{
		Area area;
		int weatherSource;
		std::string language;
		std::string cityNewCode;
		std::string windSpeedUnit;
		std::string windType;
		string temperatureUnit;
		bool isShowUnit;
		std::string regular;
		bool isShowInOneLine;
		long refreshPeriod;
		Effects effects;
		TextProperty textAttributes;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SimpleWeather &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SimpleWeather &data);
}


namespace ns
{
	//背景音乐媒体资源
	struct AudioList
	{
		int id;
		int mid;
		std::string name;
		std::string dataSource;
		std::string originalDataSource;
		long duration;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AudioList &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AudioList &data);
}


namespace ns
{
	//背景音乐
	struct Audio
	{
		PlayPolicy playPolicy;
		std::vector<AudioList> audioLists;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Audio &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Audio &data);
}

namespace ns
{
	//实时媒体布局样式
	struct LayoutStyles
	{
		int type;//布局样式类型，0：间距 1:自定义标签，2：数值，3：单位，4：数值+单位
		HAlignment horizontalAlignment; //对齐方式
		VAlignment verticalAlignment = VCENTER;//垂直对齐方式
		int proportion; //范围
	};
	VIPLEXCOMMON_EXPORT void to_json(json &j, const LayoutStyles &data);
	VIPLEXCOMMON_EXPORT void from_json(const json&j, LayoutStyles &data);
	//媒体内容
	struct RegularContents
	{
		std::string key; //占位符
		std::string unit;//对应数值的单位
		int type;//对应不同单位的换算类型
		int compension;//补偿值
		std::vector<string> mediaTemplates; //风向
	};
	VIPLEXCOMMON_EXPORT void to_json(json &j, const RegularContents &data);
	VIPLEXCOMMON_EXPORT void from_json(const json&j, RegularContents &data);
	//实时媒体：温度
	struct RtMedia
	{
		long updatePeriod;
		std::string regular;
		TemperatureUnit temperatureUnit;
		int temperatureCompensation;
		SolidText solidText;
		TextProperty textAttributes; //固定文本属性，标签文本属性
		TextProperty valueTextAttributes;//数值文本属性
		TextProperty unitTextAttributes;//单位文本属性
		//2019-03-19添加
		DisplayStyle displayStyle;   //图片特效
		std::vector<LayoutStyles> layoutStyles;     //布局样式
		std::vector<RegularContents> regularContents; //媒体内容
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RtMedia &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RtMedia &data);
}


namespace ns
{
	struct ViplexQrect
	{
		int x;
		int y;
		int w;
		int h;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ViplexQrect &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ViplexQrect &data);

	struct ViplexParameter {

		ViplexQrect rect;
		bool doesHideMainUI;
		bool doespreview;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ViplexParameter &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ViplexParameter &data);

}

namespace ns {
	struct  ScreenShot
	{
		int width = -1;
		int height = -1;
		string type;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenShot &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenShot &data);
}

namespace ns {
	struct Scale
	{
		bool enable = true;
		string shape;
		int width = 0;
		int height = 0;
		string color;
		TextProperty textAttributes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Scale &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Scale &data);

	struct Hand
	{
		bool enable = true;
		string color;
		//string drawable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Hand &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Hand &data);

	struct  Background
	{
		string color = "#000000";
		//string drawable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Background &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Background &data);
}
namespace ns {
	struct ScreenShotReply
	{
		string path;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenShotReply &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenShotReply &data);
}

namespace ns {
	struct HdSerialNumber
	{
		string hdSerialNumber;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const HdSerialNumber &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, HdSerialNumber &data);
}



namespace ns {
	struct HourScale
	{
		string enable;
		string shape;
		int width = 0;
		int height = 0;
		string color;
	};

	struct  Date
	{
		bool enable = true;
		string regular;
		std::vector<string> weekTemplates;
		TextProperty textAttributes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Date &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Date &data);

	struct Text
	{
		bool enable = true;
		string text;
		TextProperty textAttributes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Text &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Text &data);

	struct AnalogClock
	{
		string zone;
		string gmt;
		Scale hourScale;
		Scale  minuteScale;
		Hand  hourHand;
		Hand  minuteHand;
		Hand secondHand;
		Background  background;
		Date  date;
		Text text;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AnalogClock &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AnalogClock &data);
}


namespace ns {
	struct ColorfulText
	{
		string content;
		ScrollAttributes scrollAttributes;
		TextProperty textAttributes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ColorfulText &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ColorfulText &data);



	struct EffectsofBorder
	{
		string animation;
		bool isHeadTail;
		int speed = 0;
		string headTailSpacing;
		bool speedByPixelEnable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const EffectsofBorder &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, EffectsofBorder &data);

	struct SDKBorder
	{
		string name;
		string borderThickness;
		string cornerRadius;
		string backgroundColor;
		int style;
		EffectsofBorder effects;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SDKBorder &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SDKBorder &data);

	struct  Widget
	{
		int id;//挂件编号
		//int mid;//媒体唯一编号
		string name;//挂件名称
		bool enable;//是否启用，默认为TRUE
		string type;//
		long duration;
		int repeatCount = 0;
		WidgetLayout layout;
		string displayRatio;
		Animation inAnimation;
		Animation outAnimation;
		string dataSource;
		string originalDataSource;
		string backgroundMusic;
		string backgroundColor;
		string backgroundDrawable;
		string originalMD5;
		int64_t mStartTimeMillis = 0;
		int64_t mEndTimeMillis = 0;
		int zOrder;
		//std::vector<Constraint> constraints;
		Constraint constraints;
		DigitalClock digitClockMetadata;
		AnalogClock analogClockMetadata;
		SimpleWeather simpleWeather;
		RichTextInfo richTextInfo;
		ScrollAttribute picture;
		//Fold fold;
		SDKBorder border;

	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Widget &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Widget &data);

}

namespace ns {
	struct  MediaInfo
	{
		int playerId;
		int taskId;
		int layerId = 0;
		int pageId;
		int containerId;
		ns::Widget widget;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaInfo &data);
}
namespace ns {

	struct  TrafficData
	{
		string type;
		long size;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TrafficData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TrafficData &data);
	struct TrafficInfo
	{
		string date;
		std::vector<TrafficData>traffics;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TrafficInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TrafficInfo &data);
}

namespace ns {
	VIPLEXCOMMON_EXPORT std::string getStringFromKey(const json &j);

	VIPLEXCOMMON_EXPORT std::vector<std::string> getStringsFromKey(const json &j);

	VIPLEXCOMMON_EXPORT std::vector<std::string> getStringsFromKey(const json &j, const std::string &key);

	std::map<std::string, std::string> getMapsFromKey(const json &j);
}

namespace ns {
	struct PlaylistUrl
	{
		std::string planUrl;
		std::string confUrl;
		std::string jobUrl;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlaylistUrl &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlaylistUrl &data);

}

#pragma region Region RequestBase

namespace ns {
	struct BaseRequestContent
	{
		string url;
		string method;
	};
}

namespace ns {
	struct BaseResponseContent
	{
		std::vector<int> status;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BaseResponseContent &content);
}

namespace ns {
	struct BaseResponse
	{
		string app;
		long long command;
		int contentType;
		long long requestId;
		BaseResponseContent _content;
		string url;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BaseResponse &response);
}

namespace ns {
	struct BaseRequest
	{
		string app;
		long long command;
		EnumContentType contentType;
		long long requestId;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BaseRequest &request);
}
#pragma endregion

#pragma region Region Websocket config
namespace ns {
	//websocket 配置请求信息
	struct WsConfigBody
	{
		std::string userName;   //认证用户名
		std::string passWord;    //认证用户密码		
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WsConfigBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WsConfigBody &body);
}

namespace ns {
	//websocket 配置请求信息
	struct WsConfigContent :BaseRequestContent
	{
		WsConfigBody body;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WsConfigContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WsConfigContent &content);
}

namespace ns {
	//websocket 配置请求信息
	struct WsConfigRequest :BaseRequest
	{
		WsConfigContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WsConfigRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WsConfigRequest &request);
}



namespace ns {
	//websocket 配置回复中数据部分
	struct WsConfigReplyData
	{
		bool isSupportWebsocket;   //是否支持
		std::string websocketUrl;    //websocket节点url		
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WsConfigReplyData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WsConfigReplyData &data);
}

namespace ns {
	//websocket 配置回复信息
	struct WsConfigReply
	{
		std::vector<EnumResponseStatus> status;
		WsConfigReplyData data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WsConfigReply &reply);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WsConfigReply &reply);
}
#pragma endregion

#pragma region Region PlayerList
namespace ns {
	//获取播放器列表请求信息
	struct PlayerListBody//:public HttpBaseBody
	{
		std::string userName;   //认证用户名
		std::string passWord;    //认证用户密码		
		int playerType;    //播放器类型，同步1，异步2
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerListBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerListBody &body);
}

namespace ns {
	//websocket 配置请求信息
	struct PlayerListContent //:public HttpBaseContent
	{
		string url;
		string method;
		PlayerListBody body;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerListContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerListContent &content);
}

namespace ns {
	//获取播放器列表请求信息
	struct PlayerListRequest //:public HttpBaseRequest
	{
		long requestId;
		PlayerListContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerListRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerListRequest &request);
}

namespace ns {
	//播放器列表数据
	struct PlayerListData
	{
		int requestId;
		string url;
		int result;
		std::string token;   //token
		std::vector<ns::PlayerInfo> playerList;    //播放器列表		
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerListData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerListData &data);
}

namespace ns {
	//播放器列表信息
	struct PlayerListResponse
	{
		std::vector<EnumResponseStatus> status;   //回复状态
		ns::PlayerListData data;    //播放器列表数据
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerListResponse &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerListResponse &info);
}
Q_DECLARE_METATYPE(ns::PlayerListResponse);
#pragma endregion	

#pragma region Verify Host
namespace ns {
	struct VerifyHostBody
	{
		std::string url;   //认证用户名

		VIPLEXCOMMON_EXPORT void Null() {};
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const VerifyHostBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VerifyHostBody &body);
}

namespace ns {
	//websocket 配置请求信息
	struct VerifyHostContent :BaseRequestContent
	{
		VerifyHostBody body;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ns::VerifyHostContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VerifyHostContent &body);
}

namespace ns {
	//websocket 配置请求信息
	struct VerifyHostRequest :BaseRequest
	{
		VerifyHostContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VerifyHostRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VerifyHostRequest &request);
}

namespace ns {
	//websocket 配置请求信息
	struct VerifyHostResponse
	{
		int result;
		long requestId;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VerifyHostResponse &response);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VerifyHostResponse &response);
}
#pragma endregion

#pragma region Region Token
namespace ns {
	struct TokenBody
	{
		string username;
		string password;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const TokenBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TokenBody &body);
}

namespace ns {
	struct TokenHeader
	{
		string baseUrl;
		TokenBody data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TokenHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TokenHeader &header);
}

namespace ns {
	struct TokenContent : BaseRequestContent
	{
		TokenBody body;
		TokenHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TokenContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TokenContent &content);
}

namespace ns {
	struct TokenRequest : BaseRequest
	{
		TokenContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TokenRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TokenRequest &request);
}

namespace ns {
	struct TokenResponseData
	{
		string token;
		string timeout;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TokenResponseData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TokenResponseData &data);
}

namespace ns {
	struct TokenResponse
	{
		std::vector<EnumResponseStatus>status;
		ns::TokenResponseData data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TokenResponse &response);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TokenResponse &response);
}
Q_DECLARE_METATYPE(ns::TokenResponse);
#pragma endregion

#pragma endregion

#pragma region Websocket Part	

#pragma region  Window

namespace ns {
	struct Window
	{
		int id;
		int height;
		int width;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Window &window);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Window &window);
}

namespace ns {
	struct WindowBody
	{
		std::vector<Window> window;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const WindowBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WindowBody &body);
}

namespace ns {
	struct WindowHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const WindowHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WindowHeader &header);
}

namespace ns {
	struct WindowContent :BaseRequestContent
	{
		WindowBody body;
		WindowHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WindowContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WindowContent &content);
}

namespace ns {
	struct WindowRequest :BaseRequest
	{
		WindowContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WindowRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WindowRequest &request);
}
#pragma endregion

#pragma region Region Binding
namespace ns {
	struct BindingBody
	{
		string url;
		string userName;
		string password;
		string productName;
		string platform;
		string platformSystem;
		string hostName;
		string hostIp;
		string softwareName;
		string softwareVersion;
		int playerType;
		string playerIdentifier;
		string identifier;
		string playerName;
		std::vector<ns::Window> window;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingBody &body);
}

namespace ns {
	struct BindingHeader
	{
		string token;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingHeader &header);
}

namespace ns {
	struct BindingContent :BaseRequestContent
	{
		BindingHeader header;
		BindingBody body;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingContent &content);
}

namespace ns {
	struct BindingRequest :BaseRequest
	{
		BindingContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingRequest &request);
}

namespace ns {
	struct BindingBodyPure
	{
		string productName;
		string platform;
		string platformSystem;
		string hostName;
		string hostIp;
		string softwareName;
		string softwareVersion;
		int playerType;
		string playerIdentifier;
		string identifier;
		string playerName;
		std::vector<ns::Window> window;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingBodyPure &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingBodyPure &body);
}

namespace ns {
	struct BindingContentPure :BaseRequestContent
	{
		BindingHeader header;
		BindingBodyPure body;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingContentPure &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingContentPure &content);
}

namespace ns {
	struct BindingRequestPure :BaseRequest
	{
		BindingContentPure content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingRequestPure &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingRequestPure &request);
}

namespace ns {
	struct BindingResponseContentData
	{
		string planUrl;
		string confUrl;
		string jobUrl;
		VIPLEXCOMMON_EXPORT void Null() {};
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingResponseContentData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingResponseContentData &data);
}

namespace ns {
	struct BindingResponseContent
	{
		BindingResponseContentData data;
		std::vector<EnumResponseStatus> status;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingResponseContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingResponseContent &content);

}

namespace ns {
	struct BindingResponse
	{
		string app;
		int command;
		BindingResponseContent content;
		int contentType;
		long requestId;
		string url;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindingResponse &response);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindingResponse &response);
}
#pragma endregion

#pragma region  FileSignature
namespace ns {
	struct FileSignatureBody
	{
		std::list<string> data;;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileSignatureBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileSignatureBody &body);
}

namespace ns {
	struct FileSignatureHeader
	{
		string token;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileSignatureHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileSignatureHeader &header);
}

namespace ns {
	struct FileSignatureContent :BaseRequestContent
	{
		std::list<string> body;
		FileSignatureHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileSignatureContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileSignatureContent &content);
}

namespace ns {
	struct FileSignatureRequest :BaseRequest
	{
		FileSignatureContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileSignatureRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileSignatureRequest &request);
}
namespace ns {
	struct FileSignatureResponseContent
	{
		std::vector<string> data;
		std::vector<int> status;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileSignatureResponseContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileSignatureResponseContent &content);
}

namespace ns {
	struct FileSignatureResponse :BaseRequest
	{
		FileSignatureResponseContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileSignatureResponse &response);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileSignatureResponse &response);
}
#pragma endregion

#pragma region Region HeartBeat
namespace ns {
	struct HeartBeatHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
		string version;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const HeartBeatHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, HeartBeatHeader &header);
}

namespace ns {
	struct HeartBeatBody
	{
		list<int> statusCode;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const HeartBeatBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, HeartBeatBody &body);
}

namespace ns {
	struct HeartBeatRequestContent
	{
		std::string url;
		std::string method;
		HeartBeatHeader header;
		HeartBeatBody body;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const HeartBeatRequestContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, HeartBeatRequestContent &content);
}

namespace ns {
	struct HeartBeatRequest
	{
		string app;
		long requestId;
		int command;
		int contentType;
		HeartBeatRequestContent content;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const HeartBeatRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, HeartBeatRequest &request);
}
#pragma endregion

#pragma region Region Online


namespace ns {
	struct OnlineBody
	{
		int passageway;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const OnlineBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OnlineBody &body);
}

namespace ns {
	struct OnlineHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const OnlineHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OnlineHeader &header);
}

namespace ns {
	struct OnlineContent :BaseRequestContent
	{
		OnlineHeader header;
		OnlineBody body;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const OnlineContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OnlineContent &content);
}

namespace ns {
	struct OnlineRequest :BaseRequest
	{
		OnlineContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const OnlineRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OnlineRequest &request);
}
#pragma endregion

#pragma region Region Version
namespace ns {
	struct SoftwareSubVersion
	{
		string playerVersion;
		string sereenServiceVersion;
		string hwServiceVersion;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const SoftwareSubVersion &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SoftwareSubVersion &request);
}

namespace ns {
	struct VersionBody
	{
		string productName;
		string platform;
		string platformSystem;
		string osVersion;
		string osVersionNumber;
		string fpgaVersion;
		string softwareMainVersion;
		SoftwareSubVersion softwareSubVersion;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const VersionBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VersionBody &body);
}

namespace ns {
	struct VersionHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const VersionHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VersionHeader &header);
}

namespace ns {
	struct VersionContent :BaseRequestContent
	{
		VersionBody body;
		VersionHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VersionContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VersionContent &content);
}

namespace ns {
	struct VersionRequest :BaseRequest
	{
		VersionContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VersionRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VersionRequest &request);
}

#pragma endregion

#pragma region Region MediaStatus
namespace ns {
	struct ProcessBody
	{
		int mid;
		long total;
		long download;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ProcessBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ProcessBody &body);

	struct MediaStatusBody
	{
		int type = 0;
		std::list<int> downloading;
		std::list<ProcessBody> process;
		std::list<int> completed;
		std::list<int> failed;

		void clear()
		{
			downloading.clear();
			process.clear();
			completed.clear();
			failed.clear();
		}

		void addFailedData(int tag)
		{
			failed.push_back(tag);
		}

		void addCompletedData(int tag)
		{
			completed.push_back(tag);
		}

		void addDownloadingData(ProcessBody body)
		{
			downloading.push_back(body.mid);
			process.push_back(body);
		}
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaStatusBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaStatusBody &body);
}

namespace ns {
	struct MediaStatusHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaStatusHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaStatusHeader &header);
}

namespace ns {
	struct MediaStatusContent :BaseRequestContent
	{
		MediaStatusBody body;
		MediaStatusHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaStatusContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaStatusContent &content);
}

namespace ns {
	struct MediaStatusRequest :BaseRequest
	{
		MediaStatusContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaStatusRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaStatusRequest &request);
}


namespace ns {
	struct ProgramStatusHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ProgramStatusHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ProgramStatusHeader &header);

	struct ProgramStatusBody
	{
		int status;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ProgramStatusBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ProgramStatusBody &body);
}

namespace ns {
	struct ProgramStatusContent :BaseRequestContent
	{
		ProgramStatusHeader header;
		ProgramStatusBody body;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ProgramStatusContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ProgramStatusContent &content);
}

namespace ns {
	struct ProgramStatusRequest :BaseRequest
	{
		ProgramStatusContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ProgramStatusRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ProgramStatusRequest &request);
}
#pragma endregion

#pragma region Region UploadInfo
namespace ns {
	struct UploadInfoBody
	{
		int logType;
		string date;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadInfoBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoBody &body);
}

namespace ns {
	struct UploadInfoHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadInfoHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoHeader &header);
}

namespace ns {
	struct UploadInfoContent :BaseRequestContent
	{
		UploadInfoBody body;
		UploadInfoHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadInfoContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoContent &content);
}

namespace ns {
	struct UploadInfoRequest :BaseRequest
	{
		UploadInfoContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadInfoRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoRequest &request);
}
namespace ns
{
	struct UploadInfoResponseData
	{
		string sessionID;
		string uploadHost;
		bool isUpload;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoResponseData &response);
}
namespace ns {
	struct UploadInfoResponseContent
	{
		UploadInfoResponseData data;
		vector<int> status;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoResponseContent &response);
}
namespace ns
{
	struct UploadInfoResponse
	{
		UploadInfoResponseContent content;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoResponse &response);
}
namespace ns {
	struct UploadInfoLogBody
	{
		string data;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadInfoLogBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoLogBody &body);
}

namespace ns {
	struct UploadInfoLogHeader
	{
		string contentType;
		string fileName;
		string sessionID;
		int contentLength;
		string range;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadInfoLogHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoLogHeader &header);
}

namespace ns {
	struct UploadInfoLogContent :BaseRequestContent
	{
		UploadInfoLogBody body;
		UploadInfoLogHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadInfoLogContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoLogContent &content);
}

namespace ns {
	struct UploadInfoLogRequest :BaseRequest
	{
		UploadInfoLogContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadInfoLogRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadInfoLogRequest &request);
}
namespace ns
{
	struct ResponseStatus
	{
		int status = -1;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ResponseStatus &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ResponseStatus &data);
}
namespace ns
{
	struct LogFileInfo
	{
		string in;//媒体播放开始时间
		string out;//媒体播放结束时间
		long duration;//播放持续时长
		int widgetId;
		int widgetContainerId;
		int widgetGroupId;
		int pageId;
		int taskId;
		string mediaName;
		int mid;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LogFileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LogFileInfo &data);

}
namespace ns
{
	struct PlayLogPathInfo
	{
		string url;//播放日志路径
		vector<string> logList;//日志文件名集合
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayLogPathInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayLogPathInfo &data);
}

namespace ns
{
	struct Schema
	{
		string in;
		string out;
		long duration;
		int windowId;
		int taskId;
		int pageId;
		string mediaName;
		int mid;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Schema &data);
}
namespace ns
{
	struct LogContent
	{
		string logStartDate;
		string logEndDate;
		string identifier;
		string playerIdentifier;
		vector<Schema> schema;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LogContent &data);
}
namespace ns
{
	struct ReportRuntimeUploadBody
	{
		string date;
		string tempPath;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportRuntimeUploadBody &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportRuntimeUploadBody &content);
}
namespace ns {
	struct ReportRuntimeUploadContent :BaseRequestContent
	{
		ReportRuntimeUploadBody body;
		UploadInfoHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportRuntimeUploadContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportRuntimeUploadContent &content);
}

namespace ns {
	struct ReportRuntimeUploadRequest :BaseRequest
	{
		ReportRuntimeUploadContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportRuntimeUploadRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportRuntimeUploadRequest &request);
}
namespace ns
{
	struct ReportRuntimeUploadResponseContent
	{
		vector<int> status;
		string data;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportRuntimeUploadResponseContent &request);
}
namespace ns
{
	struct ReportRuntimeUploadResponse
	{
		ReportRuntimeUploadResponseContent content;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportRuntimeUploadResponse &request);
}

#pragma endregion

#pragma region Region TaskExecutionInfo
namespace ns {
	struct TaskExecutionInfoBody
	{
		int platform;
		string taskType;
		string taskAction;
		string softwareVersion;
		int playerType;
		string startTime;
		string endTime;
		int taskStatus;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskExecutionInfoBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskExecutionInfoBody &body);
}
Q_DECLARE_METATYPE(ns::TaskExecutionInfoBody);

namespace ns {
	struct TaskExecutionInfoHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskExecutionInfoHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskExecutionInfoHeader &header);
}

namespace ns {
	struct TaskExecutionInfoContent :BaseRequestContent
	{
		TaskExecutionInfoBody body;
		TaskExecutionInfoHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskExecutionInfoContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskExecutionInfoContent &content);
}

namespace ns {
	struct TaskExecutionInfoRequest :BaseRequest
	{
		TaskExecutionInfoContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskExecutionInfoRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskExecutionInfoRequest &request);
}

namespace ns {
	struct TaskExecutionInfoResponse
	{
		vector<int> status;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskExecutionInfoResponse &response);
}
#pragma endregion

#pragma region Region ImmediatelyJobInfo
namespace ns {
	struct ImmediatelyJobInfoBody
	{

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ImmediatelyJobInfoBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ImmediatelyJobInfoBody &body);
}

namespace ns {
	struct ImmediatelyJobInfoHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ImmediatelyJobInfoHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ImmediatelyJobInfoHeader &header);
}

namespace ns {
	struct ImmediatelyJobInfoContent :BaseRequestContent
	{
		ImmediatelyJobInfoBody body;
		ImmediatelyJobInfoHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ImmediatelyJobInfoContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ImmediatelyJobInfoContent &content);
}

namespace ns {
	struct ImmediatelyJobInfoRequest :BaseRequest
	{
		ImmediatelyJobInfoContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ImmediatelyJobInfoRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ImmediatelyJobInfoRequest &request);
}
#pragma endregion

#pragma region Region ConfInfo
namespace ns {
	struct ConfInfoBody
	{

	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfInfoBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfInfoBody &body);
}

namespace ns {
	struct ConfInfoHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfInfoHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfInfoHeader &header);
}

namespace ns {
	struct ConfInfoContent :BaseRequestContent
	{
		ConfInfoBody body;
		ConfInfoHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfInfoContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfInfoContent &content);
}

namespace ns {
	struct ConfInfoRequest :BaseRequest
	{
		ConfInfoContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfInfoRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfInfoRequest &request);
}
#pragma endregion

#pragma region Region FileDownload
namespace ns {
	struct Download
	{
		string id;
		long download;
		long total;
		int status;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Download &download);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Download &download);
}

namespace ns {
	struct FileDownloadBody
	{
		std::list<Download> downloadList;

		void clear()
		{
			downloadList.clear();
		}

		void addDownloadData(Download download)
		{
			bool res = false;
			for (auto &down : downloadList)
			{
				if (down.id == download.id)
				{
					res = true;
					down.download = download.download;
					down.total = download.total;
					down.status = download.status;
					break;
				}
			}
			if (!res)
			{
				downloadList.push_back(download);
			}
		}
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileDownloadBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileDownloadBody &body);
}

namespace ns {
	struct FileDownloadHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileDownloadHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileDownloadHeader &header);
}

namespace ns {
	struct FileDownloadContent :BaseRequestContent
	{
		FileDownloadBody body;
		FileDownloadHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileDownloadContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileDownloadContent &content);
}

namespace ns {
	struct FileDownloadRequest :BaseRequest
	{
		FileDownloadContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileDownloadRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileDownloadRequest &request);
}
#pragma endregion

#pragma region Region ReportStatus
namespace ns {
	struct Update
	{
		string id;
		string platform;
		string time;
		int status;
		int reason;
		string softwareVersion;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Update &download);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Update &download);
}

namespace ns {
	struct ReportStatusBody
	{
		std::list<Update> updateList;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportStatusBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportStatusBody &body);
}

namespace ns {
	struct ReportStatusHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportStatusHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportStatusHeader &header);
}

namespace ns {
	struct ReportStatusContent :BaseRequestContent
	{
		ReportStatusBody body;
		ReportStatusHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportStatusContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportStatusContent &content);
}

namespace ns {
	struct ReportStatusRequest :BaseRequest
	{
		ReportStatusContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportStatusRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportStatusRequest &request);
}
#pragma endregion

#pragma region Region ReportMediaDisk
namespace ns {
	struct Disk
	{
		string diskName;
		long long diskSize;
		long long diskUsed;
		long long mediaUsed;
		long long reserveSize;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Disk &download);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Disk &download);
}

namespace ns {
	struct ReportMediaDiskBody
	{
		std::list<Disk> disks;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportMediaDiskBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportMediaDiskBody &body);
}

namespace ns {
	struct ReportMediaDiskHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportMediaDiskHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportMediaDiskHeader &header);
}

namespace ns {
	struct ReportMediaDiskContent :BaseRequestContent
	{
		ReportMediaDiskBody body;
		ReportMediaDiskHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportMediaDiskContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportMediaDiskContent &content);
}

namespace ns {
	struct ReportMediaDiskRequest :BaseRequest
	{
		ReportMediaDiskContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportMediaDiskRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportMediaDiskRequest &request);
}

#pragma endregion

#pragma region Region ReportComponent
namespace ns {
	struct Component
	{
		string md5;
		int status;
		string info;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Component &component);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Component &component);
}
Q_DECLARE_METATYPE(ns::Component);

namespace ns {
	struct ReportComponentBody
	{
		std::list<Component> components;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportComponentBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportComponentBody &body);

}
Q_DECLARE_METATYPE(ns::ReportComponentBody);

namespace ns {
	struct ReportComponentHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportComponentHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportComponentHeader &header);
}

namespace ns {
	struct ReportComponentContent :BaseRequestContent
	{
		ReportComponentBody body;
		ReportComponentHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportComponentContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportComponentContent &content);
}

namespace ns {
	struct ReportComponentRequest :BaseRequest
	{
		ReportComponentContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportComponentRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportComponentRequest &request);
}
#pragma endregion

#pragma region Region Components
namespace ns {
	struct Module
	{
		string path;
		string version;
		int size;
		bool is_free;
		string md5;
		string url;
		string fileSavePath;
		bool isUnZip;

		bool operator==(const Module & left)
		{
			if (path == left.path &&
				version == left.version &&
				size == left.size &&
				is_free == left.is_free &&
				md5 == left.md5 &&
				url == left.url)
			{
				return true;
			}
			return false;
		}
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Module &module);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Module &module);
}

namespace ns {
	struct ComponentsData
	{
		std::list<Module> modules;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ComponentsData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ComponentsData &data);
}

namespace ns {
	struct ComponentsBody
	{
		std::list<int> status;
		ComponentsData data;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ComponentsBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ComponentsBody &body);
}

namespace ns {
	struct ComponentsHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ComponentsHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ComponentsHeader &header);
}

namespace ns {
	struct ComponentsContent :BaseRequestContent
	{
		ComponentsBody body;
		ComponentsHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ComponentsContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ComponentsContent &content);
}

namespace ns {
	struct ComponentsRequest :BaseRequest
	{
		ComponentsContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ComponentsRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ComponentsRequest &request);
}


namespace ns {
	struct ComponentsResponse :BaseRequest
	{
		ComponentsBody content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ComponentsResponse &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ComponentsResponse &request);
}
#pragma endregion
#pragma endregion

#pragma region MyRegion

namespace ns
{
	struct JobDescription
	{
		std::string jobID;
		std::string taskName;
		JobType type;
		std::string md5;
		std::string url;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const JobDescription &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, JobDescription &request);
	struct JobData
	{
		std::string name;
		std::vector<JobDescription> item;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const JobData &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, JobData &request);

	struct Source
	{
		int type;
		int platform;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Source &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Source &data);

	struct JobsData
	{
		std::string setupType;
		std::string version;
		qint64 size;
		std::string updateType;
		std::string md5;
		std::string source;
		std::string scope;
	};

	struct ImmediatelyJobData
	{
		JobType jobType;
		JobsData data;
	};

	struct ImmediatelyJobInfo
	{
		Source source;
		std::vector<ImmediatelyJobData> jobs;
	};
}

#pragma endregion

namespace ns
{
	struct PlaylogData
	{
		std::string in;
		std::string out;
		qint64 duration;
		int widgetID;
		int widgetContainerID;
		int widgetGroupID;
		int pageID;
		int taskID;
		std::string mediaName;
		int mid;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlaylogData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlaylogData &data);

	struct Condition
	{
		std::vector<string> cron;
		//std::string action;
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Condition &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Condition &data);


	/* struct Conditions
	 {
		 std::vector<Condition> conditionVec;
	 };
	 VIPLEXCOMMON_EXPORT void to_json(json& j, const Conditions &data);
	 VIPLEXCOMMON_EXPORT void from_json(const json& j, Conditions &data);*/

	struct JobTaskInfo
	{
		std::string type;
		Source source;
		std::string action;
		std::string reason;
		bool enable;
		vector<Condition> conditions;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const JobTaskInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, JobTaskInfo &data);

	struct JobDescriptionFileTask
	{
		std::string taskName;
		std::string type;
		std::string md5;
		std::string url;
		int jobID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const JobDescriptionFileTask &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, JobDescriptionFileTask &data);

	struct JobDescriptionFileTasks
	{
		std::vector<JobDescriptionFileTask> tasks;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const JobDescriptionFileTasks &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, JobDescriptionFileTasks &data);

	struct JobDescriptionFileInfo
	{
		std::string name;
		JobDescriptionFileTasks jobDescriptionFileTasks;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const JobDescriptionFileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, JobDescriptionFileInfo &data);

}

//#pragma region Region MonitorAuth
//
//	namespace ns {
//		struct MonitorAuthBody 
//		{
//			int passageway;
//		};
//		VIPLEXCOMMON_EXPORT void to_json(json& j, const MonitorAuthBody &body);
//		VIPLEXCOMMON_EXPORT void from_json(const json& j, MonitorAuthBody &body);
//	}
//
//	namespace ns {
//		struct MonitorAuthHeader 
//		{
//			string token;
//			string playerIdentifier;
//			string identifier;
//		};
//		VIPLEXCOMMON_EXPORT void to_json(json& j, const MonitorAuthHeader &header);
//		VIPLEXCOMMON_EXPORT void from_json(const json& j, MonitorAuthHeader &header);
//	}
//
//	namespace ns {
//		struct MonitorAuthContent : BaseRequestContent
//		{
//			MonitorAuthBody body;
//			MonitorAuthHeader header;
//		};
//		VIPLEXCOMMON_EXPORT void to_json(json& j, const MonitorAuthContent &content);
//		VIPLEXCOMMON_EXPORT void from_json(const json& j, MonitorAuthContent &content);
//	}
//
//	namespace ns {
//		struct MonitorAuthRequest : BaseRequest
//		{
//			MonitorAuthContent content;
//		};
//		VIPLEXCOMMON_EXPORT void to_json(json& j, const MonitorAuthRequest &request);
//		VIPLEXCOMMON_EXPORT void from_json(const json& j, MonitorAuthRequest &request);
//	}
//#pragma endregion

namespace ns {
	struct MonitorAuthBody
	{
		int passageway;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MonitorAuthBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MonitorAuthBody &body);
}

namespace ns {
	struct MonitorAuthHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MonitorAuthHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MonitorAuthHeader &header);
}

namespace ns {
	struct MonitorAuthContent : BaseRequestContent
	{
		MonitorAuthBody body;
		MonitorAuthHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MonitorAuthContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MonitorAuthContent &content);
}

namespace ns {
	struct MonitorAuthRequest : BaseRequest
	{
		MonitorAuthContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MonitorAuthRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MonitorAuthRequest &request);
}
#pragma endregion

#pragma region Region reportCommand

namespace ns {
	struct reportCommandBody
	{
		long requstId;
		int status;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const reportCommandBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, reportCommandBody &body);
}

namespace ns {
	struct reportCommandHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const reportCommandHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, reportCommandHeader &header);
}

namespace ns {
	struct reportCommandContent :BaseRequestContent
	{
		reportCommandBody body;
		reportCommandHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const reportCommandContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, reportCommandContent &content);
}

namespace ns {
	struct reportCommandRequest : BaseRequest
	{
		reportCommandContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const reportCommandRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, reportCommandRequest &request);
}
#pragma endregion

#pragma region Region AutoCreatePlayer

namespace ns {
	struct AutoCreatePlayerBody
	{
		string username;
		string password;
		int playerType;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AutoCreatePlayerBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AutoCreatePlayerBody &body);
}

namespace ns {
	struct AutoCreatePlayerHeader
	{
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AutoCreatePlayerHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AutoCreatePlayerHeader &header);
}

namespace ns {
	struct AutoCreatePlayerContent : BaseRequestContent
	{
		AutoCreatePlayerBody body;
		AutoCreatePlayerHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AutoCreatePlayerContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AutoCreatePlayerContent &content);
}

namespace ns {
	struct AutoCreatePlayerRequest : BaseRequest
	{
		AutoCreatePlayerContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AutoCreatePlayerRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AutoCreatePlayerRequest &request);
}
#pragma endregion

#pragma region Region ScreenshotInfo

namespace ns {
	struct ScreenshotInfoBody
	{
		string playerName;
		string timeZone;
		string playerTime;
		string programName;
		string mediaInfo;
		int programSource;
		string programSourceName;
		string screenshotUrl;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenshotInfoBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenshotInfoBody &body);
}

namespace ns {
	struct ScreenshotInfoHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenshotInfoHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenshotInfoHeader &header);
}

namespace ns {
	struct ScreenshotInfoContent : BaseRequestContent
	{
		ScreenshotInfoBody body;
		ScreenshotInfoHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenshotInfoContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenshotInfoContent &content);
}

namespace ns {
	struct ScreenshotInfoRequest : BaseRequest
	{
		ScreenshotInfoContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenshotInfoRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenshotInfoRequest &request);
}
#pragma endregion

#pragma region Region TimeZoneInfo

namespace ns {
	struct TimeZoneInfoBody
	{
		string timeZone;
		string currentTime;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimeZoneInfoBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneInfoBody &body);
}

namespace ns {
	struct TimeZoneInfoHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimeZoneInfoHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneInfoHeader &header);
}

namespace ns {
	struct TimeZoneInfoContent : BaseRequestContent
	{
		TimeZoneInfoBody body;
		TimeZoneInfoHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimeZoneInfoContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneInfoContent &content);
}

namespace ns {
	struct TimeZoneInfoRequest :BaseRequest
	{
		TimeZoneInfoContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimeZoneInfoRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneInfoRequest &request);
}
#pragma endregion

#pragma region Region UploadMediaInfo

namespace ns {
	struct UploadMediaInfoBody
	{
		string type;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadMediaInfoBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadMediaInfoBody &body);
}

namespace ns {
	struct UploadMediaInfoHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadMediaInfoHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadMediaInfoHeader &header);
}

namespace ns {
	struct UploadMediaInfoContent :BaseRequestContent
	{
		UploadMediaInfoBody body;
		UploadMediaInfoHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadMediaInfoContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadMediaInfoContent &content);
}

namespace ns {
	struct UploadMediaInfoRequest : BaseRequest
	{
		UploadMediaInfoContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadMediaInfoRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UploadMediaInfoRequest &request);
}
#pragma endregion

#pragma region SQLDataStruct
namespace ns
{

	struct SQLPlayerBindingPlayerDataBody
	{
		string name;
		string identifier;
		bool isUsed;
		string playerIdentifier;
		bool litePlayerRegister;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLPlayerBindingPlayerDataBody &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLPlayerBindingPlayerDataBody &data);

	struct SQLPlayerBindingDataBody
	{
		string token;
		vector<SQLPlayerBindingPlayerDataBody> playerList;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLPlayerBindingDataBody &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLPlayerBindingDataBody &data);

	struct SQLPlayerBindingInfo
	{
		bool isBind;
		string baseUrl;
		string username;
		string password;
		SQLPlayerBindingDataBody data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLPlayerBindingInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLPlayerBindingInfo &data);

	struct SQLCloudHeartbeatRequest
	{
		string token;
		string playerIdentifier;
		string identifier;
		string name;
		string url;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLCloudHeartbeatRequest &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLCloudHeartbeatRequest &data);

	struct SQLTrafficInfo
	{
		int64_t trafficSize;
		int64_t resetTempSize;
		int64_t tempSize;
		int64_t time;
		bool isNeedClear;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLTrafficInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLTrafficInfo &data);

	struct SQLNtpData
	{
		bool enable;
		string server;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLNtpData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLNtpData &data);

	struct SQLNetTime
	{
		bool enable;
		SQLNtpData ntp;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLNetTime &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLNetTime &data);

	struct SQLUpdateInfo
	{
		bool isServer;
		string packageType;
		string version;
		int64_t size;
		string md5;
		string source;
		string updateType;
		bool startupAfterInstalled;
		int scope;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLUpdateInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLUpdateInfo &data);

	struct SQLPlaylistUrl
	{
		string planUrl;
		string confUrl;
		string jobUrl;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLPlaylistUrl &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLPlaylistUrl &data);

	struct SQLPlanStatus
	{
		int status;
		string planJsonName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SQLPlanStatus &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SQLPlanStatus &data);

	struct taskInfoTableData
	{
		int id;
		std::string dbversion;
		std::string update;
		std::string screenTimeJob;
		std::string rebootTimeJob;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const taskInfoTableData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, taskInfoTableData &data);
}
#pragma endregion

#pragma region UPGRADVERIFY
namespace ns
{
	struct Packages
	{
		string type;
		std::vector<std::string> supportedProducts;
		std::vector<std::string> supportedPlatforms;
		string version;
		int64_t order;
		string name;
		string identifier;
		int64_t size; //升级包的大小
		bool startupAfterInstalled;
		bool isUpgradeAppAfterOS;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Packages &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Packages &data);

	struct PackageDescription
	{
		string version;//nuzip版本号
		int64_t totalSize;//升级包内部文件总大小
		string description;//描述信息
		ExcutionType excutionType;
		PacketType packetType;
		string createdDate;//创建日期
		std::vector<Packages> packages;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PackageDescription &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PackageDescription &data);
}
#pragma endregion

#pragma region ERRINFO
namespace ns
{
	struct Errinfo
	{
		string errorDiscription;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Errinfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Errinfo &data);
}
#pragma endregion

#pragma region update
namespace ns
{
	struct UpDateSource
	{
		int type;
		int platform;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpDateSource &source);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpDateSource &source);
}

namespace ns
{
	struct UpdateCondition
	{
		string start;
		std::vector<string> cron;
		string end;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdateCondition &condition);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdateCondition &condition);
}

namespace ns
{
	struct UpdateTask
	{
		string packageType;
		string version;
		string executionType;
		string source;
		std::vector<UpdateCondition>conditions;
		long size;
		string md5;
		string updateType;
		bool startupAfterInstalled;
		bool startupAfterBoot;
		bool checkFeasibility;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdateTask &task);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdateTask &task);
}

namespace ns
{
	struct CSUpdate
	{
		string type;
		bool isLocal;
		Source source;
		std::vector<UpdateTask> tasks;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CSUpdate &update);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CSUpdate &update);
}

namespace ns {
	struct UpdateInfo
	{
		string upgradeFilePath;  // 升级文件 路径/*.exe     
		string workingDirectory;  //proto.exe工作目录  
		string version;       //升级文件版本号  2.0.0  不带v
		bool isUpdate = false;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdateInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdateInfo &info);
}
#pragma endregion

#pragma region Version4CS
namespace ns {
	struct Version4CSResult
	{
		string packageName;
		string versionName;
		int versionCode;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Version4CSResult &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Version4CSResult &result);
}

namespace ns {
	struct InstalledPackageVersions
	{
		std::vector<Version4CSResult> result;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const InstalledPackageVersions &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, InstalledPackageVersions &result);
}

namespace ns {
	struct Version4CS
	{
		string fpga;
		string model;
		string mainVersion;
		string productName;
		string aliasName;
		string mac;
		string registerAddress;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Version4CS &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Version4CS &info);
}

namespace ns {
	struct ConfigInfo_productInfo
	{
		string productName;
		int modelId = 0;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfigInfo_productInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfigInfo_productInfo &info);
}
namespace ns {
	struct ConfigInfo_portConfig
	{
		bool isMainPort = false;
		int portNO = 0;
		int belongMainPort = 0;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfigInfo_portConfig &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfigInfo_portConfig &info);
}
namespace ns {
	struct ConfigInfo_configInfo
	{
		bool videoSwitch = false;
		string displayDevice;
		std::vector<ns::ConfigInfo_portConfig> portConfigs;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfigInfo_configInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfigInfo_configInfo &info);
}

namespace ns {
	struct ConfigInfo
	{
		ns::ConfigInfo_productInfo productinfo;
		ns::ConfigInfo_configInfo configinfo;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfigInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfigInfo &info);
}
namespace ns {
	struct ScreenMosaicInfo
	{
		int order = 0;
		int videoSource = 0;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenMosaicInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenMosaicInfo &info);
}

#pragma endregion

#pragma region Playlist4CS
namespace ns {
	struct Solution
	{
		string name;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Solution &solution);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Solution &solution);
}

namespace ns {
	struct SolutionStart
	{
		string deviceIdentifier;
		long totalSize;
		string type;
		int source;
		bool local;
		Solution solutions;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const SolutionStart &solution);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SolutionStart &solution);
}

namespace ns {
	//struct ConfirmedInfos
	//{
	//	string identifier;
	//	string name;
	//	string planListUrl;
	//	string thumbnailUrl;
	//	bool isSupportMd5Checkout;
	//};

	//VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfirmedInfos &info);
	//VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfirmedInfos &info);
}

//namespace ns {
//	struct SolutionEnd
//	{
//		bool playImmediately;
//		ConfirmedInfos confirmedInfos;
//	};
//
//	VIPLEXCOMMON_EXPORT void to_json(json& j, const SolutionEnd &solution);
//	VIPLEXCOMMON_EXPORT void from_json(const json& j, SolutionEnd &solution);
//}

namespace ns {
	struct AppliedInfo
	{
		string name;
		string identifier;
		string uploadUrl;
		int fileSource;
		int statusCode;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const AppliedInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AppliedInfo &info);
}

namespace ns {
	struct SolutionStartResponse
	{
		bool canTranster;
		string uploadMediaUrl;
		int errorCode;
		AppliedInfo appliedInfos;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const SolutionStartResponse &response);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SolutionStartResponse &response);
}
#pragma endregion


#pragma region LoginData
namespace ns
{
	struct DissConnectData
	{
		string sn;
		int loginType = 0;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DissConnectData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DissConnectData &data);

	struct LoginData
	{
		string sn;
		string username;
		string password;
		int loginType = 0;
		int rememberPwd = 0;
		Source source;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LoginData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LoginData &data);


	struct LoginReplySuccessData
	{
		string sn;
		string username;
		string password;
		bool validation;
		bool validition;
		bool logined;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LoginReplySuccessData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LoginReplySuccessData &data);

	struct LoginReplyData
	{
		string sn;
		string username;
		string password;
		bool validation;
		bool validition;
		bool logined;
		std::vector<std::string> loginedUsernames;
		string encrypt;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LoginReplyData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LoginReplyData &data);

	struct LoginErrorData
	{
		string errorDiscription;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LoginErrorData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LoginErrorData &data);

	struct ContinuousLoginErrorData
	{
		string errorDiscription;
		int mRemainTime;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ContinuousLoginErrorData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ContinuousLoginErrorData &data);

	struct ChangePassword
	{
		string username;
		string password;
		string newPassword;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ChangePassword &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ChangePassword &data);

	struct ChangePasswordWithSN
	{
		string sn;
		ChangePassword cp;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ChangePasswordWithSN &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ChangePasswordWithSN &data);


	struct RegisterAddressData
	{
		string country;
		string province;
		string city;
		string county;
		string address;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RegisterAddressData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RegisterAddressData &data);


	struct ChangeVPlayerName
	{
		string aliasName;
		RegisterAddressData registerAddressData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ChangeVPlayerName &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ChangeVPlayerName &data);
}
#pragma endregion

#pragma region DeviceInfo

namespace ns {
	//亮度模块支持的功能
	struct Brightness
	{
		bool Validity = false;
		bool CompleteCron = false;
		bool FloatValue = false;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Brightness &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Brightness &data);
}
namespace ns {
	//网络模块支持的功能
	struct NetWork
	{
		bool IsSupport = false;			//是否支持网络功能
		bool Wifi = false;		//是否支持WiFi(此字段为T卡1.3.3版本判断wifi支持的字段，上边WIFI字段废弃不用，但继续保留为了兼容)
		bool Wired = false;		//是否支持有线网络
		bool AP = false;		//是否支持AP网络
		bool Mobile = false;		//是否支持移动网络
		bool IsSupportNetWorkCheck = false;		//是否支持切换网络检测
		bool IsSupportMultiDns = false;		//是否支持多个DNS地址
		bool WiFiApSwitch = false;		//是否支持wifi-ap/station切换
		bool Apn = false;
		bool AirPlane = false;
		bool NetStateFor4G = false;
		bool Restart4GModule = false;
		bool WorkStateFor4G = false;
		bool Log4G = false;
		bool IsSupportSimModeSwitch = false;
		bool IsSupportGetModuleInfo = false;
		bool IsSupportModuleVersionUpdate = false;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const NetWork &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, NetWork &data);
}
namespace ns {
	//支持功能信息
	struct Input
	{
		bool IsSupport = false;			//是否支持输入源
		bool Hdmi = false;		//是否支持hdmi输入源
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Input &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Input &data);
}
namespace ns {
	//支持功能信息
	struct Output
	{
		bool IsSupport = false;			//是否支持输出源
		bool HdmiToLvds = false;		//是否支持hdmi与lvds输出源
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Output &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Output &data);
}
namespace ns {
	//视频源模块支持的功能(VIDEO_SOURCE_SWITCH字段不能满足express，故加此字段)
	struct VideoSource
	{
		bool IsSupport = false;			//是否支持视频源模块
		bool Hdmi = false;		//是否支持Hdmi视频源
		Input input;
		Output output;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VideoSource &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VideoSource &data);
}
namespace ns {
	//射频管理模块支持的功能
	struct RadioFrequencyManage
	{
		bool IsSupport = false;			//是否支持射频管理
		bool IsSupportLoraInfo = false;		//是否支持Lora信息检测功能
		bool IsSupportProduct = false;		//产品是否支持，主要指硬件是否支持该功能
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RadioFrequencyManage &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RadioFrequencyManage &data);
}
namespace ns {
	//升级模块
	struct Upgrade
	{
		bool IsSupportCheckValid = false;			//是否支持升级可行性检查
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Upgrade &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Upgrade &data);
}
namespace ns {
	//输出源模式
	struct SourceOutMode
	{
		bool IsSupportChangeSourceOutMode = false;			//是否支持输出源HDMI/DVI切换
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SourceOutMode &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SourceOutMode &data);
}
namespace ns {
	//运行时文件路径获取
	struct ZipRunningLog
	{
		bool IsSupportZipRunningLogInfo = false;			//是否支持输出源HDMI/DVI切换
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ZipRunningLog &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ZipRunningLog &data);
}
namespace ns {
	//接收卡相关功能
	struct ReceiveCard
	{
		bool IsSupport = false;			//是否支持多功能卡
		bool Config = false;			//是否支持多功能卡配置
		bool Temperature = false;			//是否支持多功能卡温度
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReceiveCard &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReceiveCard &data);
}
namespace ns {
	//配屏相关功能
	struct ScreenConfig
	{
		bool IsSupport = false;			//是否支持配屏相关功能
		bool Config = false;			//是否支持配置
		bool ScreenJoint = false;			//是否支持多屏拼接
		bool IsSupportProduct = false;			//产品是否支持，主要指硬件是否支持该功能
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenConfig &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenConfig &data);
}
namespace ns {
	//监控相关功能
	struct Monitoring
	{
		bool IsSupport = false;			//是否支持监控相关功能
		bool ClearMedia = false;			//是否支持清除媒体
		bool Memory = false;			//是否支持内存监控
		bool CPU = false;			//是否支持CPU监控
		bool AmbientBrightness = false;			//是否支持环境亮度监控
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Monitoring &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Monitoring &data);
}
namespace ns {
	//对时相关功能
	struct TimeControl
	{
		bool IsSupport = false;			//是否支持对时功能
		bool Manual = false;			//是否支持手动对时
		bool NTP = false;			//是否支持NTP对时
		bool Lora = false;			//是否支持lora对时
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimeControl &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeControl &data);
}
namespace ns {
	//分辨率相关功能
	struct Resolution
	{
		bool IsSupport = false;			//是否支持切换分辨率
		bool CustomResolution = false;			//是否支持自定义分辨率，上边CustomResolution字段废弃不用，但继续保留为了兼容
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Resolution &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Resolution &data);
}
namespace ns {
	//传感器子板相关功能
	struct SensorBoard
	{
		bool IsSupport = false;			//是否支持传感器子板
		bool SensorInfo = false;			//是否支持获取及设置传感器的信息(保留)
		bool IsSupportProduct = false;		//产品是否支持，主要指硬件是否支持该功能
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SensorBoard &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SensorBoard &data);
}
namespace ns {
	//旋转功能
	struct Rotation
	{
		bool IsSupport = false;			//是否支持旋转
		bool IsSupportProduct = false;		//产品是否支持，主要指硬件是否支持该功能
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Rotation &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Rotation &data);

	struct PlayManager
	{
		bool IsSupport = false;			//是否支持查看终端信息
		bool ProgramListManager = false;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayManager &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayManager &data);
}
namespace ns {
	//开关量外部设备调节功能， 红外感应设备（高低电平）
	struct InfraredDetector
	{
		bool IsSupport = false;			//是否支持外部设备调节
		bool IsSupportProduct = false;		//产品是否支持，主要指硬件是否支持该功能
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const InfraredDetector &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, InfraredDetector &data);
}
namespace ns {
	//支持功能信息
	struct config_info
	{
		bool REBOOT = false;		//是否支持重启
		bool SCREENPOWER = false;		//是否支持开关屏
		bool SYNC_PLAY = false;		//是否支持同步播放
		bool SPOTS = false;         //是否支持插播
		bool VIDEO_SOURCE_SWITCH = false;		//是否支持视频源切换
		bool UPDATE = false;		//是否支持升级功能
		bool SCREENSHOT = false;		//是否支持截屏功能
		bool TIMEZONE = false;		//是否支持设置/获取时区功能
		bool POWER = false;		//是否支持控制电源功能
		bool VOICE = false;		//是否支持控制音量功能
		bool LIGHT = false;		//是否支持控制亮度功能
		bool UPDATEOS = false;		//是否支持系统升级
		bool WIFI = false;		//是否支持wifi station
		bool CARE = false;		//是否支持Care
		bool VNNOX = false;		//是否支持vnnox
		bool PLAYLOG = false;		//是否支持播放日志
		bool COLORTEMPERATURE = false;		//是否支持色温
		bool INDICATORLIGHT = false;		//是否支持指示灯
		bool NEXUSFONT = false;		//是否支持字体管理
		bool NEWPROTOCOL = false;		//是否支持新协议
		bool RELAYPOWER = false;		//是否支持本板电源
		bool RELAYPOWERCONFIG = false;		//是否支持本板电源配置
		bool RESET = false;		//是否支持恢复出厂设置
		bool FIXEDPOINT = false;		//是否支持定点投放
		bool TERMINALINFO = false;		//是否支持终端信息
		bool CustomResolution = false;		//是否支持自定义分辨率
		Brightness brightness;		//亮度模块支持的功能
		NetWork netWork; 		//网络模块支持的功能
		VideoSource videoSource;  		//视频源模块支持的功能(VIDEO_SOURCE_SWITCH字段不能满足express，故加此字段)
		RadioFrequencyManage radioFrequencyManage; 		//射频管理模块支持的功能
		Upgrade upgrade; 		//升级模块
		SourceOutMode sourceOutMode; 		//输出源模式
		ZipRunningLog zipRunningLog; 		//运行时文件路径获取
		ReceiveCard receiveCard; 		//接收卡相关功能
		ScreenConfig screenConfig; 		//配屏相关功能
		Monitoring monitoring; 		//监控相关功能
		TimeControl timeControl; 		//对时相关功能
		Resolution resolution; 		//分辨率相关功能
		SensorBoard sensorBoard; 		//传感器子板相关功能
		Rotation  rotation; 		//旋转功能
		PlayManager playManager;
		InfraredDetector infraredDetector;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const config_info &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, config_info &data);
	const json &getDefaultConfigJson();
}

namespace ns {
	//终端支持功能列表信息
	struct PlayerFunctions
	{
		string version;	//"V1.3.0",
		config_info configInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerFunctions &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerFunctions &data);
}
#pragma endregion

#pragma region UpdateDescription

namespace ns
{
	struct Package
	{
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Package &data);
}

namespace ns
{
	struct Description
	{
		std::vector<Package>packages;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Description &data);
}
#pragma endregion

namespace ns {
	//播放绑定请求
	struct ServerType
	{
		bool value = true;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerType &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerType &data);


}

namespace ns {
	//请求g_jIdentifierList的个数request
	struct PlayerNumber
	{
		int number = 0;
		string token;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerNumber &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerNumber &data);

	//请求g_jIdentifierList的response
	struct IdentifierList
	{
		vector<string> identifierList;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const IdentifierList &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IdentifierList &data);

	//判断播放器名称是否正确request
	struct PlayerName
	{
		string playerName;
		string token;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerName &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerName &data);

	//播放器名称是否有效response
	struct ValidPlayerName
	{
		int value = 0;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const ValidPlayerName &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ValidPlayerName &data);

	struct BaseUrl
	{
		string baseurl;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BaseUrl &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BaseUrl &data);
}
Q_DECLARE_METATYPE(ns::PlayerNumber);
Q_DECLARE_METATYPE(ns::PlayerName);
Q_DECLARE_METATYPE(ns::ValidPlayerName);
Q_DECLARE_METATYPE(ns::IdentifierList);

namespace ns {
	struct UserInfo
	{
		string userName;   //认证用户名
		string passWord;    //认证用户密码
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UserInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UserInfo &data);
}
Q_DECLARE_METATYPE(ns::UserInfo);

namespace ns {
	//播放绑定请求
	struct PlayerBoundingInfo
	{
		string productName;
		string platform;
		string platformSystem;
		string hostName;
		string hostIp;
		string softwareName;
		string softwareVersion;
		int playerType;
		string playerIdentifier;
		string identifier;
		vector<Window> windows;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerBoundingInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerBoundingInfo &data);

	struct tokenData
	{
		string token;
		int status = 0;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const tokenData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, tokenData &data);
}

namespace ns
{


	struct Border
	{
		string foregroundColor;
		string backgroundColor;
		int width = 0;
		string borderSource;
		string originalBorderSource;
		string TempBorderBackgroud;
		int style = 0;
		int styleForExpress = 0;
		EffectsofBorder effects;
	};
}

namespace ns {
	//播放页面
	struct WidgetContainer
	{
		int playerId = 0;
		int taskId = 0;
		int layerId = 0;
		int pageId = 0;
		int containerId = 0;
		int zOrder = 0;
		DisplayRect displayRect;
		string backgroundColor;
		bool isSync = false;
		ns::Audio audio;
		ns::Border border;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const WidgetContainer &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WidgetContainer &data);
}
Q_DECLARE_METATYPE(ns::WidgetContainer);

namespace ns {
	//播放页面
	struct Preview
	{
		bool isPreview;
		Layout layout;
		string programPath;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const Preview &preview);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Preview &preview);
}
Q_DECLARE_METATYPE(ns::Preview);

#pragma region Region Identifier

namespace ns {
	struct IdentifierBody
	{
		int number;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IdentifierBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IdentifierBody &body);
}

namespace ns {
	struct IdentifierHeader
	{
		string token;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IdentifierHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IdentifierHeader &header);
}

namespace ns {
	struct IdentifierContent :BaseRequestContent
	{
		IdentifierBody body;
		IdentifierHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IdentifierContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IdentifierContent &content);
}

namespace ns {
	struct IdentifierRequest : BaseRequest
	{
		IdentifierContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IdentifierRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IdentifierRequest &request);
}

namespace ns {
	struct IdentifierResponseData
	{
		std::vector<string> identifierList;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IdentifierResponseData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IdentifierResponseData &data);
}

namespace ns {
	struct IdentifierResponse
	{
		std::vector<EnumResponseStatus>status;
		ns::IdentifierResponseData data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IdentifierResponse &response);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IdentifierResponse &response);
}
Q_DECLARE_METATYPE(ns::IdentifierResponse);
#pragma endregion


#pragma region Region PlayerExist

namespace ns {
	struct PlayerExistBody
	{
		string playerName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerExistBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerExistBody &body);
}

namespace ns {
	struct PlayerExistHeader
	{
		string token;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerExistHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerExistHeader &header);
}

namespace ns {
	struct PlayerExistContent :BaseRequestContent
	{
		PlayerExistBody body;
		PlayerExistHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerExistContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerExistContent &content);
}

namespace ns {
	struct PlayerExistRequest : BaseRequest
	{
		PlayerExistContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerExistRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerExistRequest &request);
}

namespace ns {
	struct PlayerExistResponseData
	{
		string playerName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerExistResponseData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerExistResponseData &data);
}

namespace ns {
	struct PlayerExistResponse
	{
		std::vector<EnumResponseStatus> status;
		ns::PlayerExistResponseData data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerExistResponse &response);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerExistResponse &response);
}
Q_DECLARE_METATYPE(ns::PlayerExistResponse);
#pragma endregion

#pragma region Region ServerType

namespace ns {
	struct ServerTypeBody
	{
		string url;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerTypeBody &body);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerTypeBody &body);
}

namespace ns {
	struct ServerTypeContent :BaseRequestContent
	{
		ServerTypeBody body;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerTypeContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerTypeContent &content);
}

namespace ns {
	struct ServerTypeRequest : BaseRequest
	{
		ServerTypeContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerTypeRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerTypeRequest &request);
}

namespace ns {
	struct ServerTypeResponseData
	{
		int isCloud;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerTypeResponseData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerTypeResponseData &data);
}

namespace ns {
	struct ServerTypeResponse
	{
		std::vector<EnumResponseStatus>status;
		ns::ServerTypeResponseData data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerTypeResponse &response);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerTypeResponse &response);
}


#pragma endregion

#pragma region Region Task

namespace ns {
	struct TaskJobData
	{
		string packageType;
		string version;
		long size;
		string updateType;
		string md5;
		string source;
		string sessionID;
		string uploadHost;
		string scope;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskJobData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskJobData &data);

	struct Ntp
	{
		bool enable;
		string server;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Ntp &job);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Ntp &job);

	struct Lora
	{
		int address;
		int channel;
		bool enable;
		string groupId;
		string mode;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Lora &job);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Lora &job);

	struct Gps
	{
		bool enable;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Gps &job);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Gps &job);

	struct Job
	{
		string type = "NETTIME";
		TaskJobData data;
		bool enable;
		Ntp ntp;
		Lora lora;
		Gps gps;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Job &job);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Job &job);
}

namespace ns {
	struct TaskContent
	{
		ns::Source source;
		Job jobs;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskContent &content);
}

namespace ns {
	struct TaskRequest : BaseRequest
	{
		TaskContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskRequest &request);
}

namespace ns {
	struct RestartTask
	{
		bool isReboot;
		bool isUpdate;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RestartTask &task);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RestartTask &task);
}
#pragma endregion

namespace ns {
	struct PlanContent
	{
		string fileName;
		string md5;
		string url;
		string programName;
		bool isSupportMd5Checkout = false;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlanContent &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlanContent &data);
	struct PlanRefreshContent
	{
		Source source;
		PlanContent planContent;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlanRefreshContent &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlanRefreshContent &data);

	struct PlanRefreshData
	{
		string app;
		long long requsetId;
		int contentType;
		int command;
		PlanRefreshContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlanRefreshData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlanRefreshData &data);

	struct SpotsPlanRefreshContent
	{
		Source source;
		std::string spotsType;
		std::string normalProgramStatus;
		long delayTime;
		long playTime;
		PlanContent planContent;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsPlanRefreshContent &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsPlanRefreshContent &data);

	struct SpotsPlanRefreshData
	{
		string app;
		long requsetId;
		int contentType;
		int command;
		SpotsPlanRefreshContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsPlanRefreshData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsPlanRefreshData &data);
}

namespace ns {
	//struct SpotsSolutionEnd
	//{
	//	Source source;
	//	std::string spotsType;
	//	std::string   normalProgramStatus;
	//	long   delayTime;
	//	long playTime;
	//	ConfirmedInfos confirmedInfos;

	//};
	//VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsSolutionEnd &data);
	//VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsSolutionEnd &data);

	struct Plan
	{
		std::string fileName;
		std::string url;
		std::string md5;
		std::string programName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Plan &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Plan &data);

	struct SpotsSolutionUpdate
	{
		Source source;
		std::string spotsType;
		std::string   normalProgramStatus;
		long   delayTime;
		long playTime;
		Plan plan;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsSolutionUpdate &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsSolutionUpdate &data);

	struct SpotsSolutionInfoResponse
	{
		Source source;
		std::string spotsType;
		std::string   normalProgramStatus;
		long delayTime;
		long playTime;
		std::string startTime;
		std::string endTime;
		int status;
		std::string name;
		std::string md5;
		int64_t currentTime;
		std::string timeZone;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsSolutionInfoResponse &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsSolutionInfoResponse &data);


	struct SpotsCancelResponse
	{
		std::string identifier;
		std::string planListUrl;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsCancelResponse &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsCancelResponse &data);
}

namespace ns {
	struct SpotsStatusHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsStatusHeader &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsStatusHeader &header);
}

namespace ns {
	struct SpotsStatusBody
	{
		Source source;
		string spotsType;
		long delayTime;
		long playTime;
		string startTime;
		string endTime;
		int status;
		string time;
		string timezone;
		string name;
		string md5;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsStatusBody &header);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsStatusBody &header);
}

namespace ns {
	struct SpotsStatusContent :BaseRequestContent
	{
		SpotsStatusBody body;
		SpotsStatusHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsStatusContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsStatusContent &content);
}

namespace ns {
	struct SpotsStatusRequest :BaseRequest
	{
		SpotsStatusContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpotsStatusRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsStatusRequest &request);
}

namespace ns {
	struct SpotsStatusResponseContent
	{
		vector<int> status;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpotsStatusResponseContent &response);
}

#pragma region Region ScreenState
namespace ns {
	struct ScreenStateBodySource
	{
		int  type;
		int platform;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenStateBodySource &source);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenStateBodySource &source);
}
namespace ns {
	struct ScreenStateBodyDataInfo
	{
		string state;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenStateBodyDataInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenStateBodyDataInfo &info);
}
namespace ns {
	struct ScreenStateBodyData
	{
		ScreenStateBodyDataInfo current_status_info;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenStateBodyData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenStateBodyData &data);
}
namespace ns {
	struct ScreenStateBody
	{
		ScreenStateBodySource source;
		string playerIdentifier;
		ScreenStateBodyData data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenStateBody &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenStateBody &data);
}

namespace ns {
	struct ScreenStateContent :BaseRequestContent
	{
		ScreenStateBody body;
		OnlineHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenStateContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenStateContent &content);
}

namespace ns {
	struct ScreenStateRequest :BaseRequest
	{
		ScreenStateContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenStateRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenStateRequest &request);
}
#pragma endregion

//上报同步播放状态
namespace ns {
	struct ReportSyncPlayStatusBodySource
	{
		int  type;
		int platform;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportSyncPlayStatusBodySource &source);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportSyncPlayStatusBodySource &source);
}
namespace ns {
	struct ReportSyncPlayStatusBodyDataInfo
	{
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportSyncPlayStatusBodyDataInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportSyncPlayStatusBodyDataInfo &info);
}
namespace ns {
	struct ReportSyncPlayStatusBodyData
	{
		ReportSyncPlayStatusBodyDataInfo current_status_info;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportSyncPlayStatusBodyData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportSyncPlayStatusBodyData &data);
}
namespace ns {
	struct ReportSyncPlayStatusBody
	{
		ReportSyncPlayStatusBodySource source;
		string playerIdentifier;
		ReportSyncPlayStatusBodyData data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportSyncPlayStatusBody &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportSyncPlayStatusBody &data);
}

namespace ns {
	struct ReportSyncPlayStatusContent :BaseRequestContent
	{
		ReportSyncPlayStatusBody body;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportSyncPlayStatusContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportSyncPlayStatusContent &content);
}

namespace ns {
	struct ReportSyncPlayStatusRequest :BaseRequest
	{
		ReportSyncPlayStatusContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReportSyncPlayStatusRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReportSyncPlayStatusRequest &request);
}

namespace ns {

	struct TimeZoneResponseData
	{
		string timeZone;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneResponseData &reply);

	struct TimeZoneResponse
	{
		std::vector<EnumResponseStatus> status;
		TimeZoneResponseData data;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneResponse &reply);

	struct TimeZoneAllResponse
	{
		TimeZoneResponse content;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneAllResponse &reply);

	struct ScreenShotResponseData
	{
		string ossDir;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenShotResponseData &data);

	struct ScreenShotResponse
	{
		int status;
		ScreenShotResponseData data;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenShotResponse &reply);
}


namespace ns {

	struct ScreenPowerStatus
	{
		Source source;
		string type;
		string state;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenPowerStatus &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenPowerStatus &request);
}

namespace ns {
	struct IllegalFileInfo
	{
		string fileName;
		string md5;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IllegalFileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IllegalFileInfo &data);

	struct IllegalFileInfos
	{
		vector<IllegalFileInfo> fileInfos;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IllegalFileInfos &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IllegalFileInfos &data);


	struct MediaLegalityHeader
	{
		string token;
		string playerIdentifier;
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaLegalityHeader &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaLegalityHeader &data);

	struct MediaLegalityData
	{
		int falsifyLocation;
		int source;
		bool isNormal;
		string programName;
		IllegalFileInfos fileInfos;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaLegalityData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaLegalityData &data);

	struct MediaLegalityContent :BaseRequestContent
	{
		MediaLegalityData body;
		MediaLegalityHeader header;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaLegalityContent &content);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaLegalityContent &content);

	struct MediaLegalityRequest :BaseRequest
	{
		MediaLegalityContent content;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediaLegalityRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediaLegalityRequest &request);
}


namespace ns
{
	struct TimeZoneInfo
	{
		int64_t utcTimeMillis;
		string timeZone;
		string gmt;
		string isTimeOffsetEnable;
		string beginTime;
		string endTime;
		int64_t timeOffsetValue;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimeZoneInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneInfo &data);
	struct TimeAndZone
	{
		string sn;
		string currentTime;
		TimeZoneInfo timeZoneInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimeAndZone &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeAndZone &data);
}
//网络校时
namespace ns
{
	struct Compatibility
	{
		bool supportLoraInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Compatibility &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Compatibility &data);
	struct TimingInfo
	{
		bool enable = false;
		string type = "NET_TIMING";//固定值NET_TIMING
		Source source;
		Ntp ntp;
		Lora lora;
		Gps gps;
		Compatibility compatibility;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimingInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimingInfo &data);
	struct VerifyNetTimeInfo
	{
		string sn;
		TimingInfo timingInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VerifyNetTimeInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VerifyNetTimeInfo &data);

	struct ServerInfo
	{
		string label;
		string node;
		bool islocal = true;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerInfo &data);

	struct serverAddressInfo
	{
		ns::ServerInfo oldServer;
		ns::ServerInfo newServer;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const serverAddressInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, serverAddressInfo &data);

	struct serverAddress
	{
		vector<serverAddressInfo> serverInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const serverAddress &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, serverAddress &data);

	struct ServerAddressContent
	{
		vector<ServerInfo> serverInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerAddressContent &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerAddressContent &data);
	//     struct Ntp 
	//     {
	//         bool enable;
	//         string server;
	//     };
	//     struct Lora 
	//     {
	//         int address;
	//         int channel;
	//         bool enable;
	//         string mode;
	//         string groupId;
	//     };
	struct Regulation
	{
		bool timeEnable;
		bool brightnessEnable;
		bool volumeEnable;
		bool environmentalMonitoring;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Regulation &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Regulation &data);
	struct LoraData
	{
		int address;
		int channel;
		bool enable;
		string groupId;
		string mode;
		Regulation regulation;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LoraData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LoraData &data);
	struct TaskArrays
	{
		string type;
		int action;
		NtpData ntpData;
		LoraData loraData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskArrays &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskArrays &data);
	struct TimingVertify
	{
		Source source;
		vector<TaskArrays> taskArray;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimingVertify &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimingVertify &data);
	struct  TimingVertifyInfo
	{
		string sn;
		TimingVertify timingInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimingVertifyInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimingVertifyInfo &data);

	struct GetTaskArray
	{
		string type;
		int action;
		int status = -1;
		int errorcode = -1;
		NtpData ntpData;
		LoraData loraData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetTaskArray &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetTaskArray &data);
	struct GetTimingVertify
	{
		Source source;
		vector<GetTaskArray> taskArray;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetTimingVertify &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetTimingVertify &data);
}

namespace ns
{
	//高级功能-恢复出厂设置中setinfo
	struct SetInfo
	{
		string reason;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetInfo &info);

	//高级功能-adb状态设置modeInfo
	struct ModeInfo
	{
		double value;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ModeInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ModeInfo &info);

	//高级功能-获取当前分辨率&&分辨率列表RequestInfo
	struct RequestInfo
	{
		int displayMode;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RequestInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RequestInfo &info);

	//高级功能-设置当前分辨率
	struct ResolutionInfo
	{
		int displayMode;
		string resolutionValue;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ResolutionInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ResolutionInfo &info);

	struct SyncPlayInfo
	{
		string type;
		Source source;
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SyncPlayInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SyncPlayInfo &info);

	struct RebootInfo
	{
		string type;
		Source source;
		string executionType;
		string reason;
		std::vector<Condition> conditions;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RebootInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RebootInfo &info);

	struct RebootData
	{
		string sn;
		RebootInfo rebootinfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RebootData &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RebootData &info);

	struct RebootTaskData
	{
		string sn;
		RebootInfo reboottaskinfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RebootTaskData &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RebootTaskData &info);


	struct OTGUSBInfo
	{
		double value;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const OTGUSBInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OTGUSBInfo &info);

	struct VersionInfo
	{
		string packageName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VersionInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VersionInfo &info);

	struct PackageInfo
	{
		std::vector<string> packageName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PackageInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PackageInfo &info);

	struct PackageInfoWithSN
	{
		string sn;
		PackageInfo packageInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PackageInfoWithSN &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PackageInfoWithSN &info);

	struct InsertValueWithSN
	{
		string sn;
		string type;
		string value;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const InsertValueWithSN &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, InsertValueWithSN &info);

	struct DelValueWithSN
	{
		string sn;
		string type;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DelValueWithSN &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DelValueWithSN &info);

	struct GetValueWithSN
	{
		string sn;
		string type;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetValueWithSN &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetValueWithSN &info);

	struct mosaicInfo
	{
		int mosaicWidth = 256;
		int mosaicHeight = 256;
		int mosaicNum = 0;
		string lang = "";
		string userType = "user";
		bool demo = false;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const mosaicInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, mosaicInfo &info);

	struct WifiAPInfo
	{
		string aliasName;
		string suffix;
		string password;
		int channelId;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiAPInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiAPInfo &info);

	struct WifiAPOpenStatus
	{
		bool enable = false;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiAPOpenStatus &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiAPOpenStatus &info);

	//高级功能中的options的并集
	struct AdvancedOption
	{
		string sn;
		bool enable;
		RebootInfo rebootInfo;
		SetInfo setInfo;
		ModeInfo modeInfo;
		RequestInfo requestInfo;
		ResolutionInfo resolutionInfo;
		string aliasName;
		string suffix;
		string password;
		int channelId = -1;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AdvancedOption &option);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AdvancedOption &option);
}
namespace ns {

	struct GetIcareRequestInfo
	{
		string language;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetIcareRequestInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetIcareRequestInfo &data);

	struct GetIcareConfigInfo
	{
		string sn;
		GetIcareRequestInfo getIcareRequestInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetIcareConfigInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetIcareConfigInfo &data);

}

namespace ns {
	struct ServerNodes
	{
		string lable;
		string node;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerNodes &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerNodes &data);

	struct GetIcareConfigReturnInfo
	{
		bool state;
		vector<ServerNodes> serverNodes;
		string url;
		string username;
		bool isOnline;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetIcareConfigReturnInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetIcareConfigReturnInfo &data);
}

namespace ns
{

	struct SetIcareRequestInfo
	{
		bool state;
		string url;
		string username;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetIcareRequestInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetIcareRequestInfo &data);

	struct SetIcareConfigInfo
	{
		string sn;
		SetIcareRequestInfo setIcareRequestInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetIcareConfigInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetIcareConfigInfo &data);
}

namespace ns
{

	struct BindPlayerPlayerList
	{
		string identifier;
		bool isUsed;
		string name;
		string playerIdentifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindPlayerPlayerList &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindPlayerPlayerList &data);

	struct BindPlayerData
	{
		string token;
		std::vector<BindPlayerPlayerList> bindPlayerPlayerList;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindPlayerData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindPlayerData &data);

	struct BindPlayerInfo
	{
		bool isBind;
		string errorDescription;
		string baseUrl;
		string password;
		string username;
		string serverPlayerName;
		std::vector<int> status;
		BindPlayerData bindPlayerData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BindPlayerInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BindPlayerInfo &data);

	struct GetBindPlayer
	{
		string sn;
		BindPlayerInfo bindPlayerInfo;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetBindPlayer &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetBindPlayer &data);

	struct GetBindPlayerSn
	{
		string sn;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetBindPlayerSn &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetBindPlayerSn &data);

	struct SetBindPlayerInfo
	{
		string baseUrl;
		bool isNewVnnox;
		string password;
		string username;
		BindPlayerData bindPlayerData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetBindPlayerInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetBindPlayerInfo &data);

	struct SetBindPlayer
	{
		string sn;
		SetBindPlayerInfo setBindPlayerInfo;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetBindPlayer &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetBindPlayer &data);


}

namespace ns {

	struct GetCloudPlayerListData
	{
		string url;
		string username;
		string password;
		int playerType;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetCloudPlayerListData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetCloudPlayerListData &data);

	struct PlayerListReturnPlayerList
	{
		string name;
		string identifier;
		bool isUsed;
		string playerIdentifier;
		bool litePlayerRegister;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerListReturnPlayerList &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerListReturnPlayerList &data);

	struct PlayerListReturnData
	{
		string token;
		std::vector<PlayerListReturnPlayerList> playerListReturnPlayerList;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerListReturnData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerListReturnData &data);

	struct GetCloudPlayerListReturnData
	{
		std::vector<int> status;
		PlayerListReturnData playerListReturnData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetCloudPlayerListReturnData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetCloudPlayerListReturnData &data);
}
//vnnox服务器地址获取
namespace ns
{
	struct  VnnoxServerInfo
	{
		string label;
		string node;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VnnoxServerInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VnnoxServerInfo &data);

	// VIPLEXCOMMON_EXPORT void to_json(json& j, const map<string, vector<VnnoxServerInfo>> &servers);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, map<string, vector<VnnoxServerInfo>> &servers);

}
namespace ns
{
	struct GetOnlineUpdatePackage
	{
		string productName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetOnlineUpdatePackage &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetOnlineUpdatePackage &data);
	struct DownloadOnlineFileData
	{
		string url;
		string address;
		string md5;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DownloadOnlineFileData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DownloadOnlineFileData &data);
	struct OnlineUpdatePackageInfo
	{
		string type;
		string url;
		string version;
		int64_t size;
		string md5;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const OnlineUpdatePackageInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OnlineUpdatePackageInfo &data);

	struct OnlineUpdatePackageData
	{
		vector<OnlineUpdatePackageInfo> onlineUpdatePackageInfos;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const OnlineUpdatePackageData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OnlineUpdatePackageData &data);

	struct UpgradeDescription
	{
		string zh;
		string jp;
		string es;
		string kp;
		string fr;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpgradeDescription &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpgradeDescription &data);
	struct OnlinePackage
	{
		vector<string> supportedPlatforms;
		string name;
		vector<string> supportedProducts;
		string isUpgradeAppAfterOS;
		string version;
		string identifier;
		string type;
		bool startupAfterInstalled;
		int64_t size;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const OnlinePackage &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OnlinePackage &data);
	struct AnnexesDescription
	{
		vector<string> commonSupportedProducts;
		string description;
		string totalSize;
		string excutionType;
		string version;
		string createdDate;
		string packetType;
		OnlinePackage packages;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AnnexesDescription &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AnnexesDescription &data);
	struct OnlineFileDescription
	{
		string productTypeUnique;
		string productType;
		string productUnique;
		string productModel;
		string productVersion;
		UpgradeDescription upgradeDescription;
		string md5;
		int64_t size;
		string downloadAddress;
		AnnexesDescription annexesDescription;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const OnlineFileDescription &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OnlineFileDescription &data);

	struct UnzipJsonContentData
	{
		vector<string> zipFilePaths;
		vector<string> dFileNames;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UnzipJsonContentData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UnzipJsonContentData &data);

	struct ReadZipFileContent
	{
		vector<string> zipFilePaths;
		vector<string> zipFileContents;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ReadZipFileContent &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ReadZipFileContent &data);

	struct FilePath
	{
		vector<string> filePath;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FilePath &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FilePath &data);

	struct ViplexUpdateInfo
	{
		string sn;
		string filePath;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ViplexUpdateInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ViplexUpdateInfo &data);

	struct StopUpdateInfo
	{
		string sn;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const StopUpdateInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, StopUpdateInfo &data);

	struct ViplexPackage
	{
		string type;
		string version;
		string name;
		string identifier;
		int64_t size;
		bool startupAfterInstalled;
		string isUpgradeAppAfterOS;
		list<string> supportedProducts;
		list<string> supportedPlatforms;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ViplexPackage &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ViplexPackage &data);

	struct VerifyInfo
	{
		string version;
		int64_t totalSize;
		string description;
		string packetType;
		string excutionType;
		string createdDate;
		list<ViplexPackage> packages;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VerifyInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VerifyInfo &data);

	struct UpdateVerifyData
	{
		string sn;
		ns::VerifyInfo verifyInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdateVerifyData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdateVerifyData &data);

	struct UpdatePackageDescription
	{
		string description;
		string version;
		string versionCode;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdatePackageDescription &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdatePackageDescription &data);

	enum UpdatePackageUploadStatus
	{
		START = 0,           //开始传输
		UPLOADING = 1,       //传输中
		FINISH = 2           //传输结束
	};
	struct UpdatePackageUploadProgress
	{
		UpdatePackageUploadStatus status;  //状态
		qint64 bytesSent;                  //已传输的字节
		qint64 bytesTotal;                 //文件总字节数
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdatePackageUploadProgress &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdatePackageUploadProgress &data);

	enum UpdateStatusEnum
	{
		STARTUPGRADE = 0,   //开始升级
		UPGRADING = 1       //升级中(暂时不用)
	};
	struct UpdateStatus
	{
		UpdateStatusEnum status;   //升级状态
		string versioin;           //升级包版本号（现在拿不到）
		string packageType;        //包类型（APP：软件升级包 OS：系统升级包）
		string packageName;        //包名
		string time;               //当前系统时间
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdateStatus &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdateStatus &data);

	enum PackageType
	{
		APP,
		OS,
		OS_DIF,
		FPGA,
		NUZIP,
		AUTO
	};
	enum ExecutionType
	{
		IMMEDIATELY,
		BY_CONDITIONS
	};
	enum UpdateType
	{
		UPDATE,
		REPLACE
	};



	struct ViplexUpdateConditions
	{
		string start;
		vector<string> corn;
		string end;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ViplexUpdateConditions &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ViplexUpdateConditions &data);

	struct ViplexUpdateTask
	{
		string packageType;
		string version;
		string executionType;
		qint64 size;
		string md5;
		string updateType;
		bool startupAfterInstalled;
		bool startupAfterBoot;
		vector<ViplexUpdateConditions> conditions;
		string source;
		bool checkFeasibility;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ViplexUpdateTask &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ViplexUpdateTask &data);

	struct ViplexUpdateData
	{
		string type;
		bool isLocal;
		Source source;
		vector<ViplexUpdateTask> tasks;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ViplexUpdateData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ViplexUpdateData &data);
}

namespace ns {

	struct NodeServerListData
	{
		string sn;
		string nodeServerName;
		string nodeServerAddress;
		string nodeServerId;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const NodeServerListData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, NodeServerListData &data);

	struct NodeServerList
	{
		std::vector<NodeServerListData> nodeServerListData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const NodeServerList &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, NodeServerList &data);

}

namespace ns
{
	struct VolumeInfo
	{
		float ratio;
		Source source;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VolumeInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VolumeInfo &data);
	struct Volume
	{
		string sn;
		VolumeInfo volumeInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Volume &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Volume &data);

	struct TimingVolumeConditions
	{
		std::vector<string> cron;
		float value = 0;
		bool enable;
		string startTime;
		string endTime;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimingVolumeConditions &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimingVolumeConditions &data);

	struct TimingVolumeInfo
	{

		string type;
		Source source;
		bool enable;
		vector<TimingVolumeConditions> conditions;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimingVolumeInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimingVolumeInfo &data);

	struct TimingVolume
	{
		string sn;
		ns::TimingVolumeInfo data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimingVolume &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimingVolume &data);

}

namespace ns
{
	struct ColorTemperatureInfo
	{
		int colorTemperature;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ColorTemperatureInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ColorTemperatureInfo &data);
	struct ColorTemperature
	{
		string sn;
		ColorTemperatureInfo colorTemperatureInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ColorTemperature &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ColorTemperature &data);
}

namespace ns
{
	struct GetEnvironmentBrightnessInfo
	{
		string sn;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetEnvironmentBrightnessInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetEnvironmentBrightnessInfo &data);

	struct GetEnvironmentBrightnessReturnData
	{
		int value;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetEnvironmentBrightnessReturnData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetEnvironmentBrightnessReturnData &data);

}

namespace ns
{
	struct GetScreenUnitTempInfo
	{
		string sn;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetScreenUnitTempInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetScreenUnitTempInfo &data);

}

namespace ns
{
	struct GetAvailableStorageDataInfo
	{
		string sn;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetAvailableStorageDataInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetAvailableStorageDataInfo &data);

}

namespace ns
{
	struct GetCPUUsageInfo
	{
		string sn;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetCPUUsageInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetCPUUsageInfo &data);

}

namespace ns
{
	struct BrightnessAdjustModeInfo
	{
		string type;
		Source source;
		string mode;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BrightnessAdjustModeInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BrightnessAdjustModeInfo &data);
	struct BrightnessAdjustMode
	{
		string sn;
		BrightnessAdjustModeInfo brightnessAdjustModeInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BrightnessAdjustMode &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BrightnessAdjustMode &data);
}

namespace ns
{
	struct ScreenBrightnessInfo
	{
		float ratio;
		Source source;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenBrightnessInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenBrightnessInfo &data);
	struct ScreenBrightness
	{
		string sn;
		ScreenBrightnessInfo screenBrightnessInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenBrightness &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenBrightness &data);
}

namespace ns
{
	struct BrightnessPolicyInfo
	{
		bool isSupportCompleteCron;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BrightnessPolicyInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BrightnessPolicyInfo &data);
	struct ScreenBrightnessPolicy
	{
		string sn;
		BrightnessPolicyInfo brightnessPolicyInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenBrightnessPolicy &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenBrightnessPolicy &data);

}
namespace ns
{
	struct Segments
	{
		int environmentBrightness;
		double screenBrightness;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Segments &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Segments &data);
	struct OpticalFailureInfo
	{
		bool enable;
		double screenBrightness = -1;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const OpticalFailureInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OpticalFailureInfo &data);
	struct Conditions
	{
		int type;
		vector<string> crons;
		string startTime;
		string endTime;
		vector<json::value_type> args;
		vector<Segments> segments;
		OpticalFailureInfo opticalFailureInfo;
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Conditions &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Conditions &data);
	struct SegmentConfig
	{
		vector<json::value_type> args;
		vector<Segments> segments;
		OpticalFailureInfo opticalFailureInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SegmentConfig &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SegmentConfig &data);

	struct ScreenBrightnessPolicyTaskInfo
	{
		string type;
		Source source;
		bool enable;
		vector<Conditions> conditions;
		SegmentConfig segmentConfig;
		string timeStamp;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenBrightnessPolicyTaskInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenBrightnessPolicyTaskInfo &data);
	struct ScreenBrightnessPolicyDetail
	{
		string sn;
		ScreenBrightnessPolicyTaskInfo taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenBrightnessPolicyDetail &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenBrightnessPolicyDetail &data);
}

namespace ns
{
	struct SegmentsInt
	{
		int environmentBrightness;
		int screenBrightness;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SegmentsInt &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SegmentsInt &data);
	struct OpticalFailureInfoInt
	{
		bool enable;
		int screenBrightness = -1;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const OpticalFailureInfoInt &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, OpticalFailureInfoInt &data);
	struct ConditionsInt
	{
		int type;
		vector<string> crons;
		string startTime;
		string endTime;
		vector<int> args;
		vector<SegmentsInt> segments;
		OpticalFailureInfoInt opticalFailureInfo;
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConditionsInt &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConditionsInt &data);
	struct SegmentConfigInt
	{
		vector<int> args;
		vector<SegmentsInt> segments;
		OpticalFailureInfoInt opticalFailureInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SegmentConfigInt &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SegmentConfigInt &data);

	struct ScreenBrightnessPolicyTaskInfoInt
	{
		string type;
		Source source;
		bool enable;
		vector<ConditionsInt> conditions;
		SegmentConfigInt segmentConfig;
		string timeStamp;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenBrightnessPolicyTaskInfoInt &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenBrightnessPolicyTaskInfoInt &data);
	struct ScreenBrightnessPolicyDetailInt
	{
		string sn;
		ScreenBrightnessPolicyTaskInfoInt taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenBrightnessPolicyDetailInt &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenBrightnessPolicyDetailInt &data);
}


namespace ns
{
	struct  CloudPlayerListPlayerInfoData
	{
		string username;
		string password;
		int playerType;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CloudPlayerListPlayerInfoData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CloudPlayerListPlayerInfoData &data);

	struct CloudPlayerListPlayerInfo
	{
		string host;
		CloudPlayerListPlayerInfoData cloudPlayerListPlayerInfoData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CloudPlayerListPlayerInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CloudPlayerListPlayerInfo &data);

	struct CloudPlayerList
	{
		string sn;
		CloudPlayerListPlayerInfo cloudPlayerListPlayerInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CloudPlayerList &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CloudPlayerList &data);
}

namespace ns
{
	struct VedioCondition
	{
		string cron;
		int source;
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VedioCondition &condition);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VedioCondition &condition);

	struct VideoSourceInfo
	{
		string type;
		ns::Source source;
		int videoMode;
		int videoSource;
		bool isScale;
		int offsetX;
		int offsetY;
		vector<VedioCondition> conditions;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VideoSourceInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VideoSourceInfo &info);

	struct VideoSourceCtrlInfo
	{
		string sn;

		VideoSourceInfo videdSourceInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VideoSourceCtrlInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VideoSourceCtrlInfo &info);

	struct ScreenshotInfo
	{
		string sn;
		int width;
		int height;
		string downLoadDirectoryPath;
		string pictureName;
		int pictureType;
		string type;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenshotInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenshotInfo &info);

	struct ScreenshotResult
	{
		string path;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenshotResult &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenshotResult &result);

    struct EDIDInfo
    {
        int width;
        int height;
        int fieldRate = 60;
    };
    VIPLEXCOMMON_EXPORT void to_json(json& j, const EDIDInfo &result);
    VIPLEXCOMMON_EXPORT void from_json(const json& j, EDIDInfo &result);
    struct EDIDControl
    {
        string sn;
        EDIDInfo taskInfo;
    };
    VIPLEXCOMMON_EXPORT void to_json(json& j, const EDIDControl &result);
    VIPLEXCOMMON_EXPORT void from_json(const json& j, EDIDControl &result);
}

namespace ns
{
	struct ScreenPowerModeInfo
	{
		string type;
		Source source;
		string mode;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenPowerModeInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenPowerModeInfo &data);
	struct ScreenPowerMode
	{
		string sn;
		ScreenPowerModeInfo taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenPowerMode &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenPowerMode &data);
}

namespace ns
{
	struct ScreenPowerInfo
	{
		string type;
		Source source;
		string state;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenPowerInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenPowerInfo &data);
	struct ScreenPower
	{
		string sn;
		ScreenPowerInfo  taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenPower &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenPower &data);
}

namespace ns
{
	struct ScreenConditions
	{
		vector<string> cron;
		string action;
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenConditions &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenConditions &data);
	struct ScreenPowerPolicyInfo
	{
		string type;
		Source source;
		bool enable;
		vector<ScreenConditions> conditions;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenPowerPolicyInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenPowerPolicyInfo &data);
	struct  ScreenPowerPolicy
	{
		string sn;
		ScreenPowerPolicyInfo taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenPowerPolicy &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenPowerPolicy &data);
}

namespace ns
{

	struct ScanInfos
	{
		int width;
		int height;
		int x;
		int y;
		int xInPort;
		int yInPort;
		int portIndex;
		int connectIndex;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScanInfos &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScanInfos &result);


	struct ScreenAttributeData
	{
		int id;
		int screenSource;
		int xCount;
		int yCount;
		int xOffset;
		int yOffset;
		int portNumber;
		std::vector<int> orders;
		std::vector<ScanInfos> scanInfos;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenAttributeData &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenAttributeData &result);


	struct ScreenAttribute
	{
		std::vector<ScreenAttributeData> screenAttributes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenAttribute &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenAttribute &result);



	struct ScreenAttributeInfo
	{
		string sn;
		ScreenAttribute screenAttribute;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenAttributeInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenAttributeInfo &result);
}

namespace ns
{
	struct FtpFileInfo
	{
		string fileName;
		FtpFileTag tag;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FtpFileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FtpFileInfo &data);

	struct FtpParam
	{
		string hostIp;
		int port;
		string userName;
		string sn;
		string remotePath;
		string localPath;
		FtpFileInfo fileInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FtpParam &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FtpParam &data);
}

namespace ns
{
	struct GetPlayerListResponseplayerList
	{
		string name;
		string identifier;
		bool isUsed;
		string playerIdentifier;
		bool litePlayerRegister;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetPlayerListResponseplayerList &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetPlayerListResponseplayerList &result);

	struct GetPlayerListResponseData
	{
		string token;
		vector<GetPlayerListResponseplayerList> getPlayerListResponseplayerList;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetPlayerListResponseData &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetPlayerListResponseData &result);

	struct getPlayerListResponseInfo
	{
		vector<int> status;
		GetPlayerListResponseData getPlayerListResponseData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const getPlayerListResponseInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, getPlayerListResponseInfo &result);

	struct getBindPlayerResponseInfo
	{
		bool isBind;
		string baseUrl;
		string username;
		string password;
		GetPlayerListResponseData getPlayerListResponseData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const getBindPlayerResponseInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, getBindPlayerResponseInfo &result);
}

namespace ns
{
	struct GetMemoryRawRequest
	{
		string sn;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetMemoryRawRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetMemoryRawRequest &request);

	struct Receiver
	{
		string outputDestination;
		bool persistent;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Receiver &receiver);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Receiver &receiver);

	struct Picker
	{
		//CollectorType type;
		//PickType pickType;
		string type;
		string pickType;
		long period;
		std::vector<Receiver> receivers;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Picker &picker);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Picker &picker);

	struct CollectorInfo
	{
		std::vector<Picker> pickers;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CollectorInfo &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CollectorInfo &request);

	struct CollectorRequest
	{
		string sn;
		CollectorInfo info;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CollectorRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CollectorRequest &request);

	struct DeleteCollectorData
	{
		std::vector<string> types;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DeleteCollectorData &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DeleteCollectorData &request);

	struct DeleteCollectorRequest
	{
		string sn;
		DeleteCollectorData info;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DeleteCollectorRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DeleteCollectorRequest &request);

	struct FinishPickRawRequest
	{
		string sn;
		string type;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FinishPickRawRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FinishPickRawRequest &request);

	struct FinishPickRequest
	{
		std::vector<string> type;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FinishPickRequest &request);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FinishPickRequest &request);
}

namespace ns
{
	struct SpliceInfo
	{
		int order;
		int width;
		int height;
		int offsetX;
		int offsetY;
		int videoSource;
		bool isScale;
		int orderNum;
	};

	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpliceInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpliceInfo &result);

	struct SpliceData
	{
		string sn;
		SpliceInfo spliceInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SpliceData &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SpliceData &result);
}

namespace ns
{
	struct FileName
	{
		std::string fileName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileName &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileName &result);

	struct RecvCardFileInfo
	{
		std::string uri;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RecvCardFileInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RecvCardFileInfo &result);

	struct RecvCardFileData
	{
		std::string sn;
		std::string filePath;
		std::string fileName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RecvCardFileData &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RecvCardFileData &result);
}

namespace ns
{
	struct WifiConntctInfo
	{
		string ssid;
		string password;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiConntctInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiConntctInfo &data);
	struct WifiConnect
	{
		string sn;
		WifiConntctInfo taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiConnect &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiConnect &data);
	struct WifiDisconnectInfo
	{
		string ssid;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiDisconnectInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiDisconnectInfo &data);
	struct WifiDisconnect
	{
		string sn;
		WifiDisconnectInfo taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiDisconnect &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiDisconnect &data);
	struct WifiStateInfo
	{
		int state;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiStateInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiStateInfo &data);
	struct WifiState
	{
		string sn;
		WifiStateInfo taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiState &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiState &data);
	struct TaskArray
	{
		string type;
		int action;
		string data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskArray &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskArray &data);
	struct WifiApStation
	{
		Source source;
		vector<TaskArray> taskArray;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiApStation &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiApStation &data);
	struct APNetworkInfo
	{
		string aliasName;
		string suffix;
		string password;
		int channelId;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const APNetworkInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, APNetworkInfo &data);
	struct APNetwork
	{
		string sn;
		APNetworkInfo taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const APNetwork &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, APNetwork &data);
	struct BasicConfigs
	{
		bool mobileData;
		bool dataRoaming;
		bool enable4G;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BasicConfigs &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BasicConfigs &data);
	struct APN
	{
		string providerName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const APN &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, APN &data);
	struct Advanced
	{
		string networkType;
		APN apn;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Advanced &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Advanced &data);
	struct MobileNetworkInfo
	{
		BasicConfigs basicConfigs;
		Advanced advanced;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MobileNetworkInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MobileNetworkInfo &data);
	struct MobileNetwork
	{
		string sn;
		MobileNetworkInfo mobileData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MobileNetwork &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MobileNetwork &data);
	struct Ethernets
	{
		int scopeId = -1;
		string name;
		bool dhcp;
		string ip;
		string mask;
		string gateWay;
		vector<string> dns;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Ethernets &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Ethernets &data);
	struct EthernetDetail
	{
		vector<Ethernets> ethernets;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const EthernetDetail &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, EthernetDetail &data);
	struct EthernetInfo
	{
		string sn;
		EthernetDetail taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const EthernetInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, EthernetInfo &data);
	struct WifiListResult
	{
		string bssid;
		int level;
		string security;
		string ssid;
		int state;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiListResult &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiListResult &data);
	struct WifiListInfo
	{
		vector<WifiListResult> result;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WifiListInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WifiListInfo &data);
}

namespace ns
{
	struct ForceStopAppRequestInfo
	{
		string packageName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ForceStopAppRequestInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ForceStopAppRequestInfo &info);


	struct ForceStopAppInfo
	{
		string sn;
		ForceStopAppRequestInfo requestInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ForceStopAppInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ForceStopAppInfo &info);

	struct UninstalllAppInfo
	{
		string sn;
		string packageName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UninstalllAppInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UninstalllAppInfo &info);

	struct InstalllAppInfo
	{
		string sn;
		string packageName;
		string apkFile;
		bool startAfterInstal;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const InstalllAppInfo &info);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, InstalllAppInfo &info);
}

namespace ns
{
	struct TimeZoneListData
	{
		string id;
		string name;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimeZoneListData &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneListData &result);

	struct TimeZoneList
	{
		std::vector<TimeZoneListData> timeZoneListData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TimeZoneList &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TimeZoneList &result);

	struct UpLoadUserInfo
	{
		string platform;
		string title;
		string content;
		string file;
		string emailOrphone;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpLoadUserInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpLoadUserInfo &result);
}

namespace ns
{
	struct ProgramInfoData
	{
		string identifier;
		string name;
		string  thumbnailUrl;
		int statusCode;
		int source;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ProgramInfoData &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ProgramInfoData &result);

	struct ProgramInfo
	{
		std::vector<ProgramInfoData> programInfoData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ProgramInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ProgramInfo &result);

	struct DeleteProgramListDatas
	{
		string identifier;
		string name;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DeleteProgramListDatas &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DeleteProgramListDatas &result);

	struct DeleteProgramListData
	{
		std::vector<DeleteProgramListDatas> deleteProgramListDatas;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DeleteProgramListData &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DeleteProgramListData &result);

	struct DeleteProgramList
	{
		string sn;
		DeleteProgramListData deleteProgramListData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DeleteProgramList &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DeleteProgramList &result);

	struct Identifier
	{
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Identifier &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Identifier &result);	struct PlayIdentifier
	{
		string sn;
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayIdentifier &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayIdentifier &result);

	struct QueryFileByType
	{
		std::vector<string> paths;
		std::vector<string> types;
		int pageIndex;
		int pageSize;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const QueryFileByType &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, QueryFileByType &result);

	struct AllFiles
	{
		std::vector<string> files;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AllFiles &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AllFiles &result);

	struct DownLoadFiles
	{
		string sn;
		//vector<string> remotePaths;
		string downLoadDirectoryPath;
		//vector<string>  fileNames;

		std::map<string, string> remotePathsAndFileNames;
		string fileType;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DownLoadFiles &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DownLoadFiles &result);


	struct DownLoadFilesResult
	{
		string path;
		bool isDownloadSuccess;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DownLoadFilesResult &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DownLoadFilesResult &result);

	struct DownLoadFilesResultData
	{
		std::vector<DownLoadFilesResult> data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DownLoadFilesResultData &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DownLoadFilesResultData &result);
}

//plan.json文件中用到的数据结构
namespace ns
{
	//文件头信息，标注方案类型与适应平台
	struct SourceInfo
	{
		int type;
		int platform;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SourceInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SourceInfo &data);

	//方案文件信息
	struct SolutionFileInfo
	{
		string strFileName;
		string strMd5;
		//string strUrl;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SolutionFileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SolutionFileInfo &data);

	//资源文件信息
	struct ResourceFileInfo
	{
		string type;
		int id;
		long size;
		string fileName;
		string md5;
		//string url;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ResourceFileInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ResourceFileInfo &result);

	struct ThumbnailInfo
	{
		string id;
		long size;
		string fileName;
		string md5;
		string url;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ThumbnailInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ThumbnailInfo &result);

	struct PlanFileInfo
	{
		SourceInfo sourceInfo;
		int id;
		string name;
		//std::vector<SolutionFileInfo> displaySolutions;
		std::vector<SolutionFileInfo> playRelations;
		std::vector<SolutionFileInfo> playSolutions;
		std::vector<SolutionFileInfo> playlists;
		std::vector<SolutionFileInfo> scheduleConstraints;
		//std::vector<SolutionFileInfo> medialists;
		std::vector<ResourceFileInfo> resources;
		//ThumbnailInfo thumbnail;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlanFileInfo &result);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlanFileInfo &result);
}

//schedule_constraints.json文件中所用到的数据结构
namespace ns
{
	struct ConstraintInfo
	{
		int id;
		//ConstraintTypeEnum type;
		string name;
		int priority;
		string startTime;
		std::vector<string> crons;
		string endTime;
		//SceneRulesEnum rules;
		//int duration;
		//long repeatCount;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConstraintInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConstraintInfo &data);

	struct ConstraintFileInfo
	{
		//int id;
		//string name;
		//string uuid;
		std::vector<ConstraintInfo> constraints;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConstraintFileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConstraintFileInfo &data);
}

//play_solution.json文件中所用到的数据结构
namespace ns
{
	struct BackgroundMusicInfo
	{
		bool enable;
		string audioGroup;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const BackgroundMusicInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, BackgroundMusicInfo &data);
	struct TaskItem
	{
		int id;
		string name;
		DisplayRect layout;
		int zOrder;
		//BackgroundMusicInfo backgroundMusic;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TaskItem &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TaskItem &data);

	struct PlaySolutionFileInfo
	{
		string version;
		SourceInfo source;
		string name;
		string uuid;
		std::vector<int> target;
		string pickType;
		int itemCount;
		std::vector<TaskItem> items;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlaySolutionFileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlaySolutionFileInfo &data);
}

//playSolutionRelation.json文件中所用到的数据结构
namespace ns
{
	struct RelationMedialist
	{
		int pageId;
		int widgetContainerId;
		string source;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelationMedialist &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelationMedialist &data);

	struct RelationPlaylist
	{
		int playlistId;
		string playlistSource;
		//std::vector<RelationMedialist> medialists;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelationPlaylist &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelationPlaylist &data);

	struct RelationScheduleConstraint
	{
		int constraintId;
		string constraintSource;
		std::vector<RelationPlaylist> playlists;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelationScheduleConstraint &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelationScheduleConstraint &data);

	struct Relation
	{
		int taskId;
		string playSolutionSource;
		std::vector<RelationScheduleConstraint> scheduleConstraints;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Relation &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Relation &data);

	struct RelationFileInfo
	{
		int id;
		string name;
		//string playSolutionSource;
		std::vector<Relation> relations;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelationFileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelationFileInfo &data);

}

namespace ns
{
	struct Constraints
	{
		string startTime;
		vector<string> cron;
		string endTime;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Constraints &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Constraints &data);
	struct WidgetGroupsContents
	{
		vector<Widget> widgets;
		//    vector<WidgetContainers> widgetContainers;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WidgetGroupsContents &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WidgetGroupsContents &data);
	struct WidgetGroups
	{
		int id;
		string name;
		bool enable;
		int64_t duration;
		int repeatCount;
		Layout layout;
		Animation inAnimation;
		Animation outAnimation;
		string backgroundMusic;
		string backgroundColor;
		string backgroundDrawable;
		//Borders border;
		int zOrder;
		WidgetGroupsContents contents;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WidgetGroups &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WidgetGroups &data);
	struct Contents
	{
		vector<Widget> widgets;
		vector<WidgetGroups> widgetGroups;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Contents &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Contents &data);
	struct Layouts
	{
		string x;
		string y;
		string width;
		string height;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Layouts &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Layouts &data);
	struct WidgetContainers
	{
		int id;
		string name;
		bool enable = true;
		string backgroundColor;
		string backgroundDrawable;
		string pickPolicy;
		int pickCount = 0;
		Layouts layout;
		// Border border;
		int zOrder;
		string itemsSource;
		string audioGroup;
		// vector<int> orderIDArray;
		Contents contents;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WidgetContainers &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WidgetContainers &data);
	struct ScenePage
	{
		int id;
		string name;
		// Animation inAnimation;
		// Animation outAnimation;
	   //  Borders border;
		vector<WidgetGroups> widgetGroups;
		vector<Widget> widgets;
		vector<WidgetContainers> widgetContainers;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScenePage &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScenePage &data);
	struct  SceneItems
	{
		int id;
		string name;
		//int mode = 0;
		bool enable;
		string type;
		string rules;
		int64_t duration;
		int repeatCount = 0;
		string backgroundColor;
		string backgroundDrawable;
		string backgroundMusic;
		vector<Constraints> constraints;
		ScenePage page;
		//string itemSourceId;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SceneItems &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SceneItems &data);
	struct Playlist
	{
		int64_t id = -1;
		string name;
		string uuid;
		string pickPolicy;
		//std::vector<int> orderIDArray;
		//bool thirdParty;
		std::vector<SceneItems> sceneItems;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Playlist &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Playlist &data);
	struct AddPage
	{
		int programID;
		int tplID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AddPage &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AddPage &data);
	struct AddPageBackInfo
	{
		int pageID;
		vector<WidgetContainers> widgetContainers;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AddPageBackInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AddPageBackInfo &data);
	struct AddWidgetList
	{
		string widgetMediaType;
		Widget widget;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AddWidgetList &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AddWidgetList &data);
	struct AddWidget
	{
		int programID;
		int pageID;
		int widgetContainerID;
		vector<AddWidgetList> taskinfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AddWidget &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AddWidget &data);
	struct AddWidgetBackInfo
	{
		vector<int> widgetID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AddWidgetBackInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AddWidgetBackInfo &data);
	struct GetPageParam
	{
		int programID;
		int pageID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetPageParam &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetPageParam &data);

	struct GetWidgetParamInfo
	{
		int programID;
		int pageID;
		int widgetContainerID;
		int widgetID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetWidgetParamInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetWidgetParamInfo &data);

	struct DeleteWidgetParamInfo
	{
		int programID;
		int pageID;
		int widgetContainerID;
		vector<int> widgetID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DeleteWidgetParamInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DeleteWidgetParamInfo &data);

	struct MoveWidgetParamInfo
	{
		int programID;
		int pageID;
		int widgetContainerID;
		vector<int> widgetID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MoveWidgetParamInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MoveWidgetParamInfo &data);

	struct SetWidgetParamInfo
	{
		int programID;
		int pageID;
		int widgetContainerID;
		int widgetID;
		Widget widget;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetWidgetParamInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetWidgetParamInfo &data);

	struct SetPageParam
	{
		int  programID;
		int pageID;
		ScenePage pageInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetPageParam &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetPageParam &data);

	struct WidgetInfo
	{
		int programID;
		int pageID;
		int widgetContainerID;
		int widgetID;
	};
}

namespace ns
{
	struct CreateProgram
	{
		string name;
		int width;
		int height;
		int tplID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CreateProgram &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CreateProgram &data);

	struct MediasPath
	{
		string oldPath;
		string newPath;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MediasPath &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MediasPath &data);


	struct MakeProgram
	{
		std::vector<ns::MediasPath> mediasPath;
		int64_t programID;
		string outPutPath;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const MakeProgram &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, MakeProgram &data);
}

namespace ns
{

	struct TemplateSize
	{
		int height = 400;
		int width = 400;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TemplateSize &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TemplateSize &data);

	struct TemplateData
	{
		float width;
		float height;
		float left;
		float top;
		int zindex;
		int index;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TemplateData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TemplateData &data);

	struct TemplateDataInfo
	{
		std::vector<TemplateData> data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TemplateDataInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TemplateDataInfo &data);

	struct TemplateInfo
	{
		std::vector<TemplateDataInfo> data;
		TemplateSize size;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TemplateInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TemplateInfo &data);

	struct Template
	{
		int tplID;
		std::vector<TemplateData> data;
		TemplateSize size;
		bool isSystemTpl;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Template &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Template &data);

	struct Templates
	{
		std::vector<Template> templates;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Templates &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Templates &data);

	struct TemplateId
	{
		std::vector<int> tplID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TemplateId &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TemplateId &data);


	struct ResponseTemplateId
	{
		int tplID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ResponseTemplateId &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ResponseTemplateId &data);

	struct LocalProgram
	{
		string name;
		int64_t programID;
		int height;
		int width;
		vector<ScenePage> page;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const LocalProgram &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, LocalProgram &data);

	struct ProgramList
	{
		vector<LocalProgram> programList;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ProgramList &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ProgramList &data);

	struct ProgramID
	{
		std::vector<int64_t> programID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ProgramID &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ProgramID &data);

	struct SendProgramFilePaths
	{
		string programPath;
		std::map<string, string> mediasPath;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SendProgramFilePaths &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SendProgramFilePaths &data);

	struct StartTransferProgram
	{
		string sn;
		string iconPath;
		string iconName;
		SendProgramFilePaths sendProgramFilePaths;
		string programName;
		string deviceIdentifier;
		bool startPlayAfterTransferred;
		bool insertPlay;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const StartTransferProgram &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, StartTransferProgram &data);

	struct Solutions
	{
		string name;
		string identifier;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Solutions &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Solutions &data);

	struct TransferProgram
	{
		string deviceIdentifier;
		long totalSize;
		string type;
		int source;
		bool local;
		Solutions solutions;

	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TransferProgram &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TransferProgram &data);

	struct TransferProgramInfo
	{
		string sn;
		TransferProgram transferProgram;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TransferProgramInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TransferProgramInfo &data);

	struct AppliedInfos
	{
		string name;
		string identifier;
		string uploadUrl;
		int statusCode;
		int source;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AppliedInfos &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, AppliedInfos &data);


	struct DirectoryInfos
	{
		string type;
		long long  availableSize;
		long long  criticalSize;
		string directoryUrl;
		long long  reserveSize;
		long long  totalSize;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DirectoryInfos &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DirectoryInfos &data);

	struct TransferProgramResponseData
	{
		bool canTranster;
		string uploadMediaUrl;
		AppliedInfos appliedInfos;
		vector<DirectoryInfos> directoryInfos;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TransferProgramResponseData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TransferProgramResponseData &data);

	struct TransferFileInfo
	{
		int64_t bytesSent;
		int64_t bytesTotal;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TransferFileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TransferFileInfo &data);

	struct ConfirmedInfos
	{
		string identifier;
		string name;
		string planListUrl;
		string thumbnailUrl;
		int source;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConfirmedInfos &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConfirmedInfos &data);

	struct EndTransferProgramInfo
	{
		bool playImmediately;
		ConfirmedInfos confirmedInfos;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const EndTransferProgramInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, EndTransferProgramInfo &data);

	struct EndTransferProgram
	{
		string sn;
		EndTransferProgramInfo endTransferProgramInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const EndTransferProgram &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, EndTransferProgram &data);

	struct StopProgramTransfer
	{
		string sn;
		string programName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const StopProgramTransfer &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, StopProgramTransfer &data);

}

namespace ns
{
	struct CreateProgramOnSuccessData
	{
		int64_t programID;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CreateProgramOnSuccessData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CreateProgramOnSuccessData &data);

	struct CreateProgramOnSuccess
	{
		CreateProgramOnSuccessData onSuccess;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const CreateProgramOnSuccess &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, CreateProgramOnSuccess &data);
}


namespace ns
{
	struct RegisterAddress
	{
		string country;
		string province;
		string city;
		string county;
		string address;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RegisterAddress &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RegisterAddress &data);
	struct UserInfoDetail
	{
		string aliasName;
		RegisterAddress registerAddress;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UserInfoDetail &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UserInfoDetail &data);
	struct ScreenUserInfo
	{
		std::string sn;
		UserInfoDetail userInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ScreenUserInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ScreenUserInfo &data);
}

namespace ns
{
	struct DBData
	{
		std::vector<std::map<std::string, std::string>> program;
		std::vector<ns::TemplateInfo> templates;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const DBData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, DBData &data);
}

namespace ns
{
	struct ServerLang
	{
		std::string lang;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServerLang &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServerLang &data);
}

namespace ns
{
	struct Progress
	{
		long long  m_curBytes;
		long long  m_totalBytes;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Progress &data);
}

namespace ns {
	struct SearchResponseData
	{
		string sn;
		string productName;
		int16_t width = 0;
		int16_t height = 0;
		int32_t rotation = 0;
		string aliasName;
		bool logined = false;
		std::vector<string> userNameVec; ////VPlayer搜索回复
		int16_t tcpPort = 0;
		int16_t ftpPort = 0;
		int16_t syssetTcpPort = 0;
		int16_t syssetFtpPort = 0;
		int16_t encodeType = 0;
		string key;
		string platform;
		bool privacy = false;
		string ip;
		bool hasPassWord = false;
		string password;
		int64_t ignoreTime = 0;
		std::vector<string> loginedUsernames; //T卡搜索回复
		int16_t terminalState = 0;
		Version4CS firmwareInfo;
		InstalledPackageVersions installedPackageVersions;
		ConfigInfo productInfo;
		PlayerFunctions configInfo;
		ScreenMosaicInfo screenMosaicInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SearchResponseData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SearchResponseData &data);

}

namespace ns
{
	struct Number
	{
		int number;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Number &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Number &data);

	struct Name
	{
		string playerName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Name &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Name &data);


	struct newPlayerBoundingInfo
	{
		PlayerBoundingInfo data;
		string baseUrl;
		string token;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const newPlayerBoundingInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, newPlayerBoundingInfo &data);


	struct PlayerNumberData
	{
		PlayerNumber data;
		string baseUrl;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerNumberData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerNumberData &data);


	struct PlayerNameData
	{
		PlayerName data;
		string baseUrl;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PlayerNameData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PlayerNameData &data);
}

namespace ns
{
	struct Attacheds
	{
		string dir;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Attacheds &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Attacheds &data);
	struct FeedBackInfo
	{
		string sn;
		string contact;
		string description;
		vector<Attacheds> attacheds;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FeedBackInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FeedBackInfo &data);

	struct GetTokenHeader
	{
		string appid;
		string sn;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetTokenHeader &data);
	struct Sign
	{
		string sign;
		string time;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Sign &data);
	struct GetTokenResponseInfo
	{
		string token;
		long expire;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetTokenResponseInfo &data);
	struct GetTokenResponse
	{
		string logid;
		int status;
		string errmsg;
		GetTokenResponseInfo data;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetTokenResponse &data);

	struct GetOssUploadAuthInfo
	{
		string appid;
		string token;
		string sn;
	};
	struct GetOssUploadAuthInfoResponseData
	{
		string accessid;
		string host;
		string policy;
		string signature;
		int64_t expire;
		string callback;
		string dir;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetOssUploadAuthInfoResponseData &data);
	struct GetOssUploadAuthInfoResponse
	{
		string logid;
		int status;
		string errmsg;
		GetOssUploadAuthInfoResponseData data;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetOssUploadAuthInfoResponse &data);
	struct AttachedsInfo
	{
		string type;
		string dir;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const AttachedsInfo &data);
	struct FeedBackUploadInfo
	{
		string description;
		string contact;
		vector<AttachedsInfo> attacheds;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FeedBackUploadInfo &data);

	struct UploadInfoOSS
	{
		string OSSAccessKeyId;
		string policy;
		string signature;
		string callback;
		string key;
		string file;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UploadInfoOSS &data);
	struct FeedBackResult
	{
		string logid;
		int status;
		string data;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FeedBackResult &data);

	struct FeedBackState
	{
		bool state;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FeedBackState &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FeedBackState &data);
}

namespace ns
{
	struct SignalFilePath
	{
		string filePath;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SignalFilePath &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SignalFilePath &data);


	struct WidgetNameAttribute
	{
		int index;
		float speed;
		int turn;
		int scroll;
		bool random;
		string id;
		int subtabId = 0;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const WidgetNameAttribute &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, WidgetNameAttribute &data);

}

namespace ns
{
	struct FileInfo
	{
		string name;
		long size;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileInfo &data);

	struct  FileInfos
	{
		std::vector<FileInfo> fileInfos;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileInfos &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileInfos &data);

}
namespace ns
{
	//struct  IdentifierList
	//{
	//	vector<string> identifierList;
	//};
	//VIPLEXCOMMON_EXPORT void to_json(json& j, const IdentifierList &data);
	//VIPLEXCOMMON_EXPORT void from_json(const json& j, IdentifierList &data);

	struct GetIdentifierResponceData
	{
		vector<int> status;
		IdentifierList data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const GetIdentifierResponceData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, GetIdentifierResponceData &data);
}

namespace ns
{
	struct APNInfoData
	{
		string carrier;			//	APN名称，可为空，只用来显示apn列表中此apn的显示名字
		string mcc;			//	由三位数组成。 用于识别移动用户的所在国家
		string mnc;			//	由两位或三位组成。 用于识别移动用户的归属PLMN
		string apn;			//	APN网络标识（接入点名称），是APN参数中的必选组成部分。此标识由运营商分配
		string user;			//	用户名称
		string password;		//	密码
		string server;			//	服务器地址
		string proxy;			//	代理服务器的地址
		string port;			//	代理服务器的端口
		string mmsc;			//	MMS中继服务器 / 多媒体消息业务中心，是彩信的交换服务器
		string mmsproxy;		//	彩信代理服务器的地址
		string mmsport;		//	彩信代理服务器的端口号
		string type;			//	apn的接入点类型
		string protocol;		//	支持的协议，不配置默认为IPV4
		string authtype;		//	apn的认证协议
		string roamingProtocol;	//	Apn漫游协议
		bool isUserDefined;		//	是否用户自定义
		bool isUsed;			//	是否正在使用
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const APNInfoData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, APNInfoData &data);
}

namespace ns
{
	struct APNSDatas
	{
		vector<APNInfoData>APNs;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const APNSDatas &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, APNSDatas &data);
}

namespace ns
{
	struct APNInfo
	{
		string sn;
		vector<APNInfoData> APNs;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const APNInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, APNInfo &data);
}


namespace ns
{
	struct PolicyCondition
	{
		vector<string> cron;
		int action;
		string type;
		string startTime;
		string endTime;
		bool enable;
		int powerIndex;
		string flag;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const PolicyCondition &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, PolicyCondition &data);
	struct FunctionCardCommand
	{
		vector<PolicyCondition> conditions;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FunctionCardCommand &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FunctionCardCommand &data);
	struct FunctionCardPolicy
	{
		bool enable;
		int portIndex;
		int connectIndex;
		vector<FunctionCardCommand> commands;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FunctionCardPolicy &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FunctionCardPolicy &data);
	struct FunctionPowerPolicyDetail
	{
		string type;
		Source source;
		vector<FunctionCardPolicy> data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FunctionPowerPolicyDetail &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FunctionPowerPolicyDetail &data);
	struct FunctionPowerPolicy
	{
		string sn;
		FunctionPowerPolicyDetail taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FunctionPowerPolicy &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FunctionPowerPolicy &data);
}
namespace ns
{
	struct FlightModeInfo
	{
		string sn;
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FlightModeInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FlightModeInfo &data);
}


namespace ns
{
	struct FunctionCardManual
	{
		int	action;
		string type;
		int powerIndex;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FunctionCardManual &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FunctionCardManual &data);


	struct ManualPowerSwitchStatusData
	{
		vector<FunctionCardManual> conditions;
		int portIndex;
		int connectIndex;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ManualPowerSwitchStatusData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ManualPowerSwitchStatusData &data);


	struct ManualPowerSwitchStatus
	{
		string type;
		Source source;
		vector<ManualPowerSwitchStatusData> data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ManualPowerSwitchStatus &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ManualPowerSwitchStatus &data);

	struct ManualPowerSwitchStatusInfo
	{
		string sn;
		ManualPowerSwitchStatus data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ManualPowerSwitchStatusInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ManualPowerSwitchStatusInfo &data);
}

namespace ns
{
	struct IsUseDayLightTimeData
	{
		string timeZone;
		string gmt;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IsUseDayLightTimeData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IsUseDayLightTimeData &data);

	struct IsUseDayLightTimeInfo
	{
		string sn;
		IsUseDayLightTimeData isUseDayLightTimeData;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const IsUseDayLightTimeInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, IsUseDayLightTimeInfo &data);
}
//vpn管理
namespace ns
{
	struct NetWorkInfo
	{
		string ipAddress;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const NetWorkInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, NetWorkInfo &data);
	struct ConnectInfo
	{
		string connectStatus;
		string failReasonCode;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ConnectInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ConnectInfo &data);
	struct VpnInfoResponse
	{
		string guid;
		string platform;
		string taskAction;
		string softwareVersion;
		int playerType;
		string time;
		string vpnName;
		string vpnAddress;
		string vpnType;
		string username;
		string password;
		string sharedSecretKey;
		string redialNumber;
		string redialInterval;
		string sessionTime;
		string isBolTredial;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VpnInfoResponse &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VpnInfoResponse &data);
	struct VPNInfoDetailResponse
	{
		string guid;
		string taskAction;
		Source source;
		string timestamp;
		VpnInfoResponse vpnInfo;
		ConnectInfo connectInfo;
		NetWorkInfo netWorkInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VPNInfoDetailResponse &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VPNInfoDetailResponse &data);

	struct VpnInfo
	{
		string name;
		string address;
		int protocolType;
		string username;
		string password;
		string sharedSecretKey;
		int redialNumber;
		int redialInterval;
		int sessionTimeout;
		bool isReconnect;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VpnInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VpnInfo &data);
	struct VPNInfoDetail
	{
		string guid;
		string taskAction;
		Source source;
		VpnInfo vpnInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VPNInfoDetail &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VPNInfoDetail &data);
	struct VPN
	{
		string sn;
		VPNInfoDetail taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const VPN &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, VPN &data);


	struct ServiceName
	{
		string serviceName;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ServiceName &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ServiceName &data);

	struct SerciveData
	{
		string sn;
		ServiceName taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SerciveData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SerciveData &data);

}

namespace ns
{
	struct RelayPowerSwitchData
	{
		int powerIndex;
		int status;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelayPowerSwitchData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelayPowerSwitchData &data);

	struct RelayPowerSwitchInfo
	{
		ns::Source source;
		std::vector<ns::RelayPowerSwitchData> data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelayPowerSwitchInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelayPowerSwitchInfo &data);

	struct RelayPowerSwitchRequest
	{
		std::string sn;
		RelayPowerSwitchInfo info;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelayPowerSwitchRequest &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelayPowerSwitchRequest &data);
}

namespace ns
{
	struct RelayPowerPolicySwitchData
	{
		vector<string> cron;
		int powerIndex;
		int status;
		string startTime;
		string endTime;
		string type;
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelayPowerPolicySwitchData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelayPowerPolicySwitchData &data);

	struct RelayPowerPolicySwitchInfo
	{
		ns::Source source;
		std::vector<ns::RelayPowerPolicySwitchData> data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelayPowerPolicySwitchInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelayPowerPolicySwitchInfo &data);

	struct RelayPowerPolicySwitchRequest
	{
		std::string sn;
		RelayPowerPolicySwitchInfo info;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const RelayPowerPolicySwitchRequest &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, RelayPowerPolicySwitchRequest &data);
}

namespace ns
{
	struct FontInfo
	{
		string name;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FontInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FontInfo &data);
	struct FontDetail
	{
		vector<FontInfo> fonts;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FontDetail &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FontDetail &data);
	struct TerminalFont
	{
		string sn;
		FontDetail taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const TerminalFont &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, TerminalFont &data);
	struct UpdateFontInfo
	{
		string name;
		vector<string> style;
		vector<string> file;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdateFontInfo &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdateFontInfo &data);
	struct UpdateFontDetail
	{
		vector<UpdateFontInfo> fonts;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdateFontDetail &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdateFontDetail &data);
	struct UpdateFont
	{
		string sn;
		string localFontPath;
		UpdateFontDetail taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const UpdateFont &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, UpdateFont &data);
	struct FontPath
	{
		string fontPath;
	};
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FontPath &data);
}

namespace ns
{
	struct receiveCardRegionData
	{
		int connectedIndex;
        int portIndex;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const receiveCardRegionData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, receiveCardRegionData &data);

	struct receiveCardRegionWrapper
	{
		vector<receiveCardRegionData> receiveCardRegionInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const receiveCardRegionWrapper &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, receiveCardRegionWrapper &data);

	struct receiveCardRegionRequest
	{
		string sn;
		receiveCardRegionWrapper info;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const receiveCardRegionRequest &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, receiveCardRegionRequest &data);


	struct FileManagerData 
	{
		string sn;
		HostData data;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const FileManagerData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, FileManagerData &data);

	struct Enable 
	{
		bool enable;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const Enable &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, Enable &data);

	struct USBAuthenticData 
	{
		string sn;
		Enable taskInfo;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const USBAuthenticData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, USBAuthenticData &data);

}

namespace ns
{
	struct SetTerminalStatusValue
	{
		int value;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetTerminalStatusValue &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetTerminalStatusValue &data);

	struct SetTerminalStatus
	{
		string sn;
		SetTerminalStatusValue info;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetTerminalStatus &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetTerminalStatus &data);

	
}

namespace ns
{
	struct ResolutionData
	{
		int displayMode;
		int	width;
		int	height;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const ResolutionData &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, ResolutionData &data);

	struct SetCustomResolutionRequest
	{
		string sn;
		ResolutionData info;
	};
	VIPLEXCOMMON_EXPORT void to_json(json& j, const SetCustomResolutionRequest &data);
	VIPLEXCOMMON_EXPORT void from_json(const json& j, SetCustomResolutionRequest &data);


}
